/* Generated by Cython 0.16 on Sun Jul 29 12:55:45 2012 */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02040000
    #error Cython requires Python 2.4+.
#else
#include <stddef.h> /* For offsetof */
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif

#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif

#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif

#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif

#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif

#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif

#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCFunction_Call PyObject_Call
#else
  #define __Pyx_PyCFunction_Call PyCFunction_Call
#endif

#if PY_VERSION_HEX < 0x02050000
  typedef int Py_ssize_t;
  #define PY_SSIZE_T_MAX INT_MAX
  #define PY_SSIZE_T_MIN INT_MIN
  #define PY_FORMAT_SIZE_T ""
  #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
  #define PyInt_AsSsize_t(o)   __Pyx_PyInt_AsInt(o)
  #define PyNumber_Index(o)    PyNumber_Int(o)
  #define PyIndex_Check(o)     PyNumber_Check(o)
  #define PyErr_WarnEx(category, message, stacklevel) PyErr_Warn(category, message)
  #define __PYX_BUILD_PY_SSIZE_T "i"
#else
  #define __PYX_BUILD_PY_SSIZE_T "n"
#endif

#if PY_VERSION_HEX < 0x02060000
  #define Py_REFCNT(ob) (((PyObject*)(ob))->ob_refcnt)
  #define Py_TYPE(ob)   (((PyObject*)(ob))->ob_type)
  #define Py_SIZE(ob)   (((PyVarObject*)(ob))->ob_size)
  #define PyVarObject_HEAD_INIT(type, size) \
          PyObject_HEAD_INIT(type) size,
  #define PyType_Modified(t)

  typedef struct {
     void *buf;
     PyObject *obj;
     Py_ssize_t len;
     Py_ssize_t itemsize;
     int readonly;
     int ndim;
     char *format;
     Py_ssize_t *shape;
     Py_ssize_t *strides;
     Py_ssize_t *suboffsets;
     void *internal;
  } Py_buffer;

  #define PyBUF_SIMPLE 0
  #define PyBUF_WRITABLE 0x0001
  #define PyBUF_FORMAT 0x0004
  #define PyBUF_ND 0x0008
  #define PyBUF_STRIDES (0x0010 | PyBUF_ND)
  #define PyBUF_C_CONTIGUOUS (0x0020 | PyBUF_STRIDES)
  #define PyBUF_F_CONTIGUOUS (0x0040 | PyBUF_STRIDES)
  #define PyBUF_ANY_CONTIGUOUS (0x0080 | PyBUF_STRIDES)
  #define PyBUF_INDIRECT (0x0100 | PyBUF_STRIDES)
  #define PyBUF_RECORDS (PyBUF_STRIDES | PyBUF_FORMAT | PyBUF_WRITABLE)
  #define PyBUF_FULL (PyBUF_INDIRECT | PyBUF_FORMAT | PyBUF_WRITABLE)

  typedef int (*getbufferproc)(PyObject *, Py_buffer *, int);
  typedef void (*releasebufferproc)(PyObject *, Py_buffer *);
#endif

#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif

#if PY_MAJOR_VERSION < 3 && PY_MINOR_VERSION < 6
  #define PyUnicode_FromString(s) PyUnicode_Decode(s, strlen(s), "UTF-8", "strict")
#endif

#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif

#if (PY_VERSION_HEX < 0x02060000) || (PY_MAJOR_VERSION >= 3)
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif


#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_GET_LENGTH)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_GET_LENGTH(u) PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_GET_LENGTH(u) PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
#endif

#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif

#if PY_VERSION_HEX < 0x02060000
  #define PyBytesObject                PyStringObject
  #define PyBytes_Type                 PyString_Type
  #define PyBytes_Check                PyString_Check
  #define PyBytes_CheckExact           PyString_CheckExact
  #define PyBytes_FromString           PyString_FromString
  #define PyBytes_FromStringAndSize    PyString_FromStringAndSize
  #define PyBytes_FromFormat           PyString_FromFormat
  #define PyBytes_DecodeEscape         PyString_DecodeEscape
  #define PyBytes_AsString             PyString_AsString
  #define PyBytes_AsStringAndSize      PyString_AsStringAndSize
  #define PyBytes_Size                 PyString_Size
  #define PyBytes_AS_STRING            PyString_AS_STRING
  #define PyBytes_GET_SIZE             PyString_GET_SIZE
  #define PyBytes_Repr                 PyString_Repr
  #define PyBytes_Concat               PyString_Concat
  #define PyBytes_ConcatAndDel         PyString_ConcatAndDel
#endif

#if PY_VERSION_HEX < 0x02060000
  #define PySet_Check(obj)             PyObject_TypeCheck(obj, &PySet_Type)
  #define PyFrozenSet_Check(obj)       PyObject_TypeCheck(obj, &PyFrozenSet_Type)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif

#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)

#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
#endif

#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif

#if PY_VERSION_HEX < 0x03020000
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif

#if (PY_MAJOR_VERSION < 3) || (PY_VERSION_HEX >= 0x03010300)
  #define __Pyx_PySequence_GetSlice(obj, a, b) PySequence_GetSlice(obj, a, b)
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) PySequence_SetSlice(obj, a, b, value)
  #define __Pyx_PySequence_DelSlice(obj, a, b) PySequence_DelSlice(obj, a, b)
#else
  #define __Pyx_PySequence_GetSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), (PyObject*)0) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_GetSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object is unsliceable", (obj)->ob_type->tp_name), (PyObject*)0)))
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_SetSlice(obj, a, b, value)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice assignment", (obj)->ob_type->tp_name), -1)))
  #define __Pyx_PySequence_DelSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_DelSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice deletion", (obj)->ob_type->tp_name), -1)))
#endif

#if PY_MAJOR_VERSION >= 3
  #define PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#endif

#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),((char *)(n)))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),((char *)(n)),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),((char *)(n)))
#else
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),(n))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),(n),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),(n))
#endif

#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_NAMESTR(n) ((char *)(n))
  #define __Pyx_DOCSTR(n)  ((char *)(n))
#else
  #define __Pyx_NAMESTR(n) (n)
  #define __Pyx_DOCSTR(n)  (n)
#endif

#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__chealpy___ccode
#define __PYX_HAVE_API__chealpy___ccode
#include "stdio.h"
#include "stdlib.h"
#include "numpy/arrayobject.h"
#include "numpy/ufuncobject.h"
#include "stdint.h"
#include "chealpix.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif


/* inline attribute */
#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* unused attribute */
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif

typedef struct {PyObject **p; char *s; const long n; const char* encoding; const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry; /*proto*/


/* Type Conversion Predeclarations */

#define __Pyx_PyBytes_FromUString(s) PyBytes_FromString((char*)s)
#define __Pyx_PyBytes_AsUString(s)   ((unsigned char*) PyBytes_AsString(s))

#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);

static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject*);

#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))

#ifdef __GNUC__
  /* Test for GCC > 2.95 */
  #if __GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95))
    #define likely(x)   __builtin_expect(!!(x), 1)
    #define unlikely(x) __builtin_expect(!!(x), 0)
  #else /* __GNUC__ > 2 ... */
    #define likely(x)   (x)
    #define unlikely(x) (x)
  #endif /* __GNUC__ > 2 ... */
#else /* __GNUC__ */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
    
static PyObject *__pyx_m;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;

#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif defined(_Complex_I)
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif


static const char *__pyx_f[] = {
  "_ccode.pyx",
  "npyiter.pxd",
  "numpy.pxd",
};

/* "numpy.pxd":722
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "numpy.pxd":723
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "numpy.pxd":724
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "numpy.pxd":725
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "numpy.pxd":729
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "numpy.pxd":730
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "numpy.pxd":731
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "numpy.pxd":732
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "numpy.pxd":736
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "numpy.pxd":737
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "numpy.pxd":746
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "numpy.pxd":747
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_longlong __pyx_t_5numpy_long_t;

/* "numpy.pxd":748
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "numpy.pxd":750
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "numpy.pxd":751
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulonglong __pyx_t_5numpy_ulong_t;

/* "numpy.pxd":752
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "numpy.pxd":754
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "numpy.pxd":755
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "numpy.pxd":757
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "numpy.pxd":758
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "numpy.pxd":759
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif


/*--- Type declarations ---*/

/* "numpy.pxd":761
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "numpy.pxd":762
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "numpy.pxd":763
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "numpy.pxd":765
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;
struct __pyx_t_7chealpy_7npyiter_NewNpyArrayIterObject;
typedef struct __pyx_t_7chealpy_7npyiter_NewNpyArrayIterObject __pyx_t_7chealpy_7npyiter_NewNpyArrayIterObject;
struct __pyx_t_7chealpy_7npyiter_CIter;
typedef struct __pyx_t_7chealpy_7npyiter_CIter __pyx_t_7chealpy_7npyiter_CIter;

/* "npyiter.pxd":27
 * from cpython.ref cimport PyObject
 * 
 * ctypedef void NpyIter             # <<<<<<<<<<<<<<
 * ctypedef int (*IterNextFunc)(NpyIter * iter) nogil
 * ctypedef void (*GetMultiIndexFunc)(NpyIter * iter, numpy.npy_intp *outcoords) nogil
 */
typedef void __pyx_t_7chealpy_7npyiter_NpyIter;

/* "npyiter.pxd":28
 * 
 * ctypedef void NpyIter
 * ctypedef int (*IterNextFunc)(NpyIter * iter) nogil             # <<<<<<<<<<<<<<
 * ctypedef void (*GetMultiIndexFunc)(NpyIter * iter, numpy.npy_intp *outcoords) nogil
 * 
 */
typedef int (*__pyx_t_7chealpy_7npyiter_IterNextFunc)(__pyx_t_7chealpy_7npyiter_NpyIter *);

/* "npyiter.pxd":29
 * ctypedef void NpyIter
 * ctypedef int (*IterNextFunc)(NpyIter * iter) nogil
 * ctypedef void (*GetMultiIndexFunc)(NpyIter * iter, numpy.npy_intp *outcoords) nogil             # <<<<<<<<<<<<<<
 * 
 * ctypedef struct NewNpyArrayIterObject:
 */
typedef void (*__pyx_t_7chealpy_7npyiter_GetMultiIndexFunc)(__pyx_t_7chealpy_7npyiter_NpyIter *, npy_intp *);

/* "npyiter.pxd":31
 * ctypedef void (*GetMultiIndexFunc)(NpyIter * iter, numpy.npy_intp *outcoords) nogil
 * 
 * ctypedef struct NewNpyArrayIterObject:             # <<<<<<<<<<<<<<
 *     PyObject base
 *     NpyIter *iter
 */
struct __pyx_t_7chealpy_7npyiter_NewNpyArrayIterObject {
  PyObject base;
  __pyx_t_7chealpy_7npyiter_NpyIter *iter;
};

/* "npyiter.pxd":48
 *   return (<NewNpyArrayIterObject*>iter).iter
 * 
 * ctypedef struct CIter:             # <<<<<<<<<<<<<<
 *   NpyIter * npyiter
 *   IterNextFunc _next
 */
struct __pyx_t_7chealpy_7npyiter_CIter {
  __pyx_t_7chealpy_7npyiter_NpyIter *npyiter;
  __pyx_t_7chealpy_7npyiter_IterNextFunc _next;
  char **data;
  npy_intp *strides;
  npy_intp *size_ptr;
  int nop;
};
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname); /*proto*/
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif /* CYTHON_REFNANNY */
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found); /*proto*/

static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name); /*proto*/

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[], \
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args, \
    const char* function_name); /*proto*/

static PyObject *__Pyx_GetName(PyObject *dict, PyObject *name); /*proto*/

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type); /*proto*/

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb); /*proto*/
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index); /*proto*/

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, long level); /*proto*/

#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(_WIN32) && defined(__cplusplus) && CYTHON_CCOMPLEX
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

#if CYTHON_CCOMPLEX
    #define __Pyx_c_eqf(a, b)   ((a)==(b))
    #define __Pyx_c_sumf(a, b)  ((a)+(b))
    #define __Pyx_c_difff(a, b) ((a)-(b))
    #define __Pyx_c_prodf(a, b) ((a)*(b))
    #define __Pyx_c_quotf(a, b) ((a)/(b))
    #define __Pyx_c_negf(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zerof(z) ((z)==(float)0)
    #define __Pyx_c_conjf(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_absf(z)     (::std::abs(z))
        #define __Pyx_c_powf(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zerof(z) ((z)==0)
    #define __Pyx_c_conjf(z)    (conjf(z))
    #if 1
        #define __Pyx_c_absf(z)     (cabsf(z))
        #define __Pyx_c_powf(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eqf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sumf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_difff(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prodf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quotf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_negf(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zerof(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conjf(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_absf(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_powf(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);

#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq(a, b)   ((a)==(b))
    #define __Pyx_c_sum(a, b)  ((a)+(b))
    #define __Pyx_c_diff(a, b) ((a)-(b))
    #define __Pyx_c_prod(a, b) ((a)*(b))
    #define __Pyx_c_quot(a, b) ((a)/(b))
    #define __Pyx_c_neg(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero(z) ((z)==(double)0)
    #define __Pyx_c_conj(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs(z)     (::std::abs(z))
        #define __Pyx_c_pow(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero(z) ((z)==0)
    #define __Pyx_c_conj(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs(z)     (cabs(z))
        #define __Pyx_c_pow(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject *);

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject *);

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject *);

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject *);

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject *);

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject *);

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject *);

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject *);

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject *);

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject *);

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject *);

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject *);

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject *);

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject *);

static int __Pyx_check_binary_version(void);

#if !defined(__Pyx_PyIdentifier_FromString)
#if PY_MAJOR_VERSION < 3
  #define __Pyx_PyIdentifier_FromString(s) PyString_FromString(s)
#else
  #define __Pyx_PyIdentifier_FromString(s) PyUnicode_FromString(s)
#endif
#endif

static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name, size_t size, int strict);  /*proto*/

static PyObject *__Pyx_ImportModule(const char *name); /*proto*/

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename); /*proto*/

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t); /*proto*/


/* Module declarations from 'cpython.buffer' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'libc.stdlib' */

/* Module declarations from 'numpy' */

/* Module declarations from 'numpy' */
static PyTypeObject *__pyx_ptype_5numpy_dtype = 0;
static PyTypeObject *__pyx_ptype_5numpy_flatiter = 0;
static PyTypeObject *__pyx_ptype_5numpy_broadcast = 0;
static PyTypeObject *__pyx_ptype_5numpy_ndarray = 0;
static PyTypeObject *__pyx_ptype_5numpy_ufunc = 0;
static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *, char *, char *, int *); /*proto*/

/* Module declarations from 'chealpy.npyiter' */
static CYTHON_INLINE __pyx_t_7chealpy_7npyiter_NpyIter *__pyx_f_7chealpy_7npyiter_GetNpyIter(PyObject *); /*proto*/
static CYTHON_INLINE size_t __pyx_f_7chealpy_7npyiter_next(__pyx_t_7chealpy_7npyiter_CIter *); /*proto*/
static CYTHON_INLINE size_t __pyx_f_7chealpy_7npyiter_init(__pyx_t_7chealpy_7npyiter_CIter *, PyObject *); /*proto*/
static CYTHON_INLINE void __pyx_f_7chealpy_7npyiter_advance(__pyx_t_7chealpy_7npyiter_CIter *); /*proto*/

/* Module declarations from 'libc.stdint' */

/* Module declarations from 'chealpy._ccode' */
#define __Pyx_MODULE_NAME "chealpy._ccode"
int __pyx_module_is_main_chealpy___ccode = 0;

/* Implementation of 'chealpy._ccode' */
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_pf_7chealpy_6_ccode_ang2pix_ring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi, PyObject *__pyx_v_ipix); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_2ang2pix_nest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi, PyObject *__pyx_v_ipix); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_4ang2pix_ring64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi, PyObject *__pyx_v_ipix); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_6ang2pix_nest64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi, PyObject *__pyx_v_ipix); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_8pix2ang_ring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_10pix2ang_nest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_12pix2ang_ring64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_14pix2ang_nest64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_16vec2pix_ring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_vec, PyObject *__pyx_v_ipix); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_18vec2pix_nest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_vec, PyObject *__pyx_v_ipix); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_20vec2pix_ring64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_vec, PyObject *__pyx_v_ipix); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_22vec2pix_nest64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_vec, PyObject *__pyx_v_ipix); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_24pix2vec_ring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_vec); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_26pix2vec_nest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_vec); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_28pix2vec_ring64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_vec); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_30pix2vec_nest64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_vec); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_32nest2ring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipnest, PyObject *__pyx_v_ipring); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_34nest2ring64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipnest, PyObject *__pyx_v_ipring); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_36ring2nest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipring, PyObject *__pyx_v_ipnest); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_38ring2nest64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipring, PyObject *__pyx_v_ipnest); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_40npix2nside(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_npix, PyObject *__pyx_v_nside); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_42npix2nside64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_npix, PyObject *__pyx_v_nside); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_44nside2npix(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_npix); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_46nside2npix64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_npix); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_48ang2vec(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi, PyObject *__pyx_v_vec); /* proto */
static PyObject *__pyx_pf_7chealpy_6_ccode_50vec2ang(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_vec, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi); /* proto */
static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info); /* proto */
static char __pyx_k_71[] = "ndarray is not C contiguous";
static char __pyx_k_73[] = "ndarray is not Fortran contiguous";
static char __pyx_k_75[] = "Non-native byte order not supported";
static char __pyx_k_77[] = "unknown dtype code in numpy.pxd (%d)";
static char __pyx_k_78[] = "Format string allocated too short, see comment in numpy.pxd";
static char __pyx_k_81[] = "Format string allocated too short.";
static char __pyx_k_85[] = "/home/yfeng1/Projects/chealpy/chealpy/_ccode.pyx";
static char __pyx_k_86[] = "chealpy._ccode";
static char __pyx_k__B[] = "B";
static char __pyx_k__H[] = "H";
static char __pyx_k__I[] = "I";
static char __pyx_k__L[] = "L";
static char __pyx_k__O[] = "O";
static char __pyx_k__Q[] = "Q";
static char __pyx_k__b[] = "b";
static char __pyx_k__d[] = "d";
static char __pyx_k__f[] = "f";
static char __pyx_k__g[] = "g";
static char __pyx_k__h[] = "h";
static char __pyx_k__i[] = "i";
static char __pyx_k__l[] = "l";
static char __pyx_k__q[] = "q";
static char __pyx_k__Zd[] = "Zd";
static char __pyx_k__Zf[] = "Zf";
static char __pyx_k__Zg[] = "Zg";
static char __pyx_k__f8[] = "f8";
static char __pyx_k__i8[] = "i8";
static char __pyx_k__int[] = "int";
static char __pyx_k__phi[] = "phi";
static char __pyx_k__vec[] = "vec";
static char __pyx_k___phi[] = "_phi";
static char __pyx_k___vec[] = "_vec";
static char __pyx_k__ipix[] = "ipix";
static char __pyx_k__iter[] = "iter";
static char __pyx_k__npix[] = "npix";
static char __pyx_k__size[] = "size";
static char __pyx_k___ipix[] = "_ipix";
static char __pyx_k___npix[] = "_npix";
static char __pyx_k__citer[] = "citer";
static char __pyx_k__dtype[] = "dtype";
static char __pyx_k__empty[] = "empty";
static char __pyx_k__flags[] = "flags";
static char __pyx_k__nside[] = "nside";
static char __pyx_k__numpy[] = "numpy";
static char __pyx_k__range[] = "range";
static char __pyx_k__shape[] = "shape";
static char __pyx_k__theta[] = "theta";
static char __pyx_k__vec_a[] = "vec_a";
static char __pyx_k___nside[] = "_nside";
static char __pyx_k___theta[] = "_theta";
static char __pyx_k__ipnest[] = "ipnest";
static char __pyx_k__ipring[] = "ipring";
static char __pyx_k__nditer[] = "nditer";
static char __pyx_k__unsafe[] = "unsafe";
static char __pyx_k___ipnest[] = "_ipnest";
static char __pyx_k___ipring[] = "_ipring";
static char __pyx_k__ang2vec[] = "ang2vec";
static char __pyx_k__casting[] = "casting";
static char __pyx_k__vec2ang[] = "vec2ang";
static char __pyx_k____main__[] = "__main__";
static char __pyx_k____test__[] = "__test__";
static char __pyx_k__buffered[] = "buffered";
static char __pyx_k__op_flags[] = "op_flags";
static char __pyx_k__readonly[] = "readonly";
static char __pyx_k__nest2ring[] = "nest2ring";
static char __pyx_k__op_dtypes[] = "op_dtypes";
static char __pyx_k__ring2nest[] = "ring2nest";
static char __pyx_k__writeonly[] = "writeonly";
static char __pyx_k__ValueError[] = "ValueError";
static char __pyx_k__npix2nside[] = "npix2nside";
static char __pyx_k__nside2npix[] = "nside2npix";
static char __pyx_k__nest2ring64[] = "nest2ring64";
static char __pyx_k__ring2nest64[] = "ring2nest64";
static char __pyx_k__zerosize_ok[] = "zerosize_ok";
static char __pyx_k__RuntimeError[] = "RuntimeError";
static char __pyx_k__ang2pix_nest[] = "ang2pix_nest";
static char __pyx_k__ang2pix_ring[] = "ang2pix_ring";
static char __pyx_k__npix2nside64[] = "npix2nside64";
static char __pyx_k__nside2npix64[] = "nside2npix64";
static char __pyx_k__pix2ang_nest[] = "pix2ang_nest";
static char __pyx_k__pix2ang_ring[] = "pix2ang_ring";
static char __pyx_k__pix2vec_nest[] = "pix2vec_nest";
static char __pyx_k__pix2vec_ring[] = "pix2vec_ring";
static char __pyx_k__vec2pix_nest[] = "vec2pix_nest";
static char __pyx_k__vec2pix_ring[] = "vec2pix_ring";
static char __pyx_k__external_loop[] = "external_loop";
static char __pyx_k__ang2pix_nest64[] = "ang2pix_nest64";
static char __pyx_k__ang2pix_ring64[] = "ang2pix_ring64";
static char __pyx_k__pix2ang_nest64[] = "pix2ang_nest64";
static char __pyx_k__pix2ang_ring64[] = "pix2ang_ring64";
static char __pyx_k__pix2vec_nest64[] = "pix2vec_nest64";
static char __pyx_k__pix2vec_ring64[] = "pix2vec_ring64";
static char __pyx_k__vec2pix_nest64[] = "vec2pix_nest64";
static char __pyx_k__vec2pix_ring64[] = "vec2pix_ring64";
static PyObject *__pyx_kp_u_71;
static PyObject *__pyx_kp_u_73;
static PyObject *__pyx_kp_u_75;
static PyObject *__pyx_kp_u_77;
static PyObject *__pyx_kp_u_78;
static PyObject *__pyx_kp_u_81;
static PyObject *__pyx_kp_s_85;
static PyObject *__pyx_n_s_86;
static PyObject *__pyx_n_s__RuntimeError;
static PyObject *__pyx_n_s__ValueError;
static PyObject *__pyx_n_s____main__;
static PyObject *__pyx_n_s____test__;
static PyObject *__pyx_n_s___ipix;
static PyObject *__pyx_n_s___ipnest;
static PyObject *__pyx_n_s___ipring;
static PyObject *__pyx_n_s___npix;
static PyObject *__pyx_n_s___nside;
static PyObject *__pyx_n_s___phi;
static PyObject *__pyx_n_s___theta;
static PyObject *__pyx_n_s___vec;
static PyObject *__pyx_n_s__ang2pix_nest;
static PyObject *__pyx_n_s__ang2pix_nest64;
static PyObject *__pyx_n_s__ang2pix_ring;
static PyObject *__pyx_n_s__ang2pix_ring64;
static PyObject *__pyx_n_s__ang2vec;
static PyObject *__pyx_n_s__buffered;
static PyObject *__pyx_n_s__casting;
static PyObject *__pyx_n_s__citer;
static PyObject *__pyx_n_s__dtype;
static PyObject *__pyx_n_s__empty;
static PyObject *__pyx_n_s__external_loop;
static PyObject *__pyx_n_s__f8;
static PyObject *__pyx_n_s__flags;
static PyObject *__pyx_n_s__i8;
static PyObject *__pyx_n_s__int;
static PyObject *__pyx_n_s__ipix;
static PyObject *__pyx_n_s__ipnest;
static PyObject *__pyx_n_s__ipring;
static PyObject *__pyx_n_s__iter;
static PyObject *__pyx_n_s__nditer;
static PyObject *__pyx_n_s__nest2ring;
static PyObject *__pyx_n_s__nest2ring64;
static PyObject *__pyx_n_s__npix;
static PyObject *__pyx_n_s__npix2nside;
static PyObject *__pyx_n_s__npix2nside64;
static PyObject *__pyx_n_s__nside;
static PyObject *__pyx_n_s__nside2npix;
static PyObject *__pyx_n_s__nside2npix64;
static PyObject *__pyx_n_s__numpy;
static PyObject *__pyx_n_s__op_dtypes;
static PyObject *__pyx_n_s__op_flags;
static PyObject *__pyx_n_s__phi;
static PyObject *__pyx_n_s__pix2ang_nest;
static PyObject *__pyx_n_s__pix2ang_nest64;
static PyObject *__pyx_n_s__pix2ang_ring;
static PyObject *__pyx_n_s__pix2ang_ring64;
static PyObject *__pyx_n_s__pix2vec_nest;
static PyObject *__pyx_n_s__pix2vec_nest64;
static PyObject *__pyx_n_s__pix2vec_ring;
static PyObject *__pyx_n_s__pix2vec_ring64;
static PyObject *__pyx_n_s__range;
static PyObject *__pyx_n_s__readonly;
static PyObject *__pyx_n_s__ring2nest;
static PyObject *__pyx_n_s__ring2nest64;
static PyObject *__pyx_n_s__shape;
static PyObject *__pyx_n_s__size;
static PyObject *__pyx_n_s__theta;
static PyObject *__pyx_n_s__unsafe;
static PyObject *__pyx_n_s__vec;
static PyObject *__pyx_n_s__vec2ang;
static PyObject *__pyx_n_s__vec2pix_nest;
static PyObject *__pyx_n_s__vec2pix_nest64;
static PyObject *__pyx_n_s__vec2pix_ring;
static PyObject *__pyx_n_s__vec2pix_ring64;
static PyObject *__pyx_n_s__vec_a;
static PyObject *__pyx_n_s__writeonly;
static PyObject *__pyx_n_s__zerosize_ok;
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_15;
static PyObject *__pyx_k_tuple_1;
static PyObject *__pyx_k_tuple_2;
static PyObject *__pyx_k_tuple_3;
static PyObject *__pyx_k_tuple_4;
static PyObject *__pyx_k_tuple_5;
static PyObject *__pyx_k_tuple_6;
static PyObject *__pyx_k_tuple_7;
static PyObject *__pyx_k_tuple_8;
static PyObject *__pyx_k_tuple_9;
static PyObject *__pyx_k_tuple_10;
static PyObject *__pyx_k_tuple_11;
static PyObject *__pyx_k_tuple_12;
static PyObject *__pyx_k_tuple_13;
static PyObject *__pyx_k_tuple_14;
static PyObject *__pyx_k_tuple_15;
static PyObject *__pyx_k_tuple_16;
static PyObject *__pyx_k_tuple_17;
static PyObject *__pyx_k_tuple_18;
static PyObject *__pyx_k_tuple_19;
static PyObject *__pyx_k_tuple_20;
static PyObject *__pyx_k_tuple_21;
static PyObject *__pyx_k_tuple_22;
static PyObject *__pyx_k_tuple_23;
static PyObject *__pyx_k_tuple_24;
static PyObject *__pyx_k_tuple_25;
static PyObject *__pyx_k_tuple_26;
static PyObject *__pyx_k_tuple_27;
static PyObject *__pyx_k_tuple_28;
static PyObject *__pyx_k_tuple_29;
static PyObject *__pyx_k_tuple_30;
static PyObject *__pyx_k_tuple_31;
static PyObject *__pyx_k_tuple_32;
static PyObject *__pyx_k_tuple_33;
static PyObject *__pyx_k_tuple_34;
static PyObject *__pyx_k_tuple_35;
static PyObject *__pyx_k_tuple_36;
static PyObject *__pyx_k_tuple_37;
static PyObject *__pyx_k_tuple_38;
static PyObject *__pyx_k_tuple_39;
static PyObject *__pyx_k_tuple_40;
static PyObject *__pyx_k_tuple_41;
static PyObject *__pyx_k_tuple_42;
static PyObject *__pyx_k_tuple_43;
static PyObject *__pyx_k_tuple_44;
static PyObject *__pyx_k_tuple_45;
static PyObject *__pyx_k_tuple_46;
static PyObject *__pyx_k_tuple_47;
static PyObject *__pyx_k_tuple_48;
static PyObject *__pyx_k_tuple_49;
static PyObject *__pyx_k_tuple_50;
static PyObject *__pyx_k_tuple_51;
static PyObject *__pyx_k_tuple_52;
static PyObject *__pyx_k_tuple_53;
static PyObject *__pyx_k_tuple_54;
static PyObject *__pyx_k_tuple_55;
static PyObject *__pyx_k_tuple_56;
static PyObject *__pyx_k_tuple_57;
static PyObject *__pyx_k_tuple_58;
static PyObject *__pyx_k_tuple_59;
static PyObject *__pyx_k_tuple_60;
static PyObject *__pyx_k_tuple_61;
static PyObject *__pyx_k_tuple_62;
static PyObject *__pyx_k_tuple_63;
static PyObject *__pyx_k_tuple_64;
static PyObject *__pyx_k_tuple_65;
static PyObject *__pyx_k_tuple_66;
static PyObject *__pyx_k_tuple_67;
static PyObject *__pyx_k_tuple_68;
static PyObject *__pyx_k_tuple_69;
static PyObject *__pyx_k_tuple_70;
static PyObject *__pyx_k_tuple_72;
static PyObject *__pyx_k_tuple_74;
static PyObject *__pyx_k_tuple_76;
static PyObject *__pyx_k_tuple_79;
static PyObject *__pyx_k_tuple_80;
static PyObject *__pyx_k_tuple_82;
static PyObject *__pyx_k_tuple_83;
static PyObject *__pyx_k_tuple_87;
static PyObject *__pyx_k_tuple_89;
static PyObject *__pyx_k_tuple_91;
static PyObject *__pyx_k_tuple_93;
static PyObject *__pyx_k_tuple_95;
static PyObject *__pyx_k_tuple_97;
static PyObject *__pyx_k_tuple_99;
static PyObject *__pyx_k_tuple_101;
static PyObject *__pyx_k_tuple_103;
static PyObject *__pyx_k_tuple_105;
static PyObject *__pyx_k_tuple_107;
static PyObject *__pyx_k_tuple_109;
static PyObject *__pyx_k_tuple_111;
static PyObject *__pyx_k_tuple_113;
static PyObject *__pyx_k_tuple_115;
static PyObject *__pyx_k_tuple_117;
static PyObject *__pyx_k_tuple_119;
static PyObject *__pyx_k_tuple_121;
static PyObject *__pyx_k_tuple_123;
static PyObject *__pyx_k_tuple_125;
static PyObject *__pyx_k_tuple_127;
static PyObject *__pyx_k_tuple_129;
static PyObject *__pyx_k_tuple_131;
static PyObject *__pyx_k_tuple_133;
static PyObject *__pyx_k_tuple_135;
static PyObject *__pyx_k_codeobj_84;
static PyObject *__pyx_k_codeobj_88;
static PyObject *__pyx_k_codeobj_90;
static PyObject *__pyx_k_codeobj_92;
static PyObject *__pyx_k_codeobj_94;
static PyObject *__pyx_k_codeobj_96;
static PyObject *__pyx_k_codeobj_98;
static PyObject *__pyx_k_codeobj_100;
static PyObject *__pyx_k_codeobj_102;
static PyObject *__pyx_k_codeobj_104;
static PyObject *__pyx_k_codeobj_106;
static PyObject *__pyx_k_codeobj_108;
static PyObject *__pyx_k_codeobj_110;
static PyObject *__pyx_k_codeobj_112;
static PyObject *__pyx_k_codeobj_114;
static PyObject *__pyx_k_codeobj_116;
static PyObject *__pyx_k_codeobj_118;
static PyObject *__pyx_k_codeobj_120;
static PyObject *__pyx_k_codeobj_122;
static PyObject *__pyx_k_codeobj_124;
static PyObject *__pyx_k_codeobj_126;
static PyObject *__pyx_k_codeobj_128;
static PyObject *__pyx_k_codeobj_130;
static PyObject *__pyx_k_codeobj_132;
static PyObject *__pyx_k_codeobj_134;
static PyObject *__pyx_k_codeobj_136;

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_1ang2pix_ring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_ang2pix_ring[] = "ang2pix_ring(nside, theta, phi, ipix=None)\nConverting theta(0 to pi), phi(0 to 2 pi) to pix number";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_1ang2pix_ring = {__Pyx_NAMESTR("ang2pix_ring"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_1ang2pix_ring, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_ang2pix_ring)};
static PyObject *__pyx_pw_7chealpy_6_ccode_1ang2pix_ring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_theta = 0;
  PyObject *__pyx_v_phi = 0;
  PyObject *__pyx_v_ipix = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__theta,&__pyx_n_s__phi,&__pyx_n_s__ipix,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ang2pix_ring (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[4] = {0,0,0,0};

    /* "chealpy/_ccode.pyx":40
 * 
 * 
 * def ang2pix_ring (nside,theta,phi, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 */
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__theta);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ang2pix_ring", 0, 3, 4, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__phi);
        if (likely(values[2])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ang2pix_ring", 0, 3, 4, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ang2pix_ring") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_theta = values[1];
    __pyx_v_phi = values[2];
    __pyx_v_ipix = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ang2pix_ring", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.ang2pix_ring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_ang2pix_ring(__pyx_self, __pyx_v_nside, __pyx_v_theta, __pyx_v_phi, __pyx_v_ipix);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_ang2pix_ring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi, PyObject *__pyx_v_ipix) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  double __pyx_v__theta;
  double __pyx_v__phi;
  long __pyx_v__ipix;
  long __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ang2pix_ring", 0);
  __Pyx_INCREF(__pyx_v_ipix);

  /* "chealpy/_ccode.pyx":42
 * def ang2pix_ring (nside,theta,phi, ipix = None):
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape             # <<<<<<<<<<<<<<
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')
 * 
 */
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_theta);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":43
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,theta,phi,ipix],
 */
  __pyx_t_3 = (__pyx_v_ipix == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__int)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_ipix);
    __pyx_v_ipix = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":45
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')
 * 
 *   iter = numpy.nditer([nside,theta,phi,ipix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(4); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_theta);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_5, 3, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));

  /* "chealpy/_ccode.pyx":46
 * 
 *   iter = numpy.nditer([nside,theta,phi,ipix],
 *        op_dtypes=['int','f8','f8','int'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_2 = PyList_New(4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_2, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 3, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":47
 *   iter = numpy.nditer([nside,theta,phi,ipix],
 *        op_dtypes=['int','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(4); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_9, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":48
 *        op_dtypes=['int','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_9 = PyList_New(3); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_9 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_iter = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":52
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef double _theta
 *   cdef double _phi
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":57
 *   cdef long _ipix
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":58
 *   cdef long _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":59
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<long * > citer.data[0])[0]
 *         _theta = (<double * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":60
 *     while size >0:
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _theta = (<double * > citer.data[1])[0]
 *         _phi = (<double * > citer.data[2])[0]
 */
            __pyx_v__nside = (((long *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":61
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 *         _theta = (<double * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _phi = (<double * > citer.data[2])[0]
 *         _ang2pix_ring ( _nside, _theta, _phi, &_ipix)
 */
            __pyx_v__theta = (((double *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":62
 *         _nside = (<long * > citer.data[0])[0]
 *         _theta = (<double * > citer.data[1])[0]
 *         _phi = (<double * > citer.data[2])[0]             # <<<<<<<<<<<<<<
 *         _ang2pix_ring ( _nside, _theta, _phi, &_ipix)
 *         (<long * > citer.data[3])[0] = _ipix
 */
            __pyx_v__phi = (((double *)(__pyx_v_citer.data[2]))[0]);

            /* "chealpy/_ccode.pyx":63
 *         _theta = (<double * > citer.data[1])[0]
 *         _phi = (<double * > citer.data[2])[0]
 *         _ang2pix_ring ( _nside, _theta, _phi, &_ipix)             # <<<<<<<<<<<<<<
 *         (<long * > citer.data[3])[0] = _ipix
 *         npyiter.advance(&citer)
 */
            ang2pix_ring(__pyx_v__nside, __pyx_v__theta, __pyx_v__phi, (&__pyx_v__ipix));

            /* "chealpy/_ccode.pyx":64
 *         _phi = (<double * > citer.data[2])[0]
 *         _ang2pix_ring ( _nside, _theta, _phi, &_ipix)
 *         (<long * > citer.data[3])[0] = _ipix             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((long *)(__pyx_v_citer.data[3]))[0]) = __pyx_v__ipix;

            /* "chealpy/_ccode.pyx":65
 *         _ang2pix_ring ( _nside, _theta, _phi, &_ipix)
 *         (<long * > citer.data[3])[0] = _ipix
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":66
 *         (<long * > citer.data[3])[0] = _ipix
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return ipix
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":67
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return ipix
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":57
 *   cdef long _ipix
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":68
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return ipix             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ipix);
  __pyx_r = __pyx_v_ipix;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("chealpy._ccode.ang2pix_ring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_ipix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_3ang2pix_nest(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_2ang2pix_nest[] = "ang2pix_nest(nside, theta, phi, ipix=None)\nConverting theta(0 to pi), phi(0 to 2 pi) to pix number";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_3ang2pix_nest = {__Pyx_NAMESTR("ang2pix_nest"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_3ang2pix_nest, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_2ang2pix_nest)};
static PyObject *__pyx_pw_7chealpy_6_ccode_3ang2pix_nest(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_theta = 0;
  PyObject *__pyx_v_phi = 0;
  PyObject *__pyx_v_ipix = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__theta,&__pyx_n_s__phi,&__pyx_n_s__ipix,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ang2pix_nest (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[4] = {0,0,0,0};

    /* "chealpy/_ccode.pyx":71
 * 
 * 
 * def ang2pix_nest (nside,theta,phi, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 */
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__theta);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ang2pix_nest", 0, 3, 4, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__phi);
        if (likely(values[2])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ang2pix_nest", 0, 3, 4, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ang2pix_nest") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_theta = values[1];
    __pyx_v_phi = values[2];
    __pyx_v_ipix = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ang2pix_nest", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.ang2pix_nest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_2ang2pix_nest(__pyx_self, __pyx_v_nside, __pyx_v_theta, __pyx_v_phi, __pyx_v_ipix);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_2ang2pix_nest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi, PyObject *__pyx_v_ipix) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  double __pyx_v__theta;
  double __pyx_v__phi;
  long __pyx_v__ipix;
  long __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ang2pix_nest", 0);
  __Pyx_INCREF(__pyx_v_ipix);

  /* "chealpy/_ccode.pyx":73
 * def ang2pix_nest (nside,theta,phi, ipix = None):
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape             # <<<<<<<<<<<<<<
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')
 * 
 */
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_theta);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":74
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,theta,phi,ipix],
 */
  __pyx_t_3 = (__pyx_v_ipix == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__int)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_ipix);
    __pyx_v_ipix = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":76
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')
 * 
 *   iter = numpy.nditer([nside,theta,phi,ipix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(4); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_theta);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_5, 3, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));

  /* "chealpy/_ccode.pyx":77
 * 
 *   iter = numpy.nditer([nside,theta,phi,ipix],
 *        op_dtypes=['int','f8','f8','int'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_2 = PyList_New(4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_2, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 3, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":78
 *   iter = numpy.nditer([nside,theta,phi,ipix],
 *        op_dtypes=['int','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(4); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_9, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":79
 *        op_dtypes=['int','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_9 = PyList_New(3); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_9 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_iter = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":83
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef double _theta
 *   cdef double _phi
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":88
 *   cdef long _ipix
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":89
 *   cdef long _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":90
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<long * > citer.data[0])[0]
 *         _theta = (<double * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":91
 *     while size >0:
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _theta = (<double * > citer.data[1])[0]
 *         _phi = (<double * > citer.data[2])[0]
 */
            __pyx_v__nside = (((long *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":92
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 *         _theta = (<double * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _phi = (<double * > citer.data[2])[0]
 *         _ang2pix_nest ( _nside, _theta, _phi, &_ipix)
 */
            __pyx_v__theta = (((double *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":93
 *         _nside = (<long * > citer.data[0])[0]
 *         _theta = (<double * > citer.data[1])[0]
 *         _phi = (<double * > citer.data[2])[0]             # <<<<<<<<<<<<<<
 *         _ang2pix_nest ( _nside, _theta, _phi, &_ipix)
 *         (<long * > citer.data[3])[0] = _ipix
 */
            __pyx_v__phi = (((double *)(__pyx_v_citer.data[2]))[0]);

            /* "chealpy/_ccode.pyx":94
 *         _theta = (<double * > citer.data[1])[0]
 *         _phi = (<double * > citer.data[2])[0]
 *         _ang2pix_nest ( _nside, _theta, _phi, &_ipix)             # <<<<<<<<<<<<<<
 *         (<long * > citer.data[3])[0] = _ipix
 *         npyiter.advance(&citer)
 */
            ang2pix_nest(__pyx_v__nside, __pyx_v__theta, __pyx_v__phi, (&__pyx_v__ipix));

            /* "chealpy/_ccode.pyx":95
 *         _phi = (<double * > citer.data[2])[0]
 *         _ang2pix_nest ( _nside, _theta, _phi, &_ipix)
 *         (<long * > citer.data[3])[0] = _ipix             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((long *)(__pyx_v_citer.data[3]))[0]) = __pyx_v__ipix;

            /* "chealpy/_ccode.pyx":96
 *         _ang2pix_nest ( _nside, _theta, _phi, &_ipix)
 *         (<long * > citer.data[3])[0] = _ipix
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":97
 *         (<long * > citer.data[3])[0] = _ipix
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return ipix
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":98
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return ipix
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":88
 *   cdef long _ipix
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":99
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return ipix             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ipix);
  __pyx_r = __pyx_v_ipix;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("chealpy._ccode.ang2pix_nest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_ipix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_5ang2pix_ring64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_4ang2pix_ring64[] = "ang2pix_ring64(nside, theta, phi, ipix=None)\nConverting theta(0 to pi), phi(0 to 2 pi) to pix number";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_5ang2pix_ring64 = {__Pyx_NAMESTR("ang2pix_ring64"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_5ang2pix_ring64, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_4ang2pix_ring64)};
static PyObject *__pyx_pw_7chealpy_6_ccode_5ang2pix_ring64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_theta = 0;
  PyObject *__pyx_v_phi = 0;
  PyObject *__pyx_v_ipix = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__theta,&__pyx_n_s__phi,&__pyx_n_s__ipix,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ang2pix_ring64 (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[4] = {0,0,0,0};

    /* "chealpy/_ccode.pyx":102
 * 
 * 
 * def ang2pix_ring64 (nside,theta,phi, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 */
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__theta);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ang2pix_ring64", 0, 3, 4, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__phi);
        if (likely(values[2])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ang2pix_ring64", 0, 3, 4, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ang2pix_ring64") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_theta = values[1];
    __pyx_v_phi = values[2];
    __pyx_v_ipix = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ang2pix_ring64", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.ang2pix_ring64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_4ang2pix_ring64(__pyx_self, __pyx_v_nside, __pyx_v_theta, __pyx_v_phi, __pyx_v_ipix);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_4ang2pix_ring64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi, PyObject *__pyx_v_ipix) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  double __pyx_v__theta;
  double __pyx_v__phi;
  int64_t __pyx_v__ipix;
  int64_t __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ang2pix_ring64", 0);
  __Pyx_INCREF(__pyx_v_ipix);

  /* "chealpy/_ccode.pyx":104
 * def ang2pix_ring64 (nside,theta,phi, ipix = None):
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape             # <<<<<<<<<<<<<<
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')
 * 
 */
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_theta);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":105
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,theta,phi,ipix],
 */
  __pyx_t_3 = (__pyx_v_ipix == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__i8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_ipix);
    __pyx_v_ipix = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":107
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')
 * 
 *   iter = numpy.nditer([nside,theta,phi,ipix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(4); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_theta);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_5, 3, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));

  /* "chealpy/_ccode.pyx":108
 * 
 *   iter = numpy.nditer([nside,theta,phi,ipix],
 *        op_dtypes=['i8','f8','f8','i8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_2 = PyList_New(4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_2, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 3, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":109
 *   iter = numpy.nditer([nside,theta,phi,ipix],
 *        op_dtypes=['i8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(4); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_9, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":110
 *        op_dtypes=['i8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_9 = PyList_New(3); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_9 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_iter = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":114
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef double _theta
 *   cdef double _phi
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":119
 *   cdef int64_t _ipix
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":120
 *   cdef int64_t _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":121
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _theta = (<double * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":122
 *     while size >0:
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _theta = (<double * > citer.data[1])[0]
 *         _phi = (<double * > citer.data[2])[0]
 */
            __pyx_v__nside = (((int64_t *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":123
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _theta = (<double * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _phi = (<double * > citer.data[2])[0]
 *         _ang2pix_ring64 ( _nside, _theta, _phi, &_ipix)
 */
            __pyx_v__theta = (((double *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":124
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _theta = (<double * > citer.data[1])[0]
 *         _phi = (<double * > citer.data[2])[0]             # <<<<<<<<<<<<<<
 *         _ang2pix_ring64 ( _nside, _theta, _phi, &_ipix)
 *         (<int64_t * > citer.data[3])[0] = _ipix
 */
            __pyx_v__phi = (((double *)(__pyx_v_citer.data[2]))[0]);

            /* "chealpy/_ccode.pyx":125
 *         _theta = (<double * > citer.data[1])[0]
 *         _phi = (<double * > citer.data[2])[0]
 *         _ang2pix_ring64 ( _nside, _theta, _phi, &_ipix)             # <<<<<<<<<<<<<<
 *         (<int64_t * > citer.data[3])[0] = _ipix
 *         npyiter.advance(&citer)
 */
            ang2pix_ring64(__pyx_v__nside, __pyx_v__theta, __pyx_v__phi, (&__pyx_v__ipix));

            /* "chealpy/_ccode.pyx":126
 *         _phi = (<double * > citer.data[2])[0]
 *         _ang2pix_ring64 ( _nside, _theta, _phi, &_ipix)
 *         (<int64_t * > citer.data[3])[0] = _ipix             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((int64_t *)(__pyx_v_citer.data[3]))[0]) = __pyx_v__ipix;

            /* "chealpy/_ccode.pyx":127
 *         _ang2pix_ring64 ( _nside, _theta, _phi, &_ipix)
 *         (<int64_t * > citer.data[3])[0] = _ipix
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":128
 *         (<int64_t * > citer.data[3])[0] = _ipix
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return ipix
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":129
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return ipix
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":119
 *   cdef int64_t _ipix
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":130
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return ipix             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ipix);
  __pyx_r = __pyx_v_ipix;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("chealpy._ccode.ang2pix_ring64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_ipix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_7ang2pix_nest64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_6ang2pix_nest64[] = "ang2pix_nest64(nside, theta, phi, ipix=None)\nConverting theta(0 to pi), phi(0 to 2 pi) to pix number";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_7ang2pix_nest64 = {__Pyx_NAMESTR("ang2pix_nest64"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_7ang2pix_nest64, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_6ang2pix_nest64)};
static PyObject *__pyx_pw_7chealpy_6_ccode_7ang2pix_nest64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_theta = 0;
  PyObject *__pyx_v_phi = 0;
  PyObject *__pyx_v_ipix = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__theta,&__pyx_n_s__phi,&__pyx_n_s__ipix,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ang2pix_nest64 (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[4] = {0,0,0,0};

    /* "chealpy/_ccode.pyx":133
 * 
 * 
 * def ang2pix_nest64 (nside,theta,phi, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 */
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__theta);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ang2pix_nest64", 0, 3, 4, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__phi);
        if (likely(values[2])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ang2pix_nest64", 0, 3, 4, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ang2pix_nest64") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_theta = values[1];
    __pyx_v_phi = values[2];
    __pyx_v_ipix = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ang2pix_nest64", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.ang2pix_nest64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_6ang2pix_nest64(__pyx_self, __pyx_v_nside, __pyx_v_theta, __pyx_v_phi, __pyx_v_ipix);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_6ang2pix_nest64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi, PyObject *__pyx_v_ipix) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  double __pyx_v__theta;
  double __pyx_v__phi;
  int64_t __pyx_v__ipix;
  int64_t __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ang2pix_nest64", 0);
  __Pyx_INCREF(__pyx_v_ipix);

  /* "chealpy/_ccode.pyx":135
 * def ang2pix_nest64 (nside,theta,phi, ipix = None):
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape             # <<<<<<<<<<<<<<
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')
 * 
 */
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_theta);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":136
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,theta,phi,ipix],
 */
  __pyx_t_3 = (__pyx_v_ipix == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__i8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_ipix);
    __pyx_v_ipix = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":138
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')
 * 
 *   iter = numpy.nditer([nside,theta,phi,ipix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(4); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_theta);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_5, 3, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));

  /* "chealpy/_ccode.pyx":139
 * 
 *   iter = numpy.nditer([nside,theta,phi,ipix],
 *        op_dtypes=['i8','f8','f8','i8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_2 = PyList_New(4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_2, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 3, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":140
 *   iter = numpy.nditer([nside,theta,phi,ipix],
 *        op_dtypes=['i8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(4); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_9, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":141
 *        op_dtypes=['i8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_9 = PyList_New(3); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_9 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_iter = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":145
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef double _theta
 *   cdef double _phi
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":150
 *   cdef int64_t _ipix
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":151
 *   cdef int64_t _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":152
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _theta = (<double * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":153
 *     while size >0:
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _theta = (<double * > citer.data[1])[0]
 *         _phi = (<double * > citer.data[2])[0]
 */
            __pyx_v__nside = (((int64_t *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":154
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _theta = (<double * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _phi = (<double * > citer.data[2])[0]
 *         _ang2pix_nest64 ( _nside, _theta, _phi, &_ipix)
 */
            __pyx_v__theta = (((double *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":155
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _theta = (<double * > citer.data[1])[0]
 *         _phi = (<double * > citer.data[2])[0]             # <<<<<<<<<<<<<<
 *         _ang2pix_nest64 ( _nside, _theta, _phi, &_ipix)
 *         (<int64_t * > citer.data[3])[0] = _ipix
 */
            __pyx_v__phi = (((double *)(__pyx_v_citer.data[2]))[0]);

            /* "chealpy/_ccode.pyx":156
 *         _theta = (<double * > citer.data[1])[0]
 *         _phi = (<double * > citer.data[2])[0]
 *         _ang2pix_nest64 ( _nside, _theta, _phi, &_ipix)             # <<<<<<<<<<<<<<
 *         (<int64_t * > citer.data[3])[0] = _ipix
 *         npyiter.advance(&citer)
 */
            ang2pix_nest64(__pyx_v__nside, __pyx_v__theta, __pyx_v__phi, (&__pyx_v__ipix));

            /* "chealpy/_ccode.pyx":157
 *         _phi = (<double * > citer.data[2])[0]
 *         _ang2pix_nest64 ( _nside, _theta, _phi, &_ipix)
 *         (<int64_t * > citer.data[3])[0] = _ipix             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((int64_t *)(__pyx_v_citer.data[3]))[0]) = __pyx_v__ipix;

            /* "chealpy/_ccode.pyx":158
 *         _ang2pix_nest64 ( _nside, _theta, _phi, &_ipix)
 *         (<int64_t * > citer.data[3])[0] = _ipix
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":159
 *         (<int64_t * > citer.data[3])[0] = _ipix
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return ipix
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":160
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return ipix
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":150
 *   cdef int64_t _ipix
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":161
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return ipix             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ipix);
  __pyx_r = __pyx_v_ipix;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("chealpy._ccode.ang2pix_nest64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_ipix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_9pix2ang_ring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_8pix2ang_ring[] = "pix2ang_ring(nside, ipix, theta=None, phi=None)\nConverting pix number to theta(0 to pi), phi(0 to 2 pi)";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_9pix2ang_ring = {__Pyx_NAMESTR("pix2ang_ring"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_9pix2ang_ring, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_8pix2ang_ring)};
static PyObject *__pyx_pw_7chealpy_6_ccode_9pix2ang_ring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_ipix = 0;
  PyObject *__pyx_v_theta = 0;
  PyObject *__pyx_v_phi = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__ipix,&__pyx_n_s__theta,&__pyx_n_s__phi,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pix2ang_ring (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[4] = {0,0,0,0};

    /* "chealpy/_ccode.pyx":164
 * 
 * 
 * def pix2ang_ring (nside,ipix, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pix2ang_ring", 0, 2, 4, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__theta);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__phi);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pix2ang_ring") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_ipix = values[1];
    __pyx_v_theta = values[2];
    __pyx_v_phi = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pix2ang_ring", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.pix2ang_ring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_8pix2ang_ring(__pyx_self, __pyx_v_nside, __pyx_v_ipix, __pyx_v_theta, __pyx_v_phi);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_8pix2ang_ring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  double __pyx_v__theta;
  double __pyx_v__phi;
  long __pyx_v__ipix;
  long __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pix2ang_ring", 0);
  __Pyx_INCREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);

  /* "chealpy/_ccode.pyx":166
 * def pix2ang_ring (nside,ipix, theta = None,phi = None):
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape             # <<<<<<<<<<<<<<
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":167
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')             # <<<<<<<<<<<<<<
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 * 
 */
  __pyx_t_3 = (__pyx_v_theta == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__f8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_theta);
    __pyx_v_theta = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":168
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipix,theta,phi],
 */
  __pyx_t_3 = (__pyx_v_phi == Py_None);
  if (__pyx_t_3) {
    __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__empty); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__f8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_2 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_5), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_v_phi);
    __pyx_v_phi = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "chealpy/_ccode.pyx":170
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 * 
 *   iter = numpy.nditer([nside,ipix,theta,phi],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','int','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],
 */
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__nditer); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __Pyx_INCREF(__pyx_v_theta);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyList_SET_ITEM(__pyx_t_2, 3, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __pyx_t_2 = 0;
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));

  /* "chealpy/_ccode.pyx":171
 * 
 *   iter = numpy.nditer([nside,ipix,theta,phi],
 *        op_dtypes=['int','int','f8','f8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_4 = PyList_New(4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 171; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_4, 1, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":172
 *   iter = numpy.nditer([nside,ipix,theta,phi],
 *        op_dtypes=['int','int','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(4); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_t_4));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_9, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  __pyx_t_4 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":173
 *        op_dtypes=['int','int','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_9 = PyList_New(3); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_9 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_5), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_v_iter = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":177
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef double _theta
 *   cdef double _phi
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":182
 *   cdef long _ipix
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":183
 *   cdef long _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":184
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipix = (<long * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":185
 *     while size >0:
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _ipix = (<long * > citer.data[1])[0]
 *         _pix2ang_ring ( _nside, _ipix, &_theta, &_phi)
 */
            __pyx_v__nside = (((long *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":186
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipix = (<long * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _pix2ang_ring ( _nside, _ipix, &_theta, &_phi)
 *         (<double * > citer.data[2])[0] = _theta
 */
            __pyx_v__ipix = (((long *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":187
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipix = (<long * > citer.data[1])[0]
 *         _pix2ang_ring ( _nside, _ipix, &_theta, &_phi)             # <<<<<<<<<<<<<<
 *         (<double * > citer.data[2])[0] = _theta
 *         (<double * > citer.data[3])[0] = _phi
 */
            pix2ang_ring(__pyx_v__nside, __pyx_v__ipix, (&__pyx_v__theta), (&__pyx_v__phi));

            /* "chealpy/_ccode.pyx":188
 *         _ipix = (<long * > citer.data[1])[0]
 *         _pix2ang_ring ( _nside, _ipix, &_theta, &_phi)
 *         (<double * > citer.data[2])[0] = _theta             # <<<<<<<<<<<<<<
 *         (<double * > citer.data[3])[0] = _phi
 *         npyiter.advance(&citer)
 */
            (((double *)(__pyx_v_citer.data[2]))[0]) = __pyx_v__theta;

            /* "chealpy/_ccode.pyx":189
 *         _pix2ang_ring ( _nside, _ipix, &_theta, &_phi)
 *         (<double * > citer.data[2])[0] = _theta
 *         (<double * > citer.data[3])[0] = _phi             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((double *)(__pyx_v_citer.data[3]))[0]) = __pyx_v__phi;

            /* "chealpy/_ccode.pyx":190
 *         (<double * > citer.data[2])[0] = _theta
 *         (<double * > citer.data[3])[0] = _phi
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":191
 *         (<double * > citer.data[3])[0] = _phi
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return theta,phi
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":192
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return theta,phi
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":182
 *   cdef long _ipix
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":193
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return theta,phi             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 193; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_v_theta);
  PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_r = ((PyObject *)__pyx_t_9);
  __pyx_t_9 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("chealpy._ccode.pix2ang_ring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_theta);
  __Pyx_XDECREF(__pyx_v_phi);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_11pix2ang_nest(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_10pix2ang_nest[] = "pix2ang_nest(nside, ipix, theta=None, phi=None)\nConverting pix number to theta(0 to pi), phi(0 to 2 pi)";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_11pix2ang_nest = {__Pyx_NAMESTR("pix2ang_nest"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_11pix2ang_nest, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_10pix2ang_nest)};
static PyObject *__pyx_pw_7chealpy_6_ccode_11pix2ang_nest(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_ipix = 0;
  PyObject *__pyx_v_theta = 0;
  PyObject *__pyx_v_phi = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__ipix,&__pyx_n_s__theta,&__pyx_n_s__phi,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pix2ang_nest (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[4] = {0,0,0,0};

    /* "chealpy/_ccode.pyx":196
 * 
 * 
 * def pix2ang_nest (nside,ipix, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pix2ang_nest", 0, 2, 4, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__theta);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__phi);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pix2ang_nest") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_ipix = values[1];
    __pyx_v_theta = values[2];
    __pyx_v_phi = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pix2ang_nest", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.pix2ang_nest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_10pix2ang_nest(__pyx_self, __pyx_v_nside, __pyx_v_ipix, __pyx_v_theta, __pyx_v_phi);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_10pix2ang_nest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  double __pyx_v__theta;
  double __pyx_v__phi;
  long __pyx_v__ipix;
  long __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pix2ang_nest", 0);
  __Pyx_INCREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);

  /* "chealpy/_ccode.pyx":198
 * def pix2ang_nest (nside,ipix, theta = None,phi = None):
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape             # <<<<<<<<<<<<<<
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":199
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')             # <<<<<<<<<<<<<<
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 * 
 */
  __pyx_t_3 = (__pyx_v_theta == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__f8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_theta);
    __pyx_v_theta = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":200
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipix,theta,phi],
 */
  __pyx_t_3 = (__pyx_v_phi == Py_None);
  if (__pyx_t_3) {
    __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 200; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__empty); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 200; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 200; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 200; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__f8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 200; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_2 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_5), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 200; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_v_phi);
    __pyx_v_phi = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "chealpy/_ccode.pyx":202
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 * 
 *   iter = numpy.nditer([nside,ipix,theta,phi],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','int','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],
 */
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__nditer); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __Pyx_INCREF(__pyx_v_theta);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyList_SET_ITEM(__pyx_t_2, 3, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __pyx_t_2 = 0;
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));

  /* "chealpy/_ccode.pyx":203
 * 
 *   iter = numpy.nditer([nside,ipix,theta,phi],
 *        op_dtypes=['int','int','f8','f8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_4 = PyList_New(4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 203; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_4, 1, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":204
 *   iter = numpy.nditer([nside,ipix,theta,phi],
 *        op_dtypes=['int','int','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(4); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_t_4));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_9, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  __pyx_t_4 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":205
 *        op_dtypes=['int','int','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_9 = PyList_New(3); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_9 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_5), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_v_iter = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":209
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef double _theta
 *   cdef double _phi
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":214
 *   cdef long _ipix
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":215
 *   cdef long _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":216
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipix = (<long * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":217
 *     while size >0:
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _ipix = (<long * > citer.data[1])[0]
 *         _pix2ang_nest ( _nside, _ipix, &_theta, &_phi)
 */
            __pyx_v__nside = (((long *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":218
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipix = (<long * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _pix2ang_nest ( _nside, _ipix, &_theta, &_phi)
 *         (<double * > citer.data[2])[0] = _theta
 */
            __pyx_v__ipix = (((long *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":219
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipix = (<long * > citer.data[1])[0]
 *         _pix2ang_nest ( _nside, _ipix, &_theta, &_phi)             # <<<<<<<<<<<<<<
 *         (<double * > citer.data[2])[0] = _theta
 *         (<double * > citer.data[3])[0] = _phi
 */
            pix2ang_nest(__pyx_v__nside, __pyx_v__ipix, (&__pyx_v__theta), (&__pyx_v__phi));

            /* "chealpy/_ccode.pyx":220
 *         _ipix = (<long * > citer.data[1])[0]
 *         _pix2ang_nest ( _nside, _ipix, &_theta, &_phi)
 *         (<double * > citer.data[2])[0] = _theta             # <<<<<<<<<<<<<<
 *         (<double * > citer.data[3])[0] = _phi
 *         npyiter.advance(&citer)
 */
            (((double *)(__pyx_v_citer.data[2]))[0]) = __pyx_v__theta;

            /* "chealpy/_ccode.pyx":221
 *         _pix2ang_nest ( _nside, _ipix, &_theta, &_phi)
 *         (<double * > citer.data[2])[0] = _theta
 *         (<double * > citer.data[3])[0] = _phi             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((double *)(__pyx_v_citer.data[3]))[0]) = __pyx_v__phi;

            /* "chealpy/_ccode.pyx":222
 *         (<double * > citer.data[2])[0] = _theta
 *         (<double * > citer.data[3])[0] = _phi
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":223
 *         (<double * > citer.data[3])[0] = _phi
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return theta,phi
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":224
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return theta,phi
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":214
 *   cdef long _ipix
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":225
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return theta,phi             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 225; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_v_theta);
  PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_r = ((PyObject *)__pyx_t_9);
  __pyx_t_9 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("chealpy._ccode.pix2ang_nest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_theta);
  __Pyx_XDECREF(__pyx_v_phi);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_13pix2ang_ring64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_12pix2ang_ring64[] = "pix2ang_ring64(nside, ipix, theta=None, phi=None)\nConverting pix number to theta(0 to pi), phi(0 to 2 pi)";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_13pix2ang_ring64 = {__Pyx_NAMESTR("pix2ang_ring64"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_13pix2ang_ring64, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_12pix2ang_ring64)};
static PyObject *__pyx_pw_7chealpy_6_ccode_13pix2ang_ring64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_ipix = 0;
  PyObject *__pyx_v_theta = 0;
  PyObject *__pyx_v_phi = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__ipix,&__pyx_n_s__theta,&__pyx_n_s__phi,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pix2ang_ring64 (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[4] = {0,0,0,0};

    /* "chealpy/_ccode.pyx":228
 * 
 * 
 * def pix2ang_ring64 (nside,ipix, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pix2ang_ring64", 0, 2, 4, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 228; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__theta);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__phi);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pix2ang_ring64") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 228; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_ipix = values[1];
    __pyx_v_theta = values[2];
    __pyx_v_phi = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pix2ang_ring64", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 228; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.pix2ang_ring64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_12pix2ang_ring64(__pyx_self, __pyx_v_nside, __pyx_v_ipix, __pyx_v_theta, __pyx_v_phi);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_12pix2ang_ring64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  double __pyx_v__theta;
  double __pyx_v__phi;
  int64_t __pyx_v__ipix;
  int64_t __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pix2ang_ring64", 0);
  __Pyx_INCREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);

  /* "chealpy/_ccode.pyx":230
 * def pix2ang_ring64 (nside,ipix, theta = None,phi = None):
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape             # <<<<<<<<<<<<<<
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 230; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 230; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 230; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":231
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')             # <<<<<<<<<<<<<<
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 * 
 */
  __pyx_t_3 = (__pyx_v_theta == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 231; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 231; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 231; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 231; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__f8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 231; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 231; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_theta);
    __pyx_v_theta = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":232
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipix,theta,phi],
 */
  __pyx_t_3 = (__pyx_v_phi == Py_None);
  if (__pyx_t_3) {
    __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__empty); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__f8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_2 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_5), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_v_phi);
    __pyx_v_phi = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "chealpy/_ccode.pyx":234
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 * 
 *   iter = numpy.nditer([nside,ipix,theta,phi],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','i8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],
 */
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__nditer); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __Pyx_INCREF(__pyx_v_theta);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyList_SET_ITEM(__pyx_t_2, 3, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __pyx_t_2 = 0;
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));

  /* "chealpy/_ccode.pyx":235
 * 
 *   iter = numpy.nditer([nside,ipix,theta,phi],
 *        op_dtypes=['i8','i8','f8','f8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_4 = PyList_New(4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_4, 1, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":236
 *   iter = numpy.nditer([nside,ipix,theta,phi],
 *        op_dtypes=['i8','i8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 236; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 236; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 236; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 236; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(4); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 236; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_t_4));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_9, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  __pyx_t_4 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":237
 *        op_dtypes=['i8','i8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_9 = PyList_New(3); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 237; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_9 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_5), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_v_iter = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":241
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef double _theta
 *   cdef double _phi
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":246
 *   cdef int64_t _ipix
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":247
 *   cdef int64_t _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":248
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipix = (<int64_t * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":249
 *     while size >0:
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _ipix = (<int64_t * > citer.data[1])[0]
 *         _pix2ang_ring64 ( _nside, _ipix, &_theta, &_phi)
 */
            __pyx_v__nside = (((int64_t *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":250
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipix = (<int64_t * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _pix2ang_ring64 ( _nside, _ipix, &_theta, &_phi)
 *         (<double * > citer.data[2])[0] = _theta
 */
            __pyx_v__ipix = (((int64_t *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":251
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipix = (<int64_t * > citer.data[1])[0]
 *         _pix2ang_ring64 ( _nside, _ipix, &_theta, &_phi)             # <<<<<<<<<<<<<<
 *         (<double * > citer.data[2])[0] = _theta
 *         (<double * > citer.data[3])[0] = _phi
 */
            pix2ang_ring64(__pyx_v__nside, __pyx_v__ipix, (&__pyx_v__theta), (&__pyx_v__phi));

            /* "chealpy/_ccode.pyx":252
 *         _ipix = (<int64_t * > citer.data[1])[0]
 *         _pix2ang_ring64 ( _nside, _ipix, &_theta, &_phi)
 *         (<double * > citer.data[2])[0] = _theta             # <<<<<<<<<<<<<<
 *         (<double * > citer.data[3])[0] = _phi
 *         npyiter.advance(&citer)
 */
            (((double *)(__pyx_v_citer.data[2]))[0]) = __pyx_v__theta;

            /* "chealpy/_ccode.pyx":253
 *         _pix2ang_ring64 ( _nside, _ipix, &_theta, &_phi)
 *         (<double * > citer.data[2])[0] = _theta
 *         (<double * > citer.data[3])[0] = _phi             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((double *)(__pyx_v_citer.data[3]))[0]) = __pyx_v__phi;

            /* "chealpy/_ccode.pyx":254
 *         (<double * > citer.data[2])[0] = _theta
 *         (<double * > citer.data[3])[0] = _phi
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":255
 *         (<double * > citer.data[3])[0] = _phi
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return theta,phi
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":256
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return theta,phi
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":246
 *   cdef int64_t _ipix
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":257
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return theta,phi             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 257; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_v_theta);
  PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_r = ((PyObject *)__pyx_t_9);
  __pyx_t_9 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("chealpy._ccode.pix2ang_ring64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_theta);
  __Pyx_XDECREF(__pyx_v_phi);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_15pix2ang_nest64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_14pix2ang_nest64[] = "pix2ang_nest64(nside, ipix, theta=None, phi=None)\nConverting pix number to theta(0 to pi), phi(0 to 2 pi)";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_15pix2ang_nest64 = {__Pyx_NAMESTR("pix2ang_nest64"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_15pix2ang_nest64, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_14pix2ang_nest64)};
static PyObject *__pyx_pw_7chealpy_6_ccode_15pix2ang_nest64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_ipix = 0;
  PyObject *__pyx_v_theta = 0;
  PyObject *__pyx_v_phi = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__ipix,&__pyx_n_s__theta,&__pyx_n_s__phi,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pix2ang_nest64 (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[4] = {0,0,0,0};

    /* "chealpy/_ccode.pyx":260
 * 
 * 
 * def pix2ang_nest64 (nside,ipix, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pix2ang_nest64", 0, 2, 4, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__theta);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__phi);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pix2ang_nest64") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_ipix = values[1];
    __pyx_v_theta = values[2];
    __pyx_v_phi = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pix2ang_nest64", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.pix2ang_nest64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_14pix2ang_nest64(__pyx_self, __pyx_v_nside, __pyx_v_ipix, __pyx_v_theta, __pyx_v_phi);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_14pix2ang_nest64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  double __pyx_v__theta;
  double __pyx_v__phi;
  int64_t __pyx_v__ipix;
  int64_t __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pix2ang_nest64", 0);
  __Pyx_INCREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);

  /* "chealpy/_ccode.pyx":262
 * def pix2ang_nest64 (nside,ipix, theta = None,phi = None):
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape             # <<<<<<<<<<<<<<
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":263
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')             # <<<<<<<<<<<<<<
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 * 
 */
  __pyx_t_3 = (__pyx_v_theta == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__f8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_theta);
    __pyx_v_theta = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":264
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipix,theta,phi],
 */
  __pyx_t_3 = (__pyx_v_phi == Py_None);
  if (__pyx_t_3) {
    __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__empty); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__f8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_2 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_5), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_v_phi);
    __pyx_v_phi = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "chealpy/_ccode.pyx":266
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 * 
 *   iter = numpy.nditer([nside,ipix,theta,phi],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','i8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],
 */
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__nditer); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __Pyx_INCREF(__pyx_v_theta);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyList_SET_ITEM(__pyx_t_2, 3, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __pyx_t_2 = 0;
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));

  /* "chealpy/_ccode.pyx":267
 * 
 *   iter = numpy.nditer([nside,ipix,theta,phi],
 *        op_dtypes=['i8','i8','f8','f8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_4 = PyList_New(4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 267; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_4, 1, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":268
 *   iter = numpy.nditer([nside,ipix,theta,phi],
 *        op_dtypes=['i8','i8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(4); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_t_4));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_9, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  __pyx_t_4 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":269
 *        op_dtypes=['i8','i8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_9 = PyList_New(3); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 269; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_9, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_9, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_9)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_9 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_5), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_v_iter = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "chealpy/_ccode.pyx":273
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef double _theta
 *   cdef double _phi
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":278
 *   cdef int64_t _ipix
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":279
 *   cdef int64_t _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":280
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipix = (<int64_t * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":281
 *     while size >0:
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _ipix = (<int64_t * > citer.data[1])[0]
 *         _pix2ang_nest64 ( _nside, _ipix, &_theta, &_phi)
 */
            __pyx_v__nside = (((int64_t *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":282
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipix = (<int64_t * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _pix2ang_nest64 ( _nside, _ipix, &_theta, &_phi)
 *         (<double * > citer.data[2])[0] = _theta
 */
            __pyx_v__ipix = (((int64_t *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":283
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipix = (<int64_t * > citer.data[1])[0]
 *         _pix2ang_nest64 ( _nside, _ipix, &_theta, &_phi)             # <<<<<<<<<<<<<<
 *         (<double * > citer.data[2])[0] = _theta
 *         (<double * > citer.data[3])[0] = _phi
 */
            pix2ang_nest64(__pyx_v__nside, __pyx_v__ipix, (&__pyx_v__theta), (&__pyx_v__phi));

            /* "chealpy/_ccode.pyx":284
 *         _ipix = (<int64_t * > citer.data[1])[0]
 *         _pix2ang_nest64 ( _nside, _ipix, &_theta, &_phi)
 *         (<double * > citer.data[2])[0] = _theta             # <<<<<<<<<<<<<<
 *         (<double * > citer.data[3])[0] = _phi
 *         npyiter.advance(&citer)
 */
            (((double *)(__pyx_v_citer.data[2]))[0]) = __pyx_v__theta;

            /* "chealpy/_ccode.pyx":285
 *         _pix2ang_nest64 ( _nside, _ipix, &_theta, &_phi)
 *         (<double * > citer.data[2])[0] = _theta
 *         (<double * > citer.data[3])[0] = _phi             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((double *)(__pyx_v_citer.data[3]))[0]) = __pyx_v__phi;

            /* "chealpy/_ccode.pyx":286
 *         (<double * > citer.data[2])[0] = _theta
 *         (<double * > citer.data[3])[0] = _phi
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":287
 *         (<double * > citer.data[3])[0] = _phi
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return theta,phi
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":288
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return theta,phi
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":278
 *   cdef int64_t _ipix
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":289
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return theta,phi             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 289; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_v_theta);
  PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_r = ((PyObject *)__pyx_t_9);
  __pyx_t_9 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("chealpy._ccode.pix2ang_nest64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_theta);
  __Pyx_XDECREF(__pyx_v_phi);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_17vec2pix_ring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_16vec2pix_ring[] = "vec2pix_ring(nside, vec, ipix=None)\nConverting 3 vectors (..., 3) to pix number";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_17vec2pix_ring = {__Pyx_NAMESTR("vec2pix_ring"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_17vec2pix_ring, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_16vec2pix_ring)};
static PyObject *__pyx_pw_7chealpy_6_ccode_17vec2pix_ring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_vec = 0;
  PyObject *__pyx_v_ipix = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__vec,&__pyx_n_s__ipix,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vec2pix_ring (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":292
 * 
 * 
 * def vec2pix_ring (nside,vec, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__vec);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("vec2pix_ring", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "vec2pix_ring") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_vec = values[1];
    __pyx_v_ipix = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("vec2pix_ring", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.vec2pix_ring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_16vec2pix_ring(__pyx_self, __pyx_v_nside, __pyx_v_vec, __pyx_v_ipix);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_16vec2pix_ring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_vec, PyObject *__pyx_v_ipix) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  long __pyx_v__ipix;
  PyArrayObject *__pyx_v_vec_a = 0;
  double *__pyx_v__vec;
  long __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vec2pix_ring", 0);
  __Pyx_INCREF(__pyx_v_ipix);

  /* "chealpy/_ccode.pyx":294
 * def vec2pix_ring (nside,vec, ipix = None):
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape             # <<<<<<<<<<<<<<
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')
 * 
 */
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_1)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_2)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_3)); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(5); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__shape); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_shape = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":295
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],
 */
  __pyx_t_5 = (__pyx_v_ipix == Py_None);
  if (__pyx_t_5) {
    __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 295; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__empty); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 295; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 295; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 295; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__int)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 295; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_4), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 295; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_v_ipix);
    __pyx_v_ipix = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":297
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','f8','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__nditer); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_4)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_5)); if (!__pyx_t_4) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_6)); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyList_New(5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_6, 3, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_6, 4, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_1 = 0;
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_6 = 0;
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_6));

  /* "chealpy/_ccode.pyx":298
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],
 *        op_dtypes=['int','f8','f8','f8','int'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_4 = PyList_New(5); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 298; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 1, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_4, 4, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":299
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],
 *        op_dtypes=['int','f8','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_10 = PyList_New(5); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_t_4));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_10, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  PyList_SET_ITEM(__pyx_t_10, 4, ((PyObject *)__pyx_t_9));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_9));
  __pyx_t_4 = 0;
  __pyx_t_1 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":300
 *        op_dtypes=['int','f8','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 300; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_10 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_3), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_iter = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":304
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":306
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 */
  __pyx_t_10 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_6 = PyObject_GetAttr(__pyx_t_10, __pyx_n_s__empty); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_10));
  if (PyDict_SetItem(__pyx_t_10, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_k_tuple_7), ((PyObject *)__pyx_t_10)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_vec_a = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "chealpy/_ccode.pyx":307
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data             # <<<<<<<<<<<<<<
 *   cdef long _nside
 *   with nogil:
 */
  __pyx_v__vec = ((double *)__pyx_v_vec_a->data);

  /* "chealpy/_ccode.pyx":309
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":310
 *   cdef long _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_5 = (__pyx_v_size > 0);
          if (!__pyx_t_5) break;

          /* "chealpy/_ccode.pyx":311
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<long * > citer.data[0])[0]
 *         _vec[0] = (<double *> citer.data[1])[0]
 */
          while (1) {
            __pyx_t_5 = (__pyx_v_size > 0);
            if (!__pyx_t_5) break;

            /* "chealpy/_ccode.pyx":312
 *     while size >0:
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _vec[0] = (<double *> citer.data[1])[0]
 *         _vec[1] = (<double *> citer.data[2])[0]
 */
            __pyx_v__nside = (((long *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":313
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 *         _vec[0] = (<double *> citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _vec[1] = (<double *> citer.data[2])[0]
 *         _vec[2] = (<double *> citer.data[3])[0]
 */
            (__pyx_v__vec[0]) = (((double *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":314
 *         _nside = (<long * > citer.data[0])[0]
 *         _vec[0] = (<double *> citer.data[1])[0]
 *         _vec[1] = (<double *> citer.data[2])[0]             # <<<<<<<<<<<<<<
 *         _vec[2] = (<double *> citer.data[3])[0]
 *         _vec2pix_ring ( _nside, _vec, &_ipix)
 */
            (__pyx_v__vec[1]) = (((double *)(__pyx_v_citer.data[2]))[0]);

            /* "chealpy/_ccode.pyx":315
 *         _vec[0] = (<double *> citer.data[1])[0]
 *         _vec[1] = (<double *> citer.data[2])[0]
 *         _vec[2] = (<double *> citer.data[3])[0]             # <<<<<<<<<<<<<<
 *         _vec2pix_ring ( _nside, _vec, &_ipix)
 *         (<long * > citer.data[4])[0] = _ipix
 */
            (__pyx_v__vec[2]) = (((double *)(__pyx_v_citer.data[3]))[0]);

            /* "chealpy/_ccode.pyx":316
 *         _vec[1] = (<double *> citer.data[2])[0]
 *         _vec[2] = (<double *> citer.data[3])[0]
 *         _vec2pix_ring ( _nside, _vec, &_ipix)             # <<<<<<<<<<<<<<
 *         (<long * > citer.data[4])[0] = _ipix
 *         npyiter.advance(&citer)
 */
            vec2pix_ring(__pyx_v__nside, __pyx_v__vec, (&__pyx_v__ipix));

            /* "chealpy/_ccode.pyx":317
 *         _vec[2] = (<double *> citer.data[3])[0]
 *         _vec2pix_ring ( _nside, _vec, &_ipix)
 *         (<long * > citer.data[4])[0] = _ipix             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((long *)(__pyx_v_citer.data[4]))[0]) = __pyx_v__ipix;

            /* "chealpy/_ccode.pyx":318
 *         _vec2pix_ring ( _nside, _vec, &_ipix)
 *         (<long * > citer.data[4])[0] = _ipix
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":319
 *         (<long * > citer.data[4])[0] = _ipix
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return ipix
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":320
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return ipix
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":309
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":321
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return ipix             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ipix);
  __pyx_r = __pyx_v_ipix;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("chealpy._ccode.vec2pix_ring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF((PyObject *)__pyx_v_vec_a);
  __Pyx_XDECREF(__pyx_v_ipix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_19vec2pix_nest(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_18vec2pix_nest[] = "vec2pix_nest(nside, vec, ipix=None)\nConverting 3 vectors (..., 3) to pix number";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_19vec2pix_nest = {__Pyx_NAMESTR("vec2pix_nest"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_19vec2pix_nest, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_18vec2pix_nest)};
static PyObject *__pyx_pw_7chealpy_6_ccode_19vec2pix_nest(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_vec = 0;
  PyObject *__pyx_v_ipix = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__vec,&__pyx_n_s__ipix,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vec2pix_nest (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":324
 * 
 * 
 * def vec2pix_nest (nside,vec, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__vec);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("vec2pix_nest", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "vec2pix_nest") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_vec = values[1];
    __pyx_v_ipix = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("vec2pix_nest", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.vec2pix_nest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_18vec2pix_nest(__pyx_self, __pyx_v_nside, __pyx_v_vec, __pyx_v_ipix);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_18vec2pix_nest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_vec, PyObject *__pyx_v_ipix) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  long __pyx_v__ipix;
  PyArrayObject *__pyx_v_vec_a = 0;
  double *__pyx_v__vec;
  long __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vec2pix_nest", 0);
  __Pyx_INCREF(__pyx_v_ipix);

  /* "chealpy/_ccode.pyx":326
 * def vec2pix_nest (nside,vec, ipix = None):
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape             # <<<<<<<<<<<<<<
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')
 * 
 */
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_9)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_10)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_11)); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(5); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__shape); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_shape = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":327
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],
 */
  __pyx_t_5 = (__pyx_v_ipix == Py_None);
  if (__pyx_t_5) {
    __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__empty); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__int)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_4), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_v_ipix);
    __pyx_v_ipix = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":329
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','f8','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__nditer); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_12)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_13)); if (!__pyx_t_4) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_14)); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyList_New(5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_6, 3, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_6, 4, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_1 = 0;
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_6 = 0;
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_6));

  /* "chealpy/_ccode.pyx":330
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],
 *        op_dtypes=['int','f8','f8','f8','int'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_4 = PyList_New(5); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 330; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 1, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_4, 4, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":331
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],
 *        op_dtypes=['int','f8','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_10 = PyList_New(5); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_t_4));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_10, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  PyList_SET_ITEM(__pyx_t_10, 4, ((PyObject *)__pyx_t_9));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_9));
  __pyx_t_4 = 0;
  __pyx_t_1 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":332
 *        op_dtypes=['int','f8','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_10 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_3), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_iter = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":336
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":338
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 */
  __pyx_t_10 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_6 = PyObject_GetAttr(__pyx_t_10, __pyx_n_s__empty); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_10));
  if (PyDict_SetItem(__pyx_t_10, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_16)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_k_tuple_15), ((PyObject *)__pyx_t_10)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_vec_a = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "chealpy/_ccode.pyx":339
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data             # <<<<<<<<<<<<<<
 *   cdef long _nside
 *   with nogil:
 */
  __pyx_v__vec = ((double *)__pyx_v_vec_a->data);

  /* "chealpy/_ccode.pyx":341
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":342
 *   cdef long _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_5 = (__pyx_v_size > 0);
          if (!__pyx_t_5) break;

          /* "chealpy/_ccode.pyx":343
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<long * > citer.data[0])[0]
 *         _vec[0] = (<double *> citer.data[1])[0]
 */
          while (1) {
            __pyx_t_5 = (__pyx_v_size > 0);
            if (!__pyx_t_5) break;

            /* "chealpy/_ccode.pyx":344
 *     while size >0:
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _vec[0] = (<double *> citer.data[1])[0]
 *         _vec[1] = (<double *> citer.data[2])[0]
 */
            __pyx_v__nside = (((long *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":345
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 *         _vec[0] = (<double *> citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _vec[1] = (<double *> citer.data[2])[0]
 *         _vec[2] = (<double *> citer.data[3])[0]
 */
            (__pyx_v__vec[0]) = (((double *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":346
 *         _nside = (<long * > citer.data[0])[0]
 *         _vec[0] = (<double *> citer.data[1])[0]
 *         _vec[1] = (<double *> citer.data[2])[0]             # <<<<<<<<<<<<<<
 *         _vec[2] = (<double *> citer.data[3])[0]
 *         _vec2pix_nest ( _nside, _vec, &_ipix)
 */
            (__pyx_v__vec[1]) = (((double *)(__pyx_v_citer.data[2]))[0]);

            /* "chealpy/_ccode.pyx":347
 *         _vec[0] = (<double *> citer.data[1])[0]
 *         _vec[1] = (<double *> citer.data[2])[0]
 *         _vec[2] = (<double *> citer.data[3])[0]             # <<<<<<<<<<<<<<
 *         _vec2pix_nest ( _nside, _vec, &_ipix)
 *         (<long * > citer.data[4])[0] = _ipix
 */
            (__pyx_v__vec[2]) = (((double *)(__pyx_v_citer.data[3]))[0]);

            /* "chealpy/_ccode.pyx":348
 *         _vec[1] = (<double *> citer.data[2])[0]
 *         _vec[2] = (<double *> citer.data[3])[0]
 *         _vec2pix_nest ( _nside, _vec, &_ipix)             # <<<<<<<<<<<<<<
 *         (<long * > citer.data[4])[0] = _ipix
 *         npyiter.advance(&citer)
 */
            vec2pix_nest(__pyx_v__nside, __pyx_v__vec, (&__pyx_v__ipix));

            /* "chealpy/_ccode.pyx":349
 *         _vec[2] = (<double *> citer.data[3])[0]
 *         _vec2pix_nest ( _nside, _vec, &_ipix)
 *         (<long * > citer.data[4])[0] = _ipix             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((long *)(__pyx_v_citer.data[4]))[0]) = __pyx_v__ipix;

            /* "chealpy/_ccode.pyx":350
 *         _vec2pix_nest ( _nside, _vec, &_ipix)
 *         (<long * > citer.data[4])[0] = _ipix
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":351
 *         (<long * > citer.data[4])[0] = _ipix
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return ipix
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":352
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return ipix
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":341
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":353
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return ipix             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ipix);
  __pyx_r = __pyx_v_ipix;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("chealpy._ccode.vec2pix_nest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF((PyObject *)__pyx_v_vec_a);
  __Pyx_XDECREF(__pyx_v_ipix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_21vec2pix_ring64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_20vec2pix_ring64[] = "vec2pix_ring64(nside, vec, ipix=None)\nConverting 3 vectors (..., 3) to pix number";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_21vec2pix_ring64 = {__Pyx_NAMESTR("vec2pix_ring64"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_21vec2pix_ring64, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_20vec2pix_ring64)};
static PyObject *__pyx_pw_7chealpy_6_ccode_21vec2pix_ring64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_vec = 0;
  PyObject *__pyx_v_ipix = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__vec,&__pyx_n_s__ipix,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vec2pix_ring64 (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":356
 * 
 * 
 * def vec2pix_ring64 (nside,vec, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__vec);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("vec2pix_ring64", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 356; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "vec2pix_ring64") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 356; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_vec = values[1];
    __pyx_v_ipix = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("vec2pix_ring64", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 356; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.vec2pix_ring64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_20vec2pix_ring64(__pyx_self, __pyx_v_nside, __pyx_v_vec, __pyx_v_ipix);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_20vec2pix_ring64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_vec, PyObject *__pyx_v_ipix) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  int64_t __pyx_v__ipix;
  PyArrayObject *__pyx_v_vec_a = 0;
  double *__pyx_v__vec;
  int64_t __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vec2pix_ring64", 0);
  __Pyx_INCREF(__pyx_v_ipix);

  /* "chealpy/_ccode.pyx":358
 * def vec2pix_ring64 (nside,vec, ipix = None):
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape             # <<<<<<<<<<<<<<
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')
 * 
 */
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_17)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 358; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_18)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 358; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_19)); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 358; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(5); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 358; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 358; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__shape); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 358; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_shape = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":359
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],
 */
  __pyx_t_5 = (__pyx_v_ipix == Py_None);
  if (__pyx_t_5) {
    __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__empty); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__i8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_4), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_v_ipix);
    __pyx_v_ipix = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":361
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','f8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__nditer); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_20)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_21)); if (!__pyx_t_4) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_22)); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyList_New(5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_6, 3, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_6, 4, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_1 = 0;
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_6 = 0;
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_6));

  /* "chealpy/_ccode.pyx":362
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],
 *        op_dtypes=['i8','f8','f8','f8','i8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_4 = PyList_New(5); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 1, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_4, 4, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":363
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],
 *        op_dtypes=['i8','f8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_10 = PyList_New(5); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_t_4));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_10, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  PyList_SET_ITEM(__pyx_t_10, 4, ((PyObject *)__pyx_t_9));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_9));
  __pyx_t_4 = 0;
  __pyx_t_1 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":364
 *        op_dtypes=['i8','f8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 364; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_10 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_3), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_iter = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":368
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":370
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 */
  __pyx_t_10 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_6 = PyObject_GetAttr(__pyx_t_10, __pyx_n_s__empty); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_10));
  if (PyDict_SetItem(__pyx_t_10, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_24)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_k_tuple_23), ((PyObject *)__pyx_t_10)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_vec_a = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "chealpy/_ccode.pyx":371
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data             # <<<<<<<<<<<<<<
 *   cdef int64_t _nside
 *   with nogil:
 */
  __pyx_v__vec = ((double *)__pyx_v_vec_a->data);

  /* "chealpy/_ccode.pyx":373
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":374
 *   cdef int64_t _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_5 = (__pyx_v_size > 0);
          if (!__pyx_t_5) break;

          /* "chealpy/_ccode.pyx":375
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _vec[0] = (<double *> citer.data[1])[0]
 */
          while (1) {
            __pyx_t_5 = (__pyx_v_size > 0);
            if (!__pyx_t_5) break;

            /* "chealpy/_ccode.pyx":376
 *     while size >0:
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _vec[0] = (<double *> citer.data[1])[0]
 *         _vec[1] = (<double *> citer.data[2])[0]
 */
            __pyx_v__nside = (((int64_t *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":377
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _vec[0] = (<double *> citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _vec[1] = (<double *> citer.data[2])[0]
 *         _vec[2] = (<double *> citer.data[3])[0]
 */
            (__pyx_v__vec[0]) = (((double *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":378
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _vec[0] = (<double *> citer.data[1])[0]
 *         _vec[1] = (<double *> citer.data[2])[0]             # <<<<<<<<<<<<<<
 *         _vec[2] = (<double *> citer.data[3])[0]
 *         _vec2pix_ring64 ( _nside, _vec, &_ipix)
 */
            (__pyx_v__vec[1]) = (((double *)(__pyx_v_citer.data[2]))[0]);

            /* "chealpy/_ccode.pyx":379
 *         _vec[0] = (<double *> citer.data[1])[0]
 *         _vec[1] = (<double *> citer.data[2])[0]
 *         _vec[2] = (<double *> citer.data[3])[0]             # <<<<<<<<<<<<<<
 *         _vec2pix_ring64 ( _nside, _vec, &_ipix)
 *         (<int64_t * > citer.data[4])[0] = _ipix
 */
            (__pyx_v__vec[2]) = (((double *)(__pyx_v_citer.data[3]))[0]);

            /* "chealpy/_ccode.pyx":380
 *         _vec[1] = (<double *> citer.data[2])[0]
 *         _vec[2] = (<double *> citer.data[3])[0]
 *         _vec2pix_ring64 ( _nside, _vec, &_ipix)             # <<<<<<<<<<<<<<
 *         (<int64_t * > citer.data[4])[0] = _ipix
 *         npyiter.advance(&citer)
 */
            vec2pix_ring64(__pyx_v__nside, __pyx_v__vec, (&__pyx_v__ipix));

            /* "chealpy/_ccode.pyx":381
 *         _vec[2] = (<double *> citer.data[3])[0]
 *         _vec2pix_ring64 ( _nside, _vec, &_ipix)
 *         (<int64_t * > citer.data[4])[0] = _ipix             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((int64_t *)(__pyx_v_citer.data[4]))[0]) = __pyx_v__ipix;

            /* "chealpy/_ccode.pyx":382
 *         _vec2pix_ring64 ( _nside, _vec, &_ipix)
 *         (<int64_t * > citer.data[4])[0] = _ipix
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":383
 *         (<int64_t * > citer.data[4])[0] = _ipix
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return ipix
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":384
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return ipix
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":373
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":385
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return ipix             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ipix);
  __pyx_r = __pyx_v_ipix;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("chealpy._ccode.vec2pix_ring64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF((PyObject *)__pyx_v_vec_a);
  __Pyx_XDECREF(__pyx_v_ipix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_23vec2pix_nest64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_22vec2pix_nest64[] = "vec2pix_nest64(nside, vec, ipix=None)\nConverting 3 vectors (..., 3) to pix number";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_23vec2pix_nest64 = {__Pyx_NAMESTR("vec2pix_nest64"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_23vec2pix_nest64, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_22vec2pix_nest64)};
static PyObject *__pyx_pw_7chealpy_6_ccode_23vec2pix_nest64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_vec = 0;
  PyObject *__pyx_v_ipix = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__vec,&__pyx_n_s__ipix,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vec2pix_nest64 (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":388
 * 
 * 
 * def vec2pix_nest64 (nside,vec, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__vec);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("vec2pix_nest64", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 388; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "vec2pix_nest64") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 388; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_vec = values[1];
    __pyx_v_ipix = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("vec2pix_nest64", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 388; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.vec2pix_nest64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_22vec2pix_nest64(__pyx_self, __pyx_v_nside, __pyx_v_vec, __pyx_v_ipix);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_22vec2pix_nest64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_vec, PyObject *__pyx_v_ipix) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  int64_t __pyx_v__ipix;
  PyArrayObject *__pyx_v_vec_a = 0;
  double *__pyx_v__vec;
  int64_t __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vec2pix_nest64", 0);
  __Pyx_INCREF(__pyx_v_ipix);

  /* "chealpy/_ccode.pyx":390
 * def vec2pix_nest64 (nside,vec, ipix = None):
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape             # <<<<<<<<<<<<<<
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')
 * 
 */
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_25)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 390; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_26)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 390; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_27)); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 390; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(5); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 390; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 390; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__shape); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 390; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_shape = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":391
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],
 */
  __pyx_t_5 = (__pyx_v_ipix == Py_None);
  if (__pyx_t_5) {
    __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 391; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__empty); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 391; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 391; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 391; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__i8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 391; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_4), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 391; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_v_ipix);
    __pyx_v_ipix = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":393
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','f8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__nditer); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_28)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_29)); if (!__pyx_t_4) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_30)); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyList_New(5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_6, 3, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_6, 4, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_1 = 0;
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_6 = 0;
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_6));

  /* "chealpy/_ccode.pyx":394
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],
 *        op_dtypes=['i8','f8','f8','f8','i8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_4 = PyList_New(5); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 394; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 1, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_4, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_4, 4, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":395
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],
 *        op_dtypes=['i8','f8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_10 = PyList_New(5); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_t_4));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_10, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  PyList_SET_ITEM(__pyx_t_10, 4, ((PyObject *)__pyx_t_9));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_9));
  __pyx_t_4 = 0;
  __pyx_t_1 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":396
 *        op_dtypes=['i8','f8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 396; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_10 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_3), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_iter = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":400
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":402
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 */
  __pyx_t_10 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_6 = PyObject_GetAttr(__pyx_t_10, __pyx_n_s__empty); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_10));
  if (PyDict_SetItem(__pyx_t_10, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_32)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_k_tuple_31), ((PyObject *)__pyx_t_10)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_vec_a = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "chealpy/_ccode.pyx":403
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data             # <<<<<<<<<<<<<<
 *   cdef int64_t _nside
 *   with nogil:
 */
  __pyx_v__vec = ((double *)__pyx_v_vec_a->data);

  /* "chealpy/_ccode.pyx":405
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":406
 *   cdef int64_t _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_5 = (__pyx_v_size > 0);
          if (!__pyx_t_5) break;

          /* "chealpy/_ccode.pyx":407
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _vec[0] = (<double *> citer.data[1])[0]
 */
          while (1) {
            __pyx_t_5 = (__pyx_v_size > 0);
            if (!__pyx_t_5) break;

            /* "chealpy/_ccode.pyx":408
 *     while size >0:
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _vec[0] = (<double *> citer.data[1])[0]
 *         _vec[1] = (<double *> citer.data[2])[0]
 */
            __pyx_v__nside = (((int64_t *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":409
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _vec[0] = (<double *> citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _vec[1] = (<double *> citer.data[2])[0]
 *         _vec[2] = (<double *> citer.data[3])[0]
 */
            (__pyx_v__vec[0]) = (((double *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":410
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _vec[0] = (<double *> citer.data[1])[0]
 *         _vec[1] = (<double *> citer.data[2])[0]             # <<<<<<<<<<<<<<
 *         _vec[2] = (<double *> citer.data[3])[0]
 *         _vec2pix_nest64 ( _nside, _vec, &_ipix)
 */
            (__pyx_v__vec[1]) = (((double *)(__pyx_v_citer.data[2]))[0]);

            /* "chealpy/_ccode.pyx":411
 *         _vec[0] = (<double *> citer.data[1])[0]
 *         _vec[1] = (<double *> citer.data[2])[0]
 *         _vec[2] = (<double *> citer.data[3])[0]             # <<<<<<<<<<<<<<
 *         _vec2pix_nest64 ( _nside, _vec, &_ipix)
 *         (<int64_t * > citer.data[4])[0] = _ipix
 */
            (__pyx_v__vec[2]) = (((double *)(__pyx_v_citer.data[3]))[0]);

            /* "chealpy/_ccode.pyx":412
 *         _vec[1] = (<double *> citer.data[2])[0]
 *         _vec[2] = (<double *> citer.data[3])[0]
 *         _vec2pix_nest64 ( _nside, _vec, &_ipix)             # <<<<<<<<<<<<<<
 *         (<int64_t * > citer.data[4])[0] = _ipix
 *         npyiter.advance(&citer)
 */
            vec2pix_nest64(__pyx_v__nside, __pyx_v__vec, (&__pyx_v__ipix));

            /* "chealpy/_ccode.pyx":413
 *         _vec[2] = (<double *> citer.data[3])[0]
 *         _vec2pix_nest64 ( _nside, _vec, &_ipix)
 *         (<int64_t * > citer.data[4])[0] = _ipix             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((int64_t *)(__pyx_v_citer.data[4]))[0]) = __pyx_v__ipix;

            /* "chealpy/_ccode.pyx":414
 *         _vec2pix_nest64 ( _nside, _vec, &_ipix)
 *         (<int64_t * > citer.data[4])[0] = _ipix
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":415
 *         (<int64_t * > citer.data[4])[0] = _ipix
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return ipix
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":416
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return ipix
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":405
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":417
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return ipix             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ipix);
  __pyx_r = __pyx_v_ipix;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("chealpy._ccode.vec2pix_nest64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF((PyObject *)__pyx_v_vec_a);
  __Pyx_XDECREF(__pyx_v_ipix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_25pix2vec_ring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_24pix2vec_ring[] = "pix2vec_ring(nside, ipix, vec=None)\nConverting pix number to 3 vectors (..., 3)";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_25pix2vec_ring = {__Pyx_NAMESTR("pix2vec_ring"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_25pix2vec_ring, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_24pix2vec_ring)};
static PyObject *__pyx_pw_7chealpy_6_ccode_25pix2vec_ring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_ipix = 0;
  PyObject *__pyx_v_vec = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__ipix,&__pyx_n_s__vec,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pix2vec_ring (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":420
 * 
 * 
 * def pix2vec_ring (nside,ipix, vec = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pix2vec_ring", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__vec);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pix2vec_ring") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_ipix = values[1];
    __pyx_v_vec = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pix2vec_ring", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.pix2vec_ring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_24pix2vec_ring(__pyx_self, __pyx_v_nside, __pyx_v_ipix, __pyx_v_vec);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_24pix2vec_ring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_vec) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  long __pyx_v__ipix;
  PyArrayObject *__pyx_v_vec_a = 0;
  double *__pyx_v__vec;
  long __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pix2vec_ring", 0);
  __Pyx_INCREF(__pyx_v_vec);

  /* "chealpy/_ccode.pyx":422
 * def pix2vec_ring (nside,ipix, vec = None):
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape             # <<<<<<<<<<<<<<
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 422; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 422; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 422; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":423
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 */
  __pyx_t_3 = (__pyx_v_vec == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 423; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 423; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 423; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 423; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_33)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 423; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 423; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_vec);
    __pyx_v_vec = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":425
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','int','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_34)); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_35)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_36)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyList_New(5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_6, 3, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_6, 4, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_5 = 0;
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_6 = 0;
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_6));

  /* "chealpy/_ccode.pyx":426
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 *        op_dtypes=['int','int','f8','f8','f8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 426; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 4, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_1)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":427
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 *        op_dtypes=['int','int','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_10 = PyList_New(5); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_10, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  PyList_SET_ITEM(__pyx_t_10, 4, ((PyObject *)__pyx_t_9));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_9));
  __pyx_t_1 = 0;
  __pyx_t_5 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":428
 *        op_dtypes=['int','int','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 428; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_10 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_2), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_iter = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":432
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":434
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 */
  __pyx_t_10 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_6 = PyObject_GetAttr(__pyx_t_10, __pyx_n_s__empty); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_10));
  if (PyDict_SetItem(__pyx_t_10, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_38)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_k_tuple_37), ((PyObject *)__pyx_t_10)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_vec_a = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":435
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data             # <<<<<<<<<<<<<<
 *   cdef long _nside
 *   with nogil:
 */
  __pyx_v__vec = ((double *)__pyx_v_vec_a->data);

  /* "chealpy/_ccode.pyx":437
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":438
 *   cdef long _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":439
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipix = (<long * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":440
 *     while size >0:
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _ipix = (<long * > citer.data[1])[0]
 *         _pix2vec_ring ( _nside, _ipix, _vec)
 */
            __pyx_v__nside = (((long *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":441
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipix = (<long * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _pix2vec_ring ( _nside, _ipix, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]
 */
            __pyx_v__ipix = (((long *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":442
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipix = (<long * > citer.data[1])[0]
 *         _pix2vec_ring ( _nside, _ipix, _vec)             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]
 */
            pix2vec_ring(__pyx_v__nside, __pyx_v__ipix, __pyx_v__vec);

            /* "chealpy/_ccode.pyx":443
 *         _ipix = (<long * > citer.data[1])[0]
 *         _pix2vec_ring ( _nside, _ipix, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]
 */
            (((double *)(__pyx_v_citer.data[2]))[0]) = (__pyx_v__vec[0]);

            /* "chealpy/_ccode.pyx":444
 *         _pix2vec_ring ( _nside, _ipix, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)
 */
            (((double *)(__pyx_v_citer.data[3]))[0]) = (__pyx_v__vec[1]);

            /* "chealpy/_ccode.pyx":445
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((double *)(__pyx_v_citer.data[4]))[0]) = (__pyx_v__vec[2]);

            /* "chealpy/_ccode.pyx":446
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":447
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return vec
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":448
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return vec
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":437
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":449
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return vec             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_vec);
  __pyx_r = __pyx_v_vec;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("chealpy._ccode.pix2vec_ring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF((PyObject *)__pyx_v_vec_a);
  __Pyx_XDECREF(__pyx_v_vec);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_27pix2vec_nest(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_26pix2vec_nest[] = "pix2vec_nest(nside, ipix, vec=None)\nConverting pix number to 3 vectors (..., 3)";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_27pix2vec_nest = {__Pyx_NAMESTR("pix2vec_nest"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_27pix2vec_nest, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_26pix2vec_nest)};
static PyObject *__pyx_pw_7chealpy_6_ccode_27pix2vec_nest(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_ipix = 0;
  PyObject *__pyx_v_vec = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__ipix,&__pyx_n_s__vec,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pix2vec_nest (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":452
 * 
 * 
 * def pix2vec_nest (nside,ipix, vec = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pix2vec_nest", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 452; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__vec);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pix2vec_nest") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 452; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_ipix = values[1];
    __pyx_v_vec = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pix2vec_nest", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 452; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.pix2vec_nest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_26pix2vec_nest(__pyx_self, __pyx_v_nside, __pyx_v_ipix, __pyx_v_vec);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_26pix2vec_nest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_vec) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  long __pyx_v__ipix;
  PyArrayObject *__pyx_v_vec_a = 0;
  double *__pyx_v__vec;
  long __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pix2vec_nest", 0);
  __Pyx_INCREF(__pyx_v_vec);

  /* "chealpy/_ccode.pyx":454
 * def pix2vec_nest (nside,ipix, vec = None):
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape             # <<<<<<<<<<<<<<
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 454; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 454; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 454; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":455
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 */
  __pyx_t_3 = (__pyx_v_vec == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 455; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 455; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 455; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 455; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_39)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 455; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 455; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_vec);
    __pyx_v_vec = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":457
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','int','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_40)); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_41)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_42)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyList_New(5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_6, 3, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_6, 4, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_5 = 0;
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_6 = 0;
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_6));

  /* "chealpy/_ccode.pyx":458
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 *        op_dtypes=['int','int','f8','f8','f8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 458; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 4, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_1)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":459
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 *        op_dtypes=['int','int','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_10 = PyList_New(5); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_10, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  PyList_SET_ITEM(__pyx_t_10, 4, ((PyObject *)__pyx_t_9));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_9));
  __pyx_t_1 = 0;
  __pyx_t_5 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":460
 *        op_dtypes=['int','int','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 460; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_10 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_2), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_iter = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":464
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":466
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 */
  __pyx_t_10 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_6 = PyObject_GetAttr(__pyx_t_10, __pyx_n_s__empty); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_10));
  if (PyDict_SetItem(__pyx_t_10, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_44)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_k_tuple_43), ((PyObject *)__pyx_t_10)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_vec_a = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":467
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data             # <<<<<<<<<<<<<<
 *   cdef long _nside
 *   with nogil:
 */
  __pyx_v__vec = ((double *)__pyx_v_vec_a->data);

  /* "chealpy/_ccode.pyx":469
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":470
 *   cdef long _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":471
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipix = (<long * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":472
 *     while size >0:
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _ipix = (<long * > citer.data[1])[0]
 *         _pix2vec_nest ( _nside, _ipix, _vec)
 */
            __pyx_v__nside = (((long *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":473
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipix = (<long * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _pix2vec_nest ( _nside, _ipix, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]
 */
            __pyx_v__ipix = (((long *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":474
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipix = (<long * > citer.data[1])[0]
 *         _pix2vec_nest ( _nside, _ipix, _vec)             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]
 */
            pix2vec_nest(__pyx_v__nside, __pyx_v__ipix, __pyx_v__vec);

            /* "chealpy/_ccode.pyx":475
 *         _ipix = (<long * > citer.data[1])[0]
 *         _pix2vec_nest ( _nside, _ipix, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]
 */
            (((double *)(__pyx_v_citer.data[2]))[0]) = (__pyx_v__vec[0]);

            /* "chealpy/_ccode.pyx":476
 *         _pix2vec_nest ( _nside, _ipix, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)
 */
            (((double *)(__pyx_v_citer.data[3]))[0]) = (__pyx_v__vec[1]);

            /* "chealpy/_ccode.pyx":477
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((double *)(__pyx_v_citer.data[4]))[0]) = (__pyx_v__vec[2]);

            /* "chealpy/_ccode.pyx":478
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":479
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return vec
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":480
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return vec
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":469
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":481
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return vec             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_vec);
  __pyx_r = __pyx_v_vec;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("chealpy._ccode.pix2vec_nest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF((PyObject *)__pyx_v_vec_a);
  __Pyx_XDECREF(__pyx_v_vec);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_29pix2vec_ring64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_28pix2vec_ring64[] = "pix2vec_ring64(nside, ipix, vec=None)\nConverting pix number to 3 vectors (..., 3)";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_29pix2vec_ring64 = {__Pyx_NAMESTR("pix2vec_ring64"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_29pix2vec_ring64, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_28pix2vec_ring64)};
static PyObject *__pyx_pw_7chealpy_6_ccode_29pix2vec_ring64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_ipix = 0;
  PyObject *__pyx_v_vec = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__ipix,&__pyx_n_s__vec,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pix2vec_ring64 (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":484
 * 
 * 
 * def pix2vec_ring64 (nside,ipix, vec = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pix2vec_ring64", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 484; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__vec);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pix2vec_ring64") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 484; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_ipix = values[1];
    __pyx_v_vec = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pix2vec_ring64", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 484; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.pix2vec_ring64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_28pix2vec_ring64(__pyx_self, __pyx_v_nside, __pyx_v_ipix, __pyx_v_vec);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_28pix2vec_ring64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_vec) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  int64_t __pyx_v__ipix;
  PyArrayObject *__pyx_v_vec_a = 0;
  double *__pyx_v__vec;
  int64_t __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pix2vec_ring64", 0);
  __Pyx_INCREF(__pyx_v_vec);

  /* "chealpy/_ccode.pyx":486
 * def pix2vec_ring64 (nside,ipix, vec = None):
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape             # <<<<<<<<<<<<<<
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 486; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 486; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 486; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":487
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 */
  __pyx_t_3 = (__pyx_v_vec == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 487; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 487; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 487; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 487; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_45)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 487; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 487; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_vec);
    __pyx_v_vec = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":489
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','i8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_46)); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_47)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_48)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyList_New(5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_6, 3, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_6, 4, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_5 = 0;
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_6 = 0;
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_6));

  /* "chealpy/_ccode.pyx":490
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 *        op_dtypes=['i8','i8','f8','f8','f8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 4, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_1)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":491
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 *        op_dtypes=['i8','i8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 491; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 491; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 491; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 491; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 491; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_10 = PyList_New(5); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 491; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_10, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  PyList_SET_ITEM(__pyx_t_10, 4, ((PyObject *)__pyx_t_9));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_9));
  __pyx_t_1 = 0;
  __pyx_t_5 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":492
 *        op_dtypes=['i8','i8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 492; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_10 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_2), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_iter = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":496
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":498
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 */
  __pyx_t_10 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_6 = PyObject_GetAttr(__pyx_t_10, __pyx_n_s__empty); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_10));
  if (PyDict_SetItem(__pyx_t_10, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_50)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_k_tuple_49), ((PyObject *)__pyx_t_10)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_vec_a = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":499
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data             # <<<<<<<<<<<<<<
 *   cdef int64_t _nside
 *   with nogil:
 */
  __pyx_v__vec = ((double *)__pyx_v_vec_a->data);

  /* "chealpy/_ccode.pyx":501
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":502
 *   cdef int64_t _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":503
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipix = (<int64_t * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":504
 *     while size >0:
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _ipix = (<int64_t * > citer.data[1])[0]
 *         _pix2vec_ring64 ( _nside, _ipix, _vec)
 */
            __pyx_v__nside = (((int64_t *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":505
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipix = (<int64_t * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _pix2vec_ring64 ( _nside, _ipix, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]
 */
            __pyx_v__ipix = (((int64_t *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":506
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipix = (<int64_t * > citer.data[1])[0]
 *         _pix2vec_ring64 ( _nside, _ipix, _vec)             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]
 */
            pix2vec_ring64(__pyx_v__nside, __pyx_v__ipix, __pyx_v__vec);

            /* "chealpy/_ccode.pyx":507
 *         _ipix = (<int64_t * > citer.data[1])[0]
 *         _pix2vec_ring64 ( _nside, _ipix, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]
 */
            (((double *)(__pyx_v_citer.data[2]))[0]) = (__pyx_v__vec[0]);

            /* "chealpy/_ccode.pyx":508
 *         _pix2vec_ring64 ( _nside, _ipix, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)
 */
            (((double *)(__pyx_v_citer.data[3]))[0]) = (__pyx_v__vec[1]);

            /* "chealpy/_ccode.pyx":509
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((double *)(__pyx_v_citer.data[4]))[0]) = (__pyx_v__vec[2]);

            /* "chealpy/_ccode.pyx":510
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":511
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return vec
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":512
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return vec
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":501
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":513
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return vec             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_vec);
  __pyx_r = __pyx_v_vec;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("chealpy._ccode.pix2vec_ring64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF((PyObject *)__pyx_v_vec_a);
  __Pyx_XDECREF(__pyx_v_vec);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_31pix2vec_nest64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_30pix2vec_nest64[] = "pix2vec_nest64(nside, ipix, vec=None)\nConverting pix number to 3 vectors (..., 3)";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_31pix2vec_nest64 = {__Pyx_NAMESTR("pix2vec_nest64"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_31pix2vec_nest64, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_30pix2vec_nest64)};
static PyObject *__pyx_pw_7chealpy_6_ccode_31pix2vec_nest64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_ipix = 0;
  PyObject *__pyx_v_vec = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__ipix,&__pyx_n_s__vec,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pix2vec_nest64 (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":516
 * 
 * 
 * def pix2vec_nest64 (nside,ipix, vec = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipix);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pix2vec_nest64", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 516; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__vec);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pix2vec_nest64") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 516; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_ipix = values[1];
    __pyx_v_vec = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pix2vec_nest64", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 516; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.pix2vec_nest64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_30pix2vec_nest64(__pyx_self, __pyx_v_nside, __pyx_v_ipix, __pyx_v_vec);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_30pix2vec_nest64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipix, PyObject *__pyx_v_vec) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  int64_t __pyx_v__ipix;
  PyArrayObject *__pyx_v_vec_a = 0;
  double *__pyx_v__vec;
  int64_t __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pix2vec_nest64", 0);
  __Pyx_INCREF(__pyx_v_vec);

  /* "chealpy/_ccode.pyx":518
 * def pix2vec_nest64 (nside,ipix, vec = None):
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape             # <<<<<<<<<<<<<<
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 518; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 518; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 518; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":519
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 */
  __pyx_t_3 = (__pyx_v_vec == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 519; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 519; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 519; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 519; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_51)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 519; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 519; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_vec);
    __pyx_v_vec = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":521
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','i8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_52)); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_53)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_54)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyList_New(5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_v_ipix);
  __Pyx_GIVEREF(__pyx_v_ipix);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_6, 3, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_6, 4, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_5 = 0;
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_6 = 0;
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_6));

  /* "chealpy/_ccode.pyx":522
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 *        op_dtypes=['i8','i8','f8','f8','f8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 522; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 4, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_1)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":523
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 *        op_dtypes=['i8','i8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_10 = PyList_New(5); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_10, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  PyList_SET_ITEM(__pyx_t_10, 4, ((PyObject *)__pyx_t_9));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_9));
  __pyx_t_1 = 0;
  __pyx_t_5 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":524
 *        op_dtypes=['i8','i8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 524; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_10 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_2), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_iter = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":528
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":530
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 */
  __pyx_t_10 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 530; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_6 = PyObject_GetAttr(__pyx_t_10, __pyx_n_s__empty); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 530; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 530; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_10));
  if (PyDict_SetItem(__pyx_t_10, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_56)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 530; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_k_tuple_55), ((PyObject *)__pyx_t_10)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 530; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 530; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_vec_a = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":531
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data             # <<<<<<<<<<<<<<
 *   cdef int64_t _nside
 *   with nogil:
 */
  __pyx_v__vec = ((double *)__pyx_v_vec_a->data);

  /* "chealpy/_ccode.pyx":533
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":534
 *   cdef int64_t _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":535
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipix = (<int64_t * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":536
 *     while size >0:
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _ipix = (<int64_t * > citer.data[1])[0]
 *         _pix2vec_nest64 ( _nside, _ipix, _vec)
 */
            __pyx_v__nside = (((int64_t *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":537
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipix = (<int64_t * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _pix2vec_nest64 ( _nside, _ipix, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]
 */
            __pyx_v__ipix = (((int64_t *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":538
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipix = (<int64_t * > citer.data[1])[0]
 *         _pix2vec_nest64 ( _nside, _ipix, _vec)             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]
 */
            pix2vec_nest64(__pyx_v__nside, __pyx_v__ipix, __pyx_v__vec);

            /* "chealpy/_ccode.pyx":539
 *         _ipix = (<int64_t * > citer.data[1])[0]
 *         _pix2vec_nest64 ( _nside, _ipix, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]
 */
            (((double *)(__pyx_v_citer.data[2]))[0]) = (__pyx_v__vec[0]);

            /* "chealpy/_ccode.pyx":540
 *         _pix2vec_nest64 ( _nside, _ipix, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)
 */
            (((double *)(__pyx_v_citer.data[3]))[0]) = (__pyx_v__vec[1]);

            /* "chealpy/_ccode.pyx":541
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((double *)(__pyx_v_citer.data[4]))[0]) = (__pyx_v__vec[2]);

            /* "chealpy/_ccode.pyx":542
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":543
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return vec
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":544
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return vec
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":533
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":545
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return vec             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_vec);
  __pyx_r = __pyx_v_vec;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("chealpy._ccode.pix2vec_nest64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF((PyObject *)__pyx_v_vec_a);
  __Pyx_XDECREF(__pyx_v_vec);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_33nest2ring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_32nest2ring[] = "nest2ring(nside, ipnest, ipring=None)\nnest2ring";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_33nest2ring = {__Pyx_NAMESTR("nest2ring"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_33nest2ring, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_32nest2ring)};
static PyObject *__pyx_pw_7chealpy_6_ccode_33nest2ring(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_ipnest = 0;
  PyObject *__pyx_v_ipring = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__ipnest,&__pyx_n_s__ipring,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nest2ring (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":548
 * 
 * 
 * def nest2ring (nside,ipnest, ipring = None):             # <<<<<<<<<<<<<<
 *   "nest2ring"
 *   shape = numpy.broadcast(1, nside,ipnest).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipnest);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("nest2ring", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 548; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipring);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "nest2ring") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 548; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_ipnest = values[1];
    __pyx_v_ipring = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nest2ring", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 548; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.nest2ring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_32nest2ring(__pyx_self, __pyx_v_nside, __pyx_v_ipnest, __pyx_v_ipring);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_32nest2ring(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipnest, PyObject *__pyx_v_ipring) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  long __pyx_v__ipnest;
  long __pyx_v__ipring;
  long __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nest2ring", 0);
  __Pyx_INCREF(__pyx_v_ipring);

  /* "chealpy/_ccode.pyx":550
 * def nest2ring (nside,ipnest, ipring = None):
 *   "nest2ring"
 *   shape = numpy.broadcast(1, nside,ipnest).shape             # <<<<<<<<<<<<<<
 *   if ipring is None: ipring = numpy.empty(shape, dtype='int')
 * 
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 550; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipnest);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_ipnest);
  __Pyx_GIVEREF(__pyx_v_ipnest);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 550; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 550; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":551
 *   "nest2ring"
 *   shape = numpy.broadcast(1, nside,ipnest).shape
 *   if ipring is None: ipring = numpy.empty(shape, dtype='int')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipnest,ipring],
 */
  __pyx_t_3 = (__pyx_v_ipring == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 551; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 551; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 551; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 551; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__int)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 551; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 551; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_ipring);
    __pyx_v_ipring = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":553
 *   if ipring is None: ipring = numpy.empty(shape, dtype='int')
 * 
 *   iter = numpy.nditer([nside,ipnest,ipring],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','int','int'],
 *        op_flags=[['readonly'],['readonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipnest);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_ipnest);
  __Pyx_GIVEREF(__pyx_v_ipnest);
  __Pyx_INCREF(__pyx_v_ipring);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_v_ipring);
  __Pyx_GIVEREF(__pyx_v_ipring);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));

  /* "chealpy/_ccode.pyx":554
 * 
 *   iter = numpy.nditer([nside,ipnest,ipring],
 *        op_dtypes=['int','int','int'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 2, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":555
 *   iter = numpy.nditer([nside,ipnest,ipring],
 *        op_dtypes=['int','int','int'],
 *        op_flags=[['readonly'],['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  PyList_SET_ITEM(__pyx_t_8, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  PyList_SET_ITEM(__pyx_t_8, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;

  /* "chealpy/_ccode.pyx":556
 *        op_dtypes=['int','int','int'],
 *        op_flags=[['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_8 = PyList_New(3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_8, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_8, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_8 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_iter = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "chealpy/_ccode.pyx":560
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef long _ipnest
 *   cdef long _ipring
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":564
 *   cdef long _ipring
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":565
 *   cdef long _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":566
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipnest = (<long * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":567
 *     while size >0:
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _ipnest = (<long * > citer.data[1])[0]
 *         _nest2ring ( _nside, _ipnest, &_ipring)
 */
            __pyx_v__nside = (((long *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":568
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipnest = (<long * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _nest2ring ( _nside, _ipnest, &_ipring)
 *         (<long * > citer.data[2])[0] = _ipring
 */
            __pyx_v__ipnest = (((long *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":569
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipnest = (<long * > citer.data[1])[0]
 *         _nest2ring ( _nside, _ipnest, &_ipring)             # <<<<<<<<<<<<<<
 *         (<long * > citer.data[2])[0] = _ipring
 *         npyiter.advance(&citer)
 */
            nest2ring(__pyx_v__nside, __pyx_v__ipnest, (&__pyx_v__ipring));

            /* "chealpy/_ccode.pyx":570
 *         _ipnest = (<long * > citer.data[1])[0]
 *         _nest2ring ( _nside, _ipnest, &_ipring)
 *         (<long * > citer.data[2])[0] = _ipring             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((long *)(__pyx_v_citer.data[2]))[0]) = __pyx_v__ipring;

            /* "chealpy/_ccode.pyx":571
 *         _nest2ring ( _nside, _ipnest, &_ipring)
 *         (<long * > citer.data[2])[0] = _ipring
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":572
 *         (<long * > citer.data[2])[0] = _ipring
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return ipring
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":573
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return ipring
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":564
 *   cdef long _ipring
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":574
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return ipring             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ipring);
  __pyx_r = __pyx_v_ipring;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("chealpy._ccode.nest2ring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_ipring);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_35nest2ring64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_34nest2ring64[] = "nest2ring64(nside, ipnest, ipring=None)\nnest2ring";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_35nest2ring64 = {__Pyx_NAMESTR("nest2ring64"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_35nest2ring64, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_34nest2ring64)};
static PyObject *__pyx_pw_7chealpy_6_ccode_35nest2ring64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_ipnest = 0;
  PyObject *__pyx_v_ipring = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__ipnest,&__pyx_n_s__ipring,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nest2ring64 (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":577
 * 
 * 
 * def nest2ring64 (nside,ipnest, ipring = None):             # <<<<<<<<<<<<<<
 *   "nest2ring"
 *   shape = numpy.broadcast(1, nside,ipnest).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipnest);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("nest2ring64", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipring);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "nest2ring64") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_ipnest = values[1];
    __pyx_v_ipring = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nest2ring64", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.nest2ring64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_34nest2ring64(__pyx_self, __pyx_v_nside, __pyx_v_ipnest, __pyx_v_ipring);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_34nest2ring64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipnest, PyObject *__pyx_v_ipring) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  int64_t __pyx_v__ipnest;
  int64_t __pyx_v__ipring;
  int64_t __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nest2ring64", 0);
  __Pyx_INCREF(__pyx_v_ipring);

  /* "chealpy/_ccode.pyx":579
 * def nest2ring64 (nside,ipnest, ipring = None):
 *   "nest2ring"
 *   shape = numpy.broadcast(1, nside,ipnest).shape             # <<<<<<<<<<<<<<
 *   if ipring is None: ipring = numpy.empty(shape, dtype='i8')
 * 
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 579; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipnest);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_ipnest);
  __Pyx_GIVEREF(__pyx_v_ipnest);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 579; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 579; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":580
 *   "nest2ring"
 *   shape = numpy.broadcast(1, nside,ipnest).shape
 *   if ipring is None: ipring = numpy.empty(shape, dtype='i8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipnest,ipring],
 */
  __pyx_t_3 = (__pyx_v_ipring == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 580; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 580; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 580; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 580; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__i8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 580; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 580; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_ipring);
    __pyx_v_ipring = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":582
 *   if ipring is None: ipring = numpy.empty(shape, dtype='i8')
 * 
 *   iter = numpy.nditer([nside,ipnest,ipring],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','i8','i8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipnest);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_ipnest);
  __Pyx_GIVEREF(__pyx_v_ipnest);
  __Pyx_INCREF(__pyx_v_ipring);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_v_ipring);
  __Pyx_GIVEREF(__pyx_v_ipring);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));

  /* "chealpy/_ccode.pyx":583
 * 
 *   iter = numpy.nditer([nside,ipnest,ipring],
 *        op_dtypes=['i8','i8','i8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 583; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 2, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":584
 *   iter = numpy.nditer([nside,ipnest,ipring],
 *        op_dtypes=['i8','i8','i8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 584; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 584; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 584; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 584; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  PyList_SET_ITEM(__pyx_t_8, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  PyList_SET_ITEM(__pyx_t_8, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;

  /* "chealpy/_ccode.pyx":585
 *        op_dtypes=['i8','i8','i8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_8 = PyList_New(3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 585; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_8, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_8, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_8 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_iter = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "chealpy/_ccode.pyx":589
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef int64_t _ipnest
 *   cdef int64_t _ipring
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":593
 *   cdef int64_t _ipring
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":594
 *   cdef int64_t _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":595
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipnest = (<int64_t * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":596
 *     while size >0:
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _ipnest = (<int64_t * > citer.data[1])[0]
 *         _nest2ring64 ( _nside, _ipnest, &_ipring)
 */
            __pyx_v__nside = (((int64_t *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":597
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipnest = (<int64_t * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _nest2ring64 ( _nside, _ipnest, &_ipring)
 *         (<int64_t * > citer.data[2])[0] = _ipring
 */
            __pyx_v__ipnest = (((int64_t *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":598
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipnest = (<int64_t * > citer.data[1])[0]
 *         _nest2ring64 ( _nside, _ipnest, &_ipring)             # <<<<<<<<<<<<<<
 *         (<int64_t * > citer.data[2])[0] = _ipring
 *         npyiter.advance(&citer)
 */
            nest2ring64(__pyx_v__nside, __pyx_v__ipnest, (&__pyx_v__ipring));

            /* "chealpy/_ccode.pyx":599
 *         _ipnest = (<int64_t * > citer.data[1])[0]
 *         _nest2ring64 ( _nside, _ipnest, &_ipring)
 *         (<int64_t * > citer.data[2])[0] = _ipring             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((int64_t *)(__pyx_v_citer.data[2]))[0]) = __pyx_v__ipring;

            /* "chealpy/_ccode.pyx":600
 *         _nest2ring64 ( _nside, _ipnest, &_ipring)
 *         (<int64_t * > citer.data[2])[0] = _ipring
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":601
 *         (<int64_t * > citer.data[2])[0] = _ipring
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return ipring
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":602
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return ipring
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":593
 *   cdef int64_t _ipring
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":603
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return ipring             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ipring);
  __pyx_r = __pyx_v_ipring;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("chealpy._ccode.nest2ring64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_ipring);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_37ring2nest(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_36ring2nest[] = "ring2nest(nside, ipring, ipnest=None)\nring2nest";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_37ring2nest = {__Pyx_NAMESTR("ring2nest"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_37ring2nest, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_36ring2nest)};
static PyObject *__pyx_pw_7chealpy_6_ccode_37ring2nest(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_ipring = 0;
  PyObject *__pyx_v_ipnest = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__ipring,&__pyx_n_s__ipnest,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ring2nest (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":606
 * 
 * 
 * def ring2nest (nside,ipring, ipnest = None):             # <<<<<<<<<<<<<<
 *   "ring2nest"
 *   shape = numpy.broadcast(1, nside,ipring).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipring);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ring2nest", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 606; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipnest);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ring2nest") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 606; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_ipring = values[1];
    __pyx_v_ipnest = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ring2nest", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 606; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.ring2nest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_36ring2nest(__pyx_self, __pyx_v_nside, __pyx_v_ipring, __pyx_v_ipnest);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_36ring2nest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipring, PyObject *__pyx_v_ipnest) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  long __pyx_v__ipring;
  long __pyx_v__nside;
  long __pyx_v__ipnest;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ring2nest", 0);
  __Pyx_INCREF(__pyx_v_ipnest);

  /* "chealpy/_ccode.pyx":608
 * def ring2nest (nside,ipring, ipnest = None):
 *   "ring2nest"
 *   shape = numpy.broadcast(1, nside,ipring).shape             # <<<<<<<<<<<<<<
 *   if ipnest is None: ipnest = numpy.empty(shape, dtype='int')
 * 
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 608; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipring);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_ipring);
  __Pyx_GIVEREF(__pyx_v_ipring);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 608; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 608; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":609
 *   "ring2nest"
 *   shape = numpy.broadcast(1, nside,ipring).shape
 *   if ipnest is None: ipnest = numpy.empty(shape, dtype='int')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipring,ipnest],
 */
  __pyx_t_3 = (__pyx_v_ipnest == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 609; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 609; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 609; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 609; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__int)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 609; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 609; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_ipnest);
    __pyx_v_ipnest = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":611
 *   if ipnest is None: ipnest = numpy.empty(shape, dtype='int')
 * 
 *   iter = numpy.nditer([nside,ipring,ipnest],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','int','int'],
 *        op_flags=[['readonly'],['readonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipring);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_ipring);
  __Pyx_GIVEREF(__pyx_v_ipring);
  __Pyx_INCREF(__pyx_v_ipnest);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_v_ipnest);
  __Pyx_GIVEREF(__pyx_v_ipnest);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));

  /* "chealpy/_ccode.pyx":612
 * 
 *   iter = numpy.nditer([nside,ipring,ipnest],
 *        op_dtypes=['int','int','int'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 612; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 2, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":613
 *   iter = numpy.nditer([nside,ipring,ipnest],
 *        op_dtypes=['int','int','int'],
 *        op_flags=[['readonly'],['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  PyList_SET_ITEM(__pyx_t_8, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  PyList_SET_ITEM(__pyx_t_8, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;

  /* "chealpy/_ccode.pyx":614
 *        op_dtypes=['int','int','int'],
 *        op_flags=[['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_8 = PyList_New(3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 614; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_8, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_8, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_8 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_iter = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "chealpy/_ccode.pyx":618
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef long _ipring
 *   cdef long _nside
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":622
 *   cdef long _nside
 *   cdef long _ipnest
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":623
 *   cdef long _ipnest
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":624
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipring = (<long * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":625
 *     while size >0:
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _ipring = (<long * > citer.data[1])[0]
 *         _ring2nest ( _nside, _ipring, &_ipnest)
 */
            __pyx_v__nside = (((long *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":626
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipring = (<long * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _ring2nest ( _nside, _ipring, &_ipnest)
 *         (<long * > citer.data[2])[0] = _ipnest
 */
            __pyx_v__ipring = (((long *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":627
 *         _nside = (<long * > citer.data[0])[0]
 *         _ipring = (<long * > citer.data[1])[0]
 *         _ring2nest ( _nside, _ipring, &_ipnest)             # <<<<<<<<<<<<<<
 *         (<long * > citer.data[2])[0] = _ipnest
 *         npyiter.advance(&citer)
 */
            ring2nest(__pyx_v__nside, __pyx_v__ipring, (&__pyx_v__ipnest));

            /* "chealpy/_ccode.pyx":628
 *         _ipring = (<long * > citer.data[1])[0]
 *         _ring2nest ( _nside, _ipring, &_ipnest)
 *         (<long * > citer.data[2])[0] = _ipnest             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((long *)(__pyx_v_citer.data[2]))[0]) = __pyx_v__ipnest;

            /* "chealpy/_ccode.pyx":629
 *         _ring2nest ( _nside, _ipring, &_ipnest)
 *         (<long * > citer.data[2])[0] = _ipnest
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":630
 *         (<long * > citer.data[2])[0] = _ipnest
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return ipnest
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":631
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return ipnest
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":622
 *   cdef long _nside
 *   cdef long _ipnest
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":632
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return ipnest             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ipnest);
  __pyx_r = __pyx_v_ipnest;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("chealpy._ccode.ring2nest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_ipnest);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_39ring2nest64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_38ring2nest64[] = "ring2nest64(nside, ipring, ipnest=None)\nring2nest";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_39ring2nest64 = {__Pyx_NAMESTR("ring2nest64"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_39ring2nest64, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_38ring2nest64)};
static PyObject *__pyx_pw_7chealpy_6_ccode_39ring2nest64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_ipring = 0;
  PyObject *__pyx_v_ipnest = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__ipring,&__pyx_n_s__ipnest,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ring2nest64 (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":635
 * 
 * 
 * def ring2nest64 (nside,ipring, ipnest = None):             # <<<<<<<<<<<<<<
 *   "ring2nest"
 *   shape = numpy.broadcast(1, nside,ipring).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipring);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ring2nest64", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__ipnest);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ring2nest64") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_ipring = values[1];
    __pyx_v_ipnest = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ring2nest64", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.ring2nest64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_38ring2nest64(__pyx_self, __pyx_v_nside, __pyx_v_ipring, __pyx_v_ipnest);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_38ring2nest64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_ipring, PyObject *__pyx_v_ipnest) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  int64_t __pyx_v__ipring;
  int64_t __pyx_v__nside;
  int64_t __pyx_v__ipnest;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ring2nest64", 0);
  __Pyx_INCREF(__pyx_v_ipnest);

  /* "chealpy/_ccode.pyx":637
 * def ring2nest64 (nside,ipring, ipnest = None):
 *   "ring2nest"
 *   shape = numpy.broadcast(1, nside,ipring).shape             # <<<<<<<<<<<<<<
 *   if ipnest is None: ipnest = numpy.empty(shape, dtype='i8')
 * 
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 637; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipring);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_ipring);
  __Pyx_GIVEREF(__pyx_v_ipring);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 637; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 637; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":638
 *   "ring2nest"
 *   shape = numpy.broadcast(1, nside,ipring).shape
 *   if ipnest is None: ipnest = numpy.empty(shape, dtype='i8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipring,ipnest],
 */
  __pyx_t_3 = (__pyx_v_ipnest == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 638; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 638; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 638; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 638; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__i8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 638; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 638; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_ipnest);
    __pyx_v_ipnest = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":640
 *   if ipnest is None: ipnest = numpy.empty(shape, dtype='i8')
 * 
 *   iter = numpy.nditer([nside,ipring,ipnest],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','i8','i8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 640; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 640; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 640; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_ipring);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_ipring);
  __Pyx_GIVEREF(__pyx_v_ipring);
  __Pyx_INCREF(__pyx_v_ipnest);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_v_ipnest);
  __Pyx_GIVEREF(__pyx_v_ipnest);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 640; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 640; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));

  /* "chealpy/_ccode.pyx":641
 * 
 *   iter = numpy.nditer([nside,ipring,ipnest],
 *        op_dtypes=['i8','i8','i8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 641; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 2, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 640; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":642
 *   iter = numpy.nditer([nside,ipring,ipnest],
 *        op_dtypes=['i8','i8','i8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 642; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 642; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 642; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 642; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  PyList_SET_ITEM(__pyx_t_8, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  PyList_SET_ITEM(__pyx_t_8, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 640; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;

  /* "chealpy/_ccode.pyx":643
 *        op_dtypes=['i8','i8','i8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_8 = PyList_New(3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 643; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_8, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_8, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 640; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 640; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_8 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 640; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_iter = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "chealpy/_ccode.pyx":647
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef int64_t _ipring
 *   cdef int64_t _nside
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":651
 *   cdef int64_t _nside
 *   cdef int64_t _ipnest
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":652
 *   cdef int64_t _ipnest
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":653
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipring = (<int64_t * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":654
 *     while size >0:
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _ipring = (<int64_t * > citer.data[1])[0]
 *         _ring2nest64 ( _nside, _ipring, &_ipnest)
 */
            __pyx_v__nside = (((int64_t *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":655
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipring = (<int64_t * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _ring2nest64 ( _nside, _ipring, &_ipnest)
 *         (<int64_t * > citer.data[2])[0] = _ipnest
 */
            __pyx_v__ipring = (((int64_t *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":656
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _ipring = (<int64_t * > citer.data[1])[0]
 *         _ring2nest64 ( _nside, _ipring, &_ipnest)             # <<<<<<<<<<<<<<
 *         (<int64_t * > citer.data[2])[0] = _ipnest
 *         npyiter.advance(&citer)
 */
            ring2nest64(__pyx_v__nside, __pyx_v__ipring, (&__pyx_v__ipnest));

            /* "chealpy/_ccode.pyx":657
 *         _ipring = (<int64_t * > citer.data[1])[0]
 *         _ring2nest64 ( _nside, _ipring, &_ipnest)
 *         (<int64_t * > citer.data[2])[0] = _ipnest             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((int64_t *)(__pyx_v_citer.data[2]))[0]) = __pyx_v__ipnest;

            /* "chealpy/_ccode.pyx":658
 *         _ring2nest64 ( _nside, _ipring, &_ipnest)
 *         (<int64_t * > citer.data[2])[0] = _ipnest
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":659
 *         (<int64_t * > citer.data[2])[0] = _ipnest
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return ipnest
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":660
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return ipnest
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":651
 *   cdef int64_t _nside
 *   cdef int64_t _ipnest
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":661
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return ipnest             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ipnest);
  __pyx_r = __pyx_v_ipnest;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("chealpy._ccode.ring2nest64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_ipnest);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_41npix2nside(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_40npix2nside[] = "npix2nside(npix, nside=None)\nnpix2nside";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_41npix2nside = {__Pyx_NAMESTR("npix2nside"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_41npix2nside, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_40npix2nside)};
static PyObject *__pyx_pw_7chealpy_6_ccode_41npix2nside(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_npix = 0;
  PyObject *__pyx_v_nside = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__npix,&__pyx_n_s__nside,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("npix2nside (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[2] = {0,0};

    /* "chealpy/_ccode.pyx":664
 * 
 * 
 * def npix2nside (npix, nside = None):             # <<<<<<<<<<<<<<
 *   "npix2nside"
 *   shape = numpy.broadcast(1, npix).shape
 */
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__npix);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "npix2nside") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 664; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_npix = values[0];
    __pyx_v_nside = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("npix2nside", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 664; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.npix2nside", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_40npix2nside(__pyx_self, __pyx_v_npix, __pyx_v_nside);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_40npix2nside(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_npix, PyObject *__pyx_v_nside) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  long __pyx_v__npix;
  long __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("npix2nside", 0);
  __Pyx_INCREF(__pyx_v_nside);

  /* "chealpy/_ccode.pyx":666
 * def npix2nside (npix, nside = None):
 *   "npix2nside"
 *   shape = numpy.broadcast(1, npix).shape             # <<<<<<<<<<<<<<
 *   if nside is None: nside = numpy.empty(shape, dtype='int')
 * 
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 666; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_npix);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_npix);
  __Pyx_GIVEREF(__pyx_v_npix);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 666; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 666; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":667
 *   "npix2nside"
 *   shape = numpy.broadcast(1, npix).shape
 *   if nside is None: nside = numpy.empty(shape, dtype='int')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([npix,nside],
 */
  __pyx_t_3 = (__pyx_v_nside == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 667; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 667; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 667; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 667; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__int)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 667; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 667; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_nside);
    __pyx_v_nside = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":669
 *   if nside is None: nside = numpy.empty(shape, dtype='int')
 * 
 *   iter = numpy.nditer([npix,nside],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','int'],
 *        op_flags=[['readonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 669; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 669; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 669; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_npix);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_npix);
  __Pyx_GIVEREF(__pyx_v_npix);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 669; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 669; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));

  /* "chealpy/_ccode.pyx":670
 * 
 *   iter = numpy.nditer([npix,nside],
 *        op_dtypes=['int','int'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 670; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 669; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":671
 *   iter = numpy.nditer([npix,nside],
 *        op_dtypes=['int','int'],
 *        op_flags=[['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 671; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 671; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_7 = PyList_New(2); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 671; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  PyList_SET_ITEM(__pyx_t_7, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_7)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 669; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;

  /* "chealpy/_ccode.pyx":672
 *        op_dtypes=['int','int'],
 *        op_flags=[['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_7 = PyList_New(3); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 672; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_7, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_7, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_7)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 669; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 669; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_7 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 669; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_iter = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "chealpy/_ccode.pyx":676
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef long _npix
 *   cdef long _nside
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":679
 *   cdef long _npix
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":680
 *   cdef long _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _npix = (<long * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":681
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _npix = (<long * > citer.data[0])[0]
 *         _nside = _npix2nside ( _npix)
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":682
 *     while size >0:
 *       while size > 0:
 *         _npix = (<long * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _nside = _npix2nside ( _npix)
 *         (<long * > citer.data[1])[0] = _nside
 */
            __pyx_v__npix = (((long *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":683
 *       while size > 0:
 *         _npix = (<long * > citer.data[0])[0]
 *         _nside = _npix2nside ( _npix)             # <<<<<<<<<<<<<<
 *         (<long * > citer.data[1])[0] = _nside
 *         npyiter.advance(&citer)
 */
            __pyx_v__nside = npix2nside(__pyx_v__npix);

            /* "chealpy/_ccode.pyx":684
 *         _npix = (<long * > citer.data[0])[0]
 *         _nside = _npix2nside ( _npix)
 *         (<long * > citer.data[1])[0] = _nside             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((long *)(__pyx_v_citer.data[1]))[0]) = __pyx_v__nside;

            /* "chealpy/_ccode.pyx":685
 *         _nside = _npix2nside ( _npix)
 *         (<long * > citer.data[1])[0] = _nside
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":686
 *         (<long * > citer.data[1])[0] = _nside
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return nside
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":687
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return nside
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":679
 *   cdef long _npix
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":688
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return nside             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_nside);
  __pyx_r = __pyx_v_nside;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("chealpy._ccode.npix2nside", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_nside);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_43npix2nside64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_42npix2nside64[] = "npix2nside64(npix, nside=None)\nnpix2nside";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_43npix2nside64 = {__Pyx_NAMESTR("npix2nside64"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_43npix2nside64, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_42npix2nside64)};
static PyObject *__pyx_pw_7chealpy_6_ccode_43npix2nside64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_npix = 0;
  PyObject *__pyx_v_nside = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__npix,&__pyx_n_s__nside,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("npix2nside64 (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[2] = {0,0};

    /* "chealpy/_ccode.pyx":691
 * 
 * 
 * def npix2nside64 (npix, nside = None):             # <<<<<<<<<<<<<<
 *   "npix2nside"
 *   shape = numpy.broadcast(1, npix).shape
 */
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__npix);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "npix2nside64") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 691; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_npix = values[0];
    __pyx_v_nside = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("npix2nside64", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 691; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.npix2nside64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_42npix2nside64(__pyx_self, __pyx_v_npix, __pyx_v_nside);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_42npix2nside64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_npix, PyObject *__pyx_v_nside) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  int64_t __pyx_v__npix;
  int64_t __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("npix2nside64", 0);
  __Pyx_INCREF(__pyx_v_nside);

  /* "chealpy/_ccode.pyx":693
 * def npix2nside64 (npix, nside = None):
 *   "npix2nside"
 *   shape = numpy.broadcast(1, npix).shape             # <<<<<<<<<<<<<<
 *   if nside is None: nside = numpy.empty(shape, dtype='i8')
 * 
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 693; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_npix);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_npix);
  __Pyx_GIVEREF(__pyx_v_npix);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 693; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 693; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":694
 *   "npix2nside"
 *   shape = numpy.broadcast(1, npix).shape
 *   if nside is None: nside = numpy.empty(shape, dtype='i8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([npix,nside],
 */
  __pyx_t_3 = (__pyx_v_nside == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 694; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 694; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 694; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 694; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__i8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 694; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 694; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_nside);
    __pyx_v_nside = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":696
 *   if nside is None: nside = numpy.empty(shape, dtype='i8')
 * 
 *   iter = numpy.nditer([npix,nside],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','i8'],
 *        op_flags=[['readonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 696; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 696; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 696; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_npix);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_npix);
  __Pyx_GIVEREF(__pyx_v_npix);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 696; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 696; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));

  /* "chealpy/_ccode.pyx":697
 * 
 *   iter = numpy.nditer([npix,nside],
 *        op_dtypes=['i8','i8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 697; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 696; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":698
 *   iter = numpy.nditer([npix,nside],
 *        op_dtypes=['i8','i8'],
 *        op_flags=[['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 698; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 698; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_7 = PyList_New(2); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 698; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  PyList_SET_ITEM(__pyx_t_7, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_7)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 696; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;

  /* "chealpy/_ccode.pyx":699
 *        op_dtypes=['i8','i8'],
 *        op_flags=[['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_7 = PyList_New(3); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 699; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_7, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_7, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_7)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 696; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 696; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_7 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 696; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_iter = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "chealpy/_ccode.pyx":703
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef int64_t _npix
 *   cdef int64_t _nside
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":706
 *   cdef int64_t _npix
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":707
 *   cdef int64_t _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _npix = (<int64_t * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":708
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _npix = (<int64_t * > citer.data[0])[0]
 *         _nside = _npix2nside64 ( _npix)
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":709
 *     while size >0:
 *       while size > 0:
 *         _npix = (<int64_t * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _nside = _npix2nside64 ( _npix)
 *         (<int64_t * > citer.data[1])[0] = _nside
 */
            __pyx_v__npix = (((int64_t *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":710
 *       while size > 0:
 *         _npix = (<int64_t * > citer.data[0])[0]
 *         _nside = _npix2nside64 ( _npix)             # <<<<<<<<<<<<<<
 *         (<int64_t * > citer.data[1])[0] = _nside
 *         npyiter.advance(&citer)
 */
            __pyx_v__nside = npix2nside64(__pyx_v__npix);

            /* "chealpy/_ccode.pyx":711
 *         _npix = (<int64_t * > citer.data[0])[0]
 *         _nside = _npix2nside64 ( _npix)
 *         (<int64_t * > citer.data[1])[0] = _nside             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((int64_t *)(__pyx_v_citer.data[1]))[0]) = __pyx_v__nside;

            /* "chealpy/_ccode.pyx":712
 *         _nside = _npix2nside64 ( _npix)
 *         (<int64_t * > citer.data[1])[0] = _nside
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":713
 *         (<int64_t * > citer.data[1])[0] = _nside
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return nside
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":714
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return nside
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":706
 *   cdef int64_t _npix
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":715
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return nside             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_nside);
  __pyx_r = __pyx_v_nside;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("chealpy._ccode.npix2nside64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_nside);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_45nside2npix(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_44nside2npix[] = "nside2npix(nside, npix=None)\nnside2npix";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_45nside2npix = {__Pyx_NAMESTR("nside2npix"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_45nside2npix, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_44nside2npix)};
static PyObject *__pyx_pw_7chealpy_6_ccode_45nside2npix(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_npix = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__npix,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nside2npix (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[2] = {0,0};

    /* "chealpy/_ccode.pyx":718
 * 
 * 
 * def nside2npix (nside, npix = None):             # <<<<<<<<<<<<<<
 *   "nside2npix"
 *   shape = numpy.broadcast(1, nside).shape
 */
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__npix);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "nside2npix") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 718; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_npix = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nside2npix", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 718; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.nside2npix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_44nside2npix(__pyx_self, __pyx_v_nside, __pyx_v_npix);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_44nside2npix(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_npix) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  long __pyx_v__npix;
  long __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nside2npix", 0);
  __Pyx_INCREF(__pyx_v_npix);

  /* "chealpy/_ccode.pyx":720
 * def nside2npix (nside, npix = None):
 *   "nside2npix"
 *   shape = numpy.broadcast(1, nside).shape             # <<<<<<<<<<<<<<
 *   if npix is None: npix = numpy.empty(shape, dtype='int')
 * 
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":721
 *   "nside2npix"
 *   shape = numpy.broadcast(1, nside).shape
 *   if npix is None: npix = numpy.empty(shape, dtype='int')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,npix],
 */
  __pyx_t_3 = (__pyx_v_npix == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 721; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 721; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 721; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 721; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__int)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 721; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 721; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_npix);
    __pyx_v_npix = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":723
 *   if npix is None: npix = numpy.empty(shape, dtype='int')
 * 
 *   iter = numpy.nditer([nside,npix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','int'],
 *        op_flags=[['readonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_npix);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_npix);
  __Pyx_GIVEREF(__pyx_v_npix);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));

  /* "chealpy/_ccode.pyx":724
 * 
 *   iter = numpy.nditer([nside,npix],
 *        op_dtypes=['int','int'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 724; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__int));
  PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__int));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__int));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":725
 *   iter = numpy.nditer([nside,npix],
 *        op_dtypes=['int','int'],
 *        op_flags=[['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 725; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 725; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_7 = PyList_New(2); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 725; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  PyList_SET_ITEM(__pyx_t_7, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_7)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;

  /* "chealpy/_ccode.pyx":726
 *        op_dtypes=['int','int'],
 *        op_flags=[['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_7 = PyList_New(3); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 726; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_7, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_7, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_7)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_7 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_iter = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "chealpy/_ccode.pyx":730
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef long _npix
 *   cdef long _nside
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":733
 *   cdef long _npix
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":734
 *   cdef long _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":735
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<long * > citer.data[0])[0]
 *         _npix = _nside2npix ( _nside)
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":736
 *     while size >0:
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _npix = _nside2npix ( _nside)
 *         (<long * > citer.data[1])[0] = _npix
 */
            __pyx_v__nside = (((long *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":737
 *       while size > 0:
 *         _nside = (<long * > citer.data[0])[0]
 *         _npix = _nside2npix ( _nside)             # <<<<<<<<<<<<<<
 *         (<long * > citer.data[1])[0] = _npix
 *         npyiter.advance(&citer)
 */
            __pyx_v__npix = nside2npix(__pyx_v__nside);

            /* "chealpy/_ccode.pyx":738
 *         _nside = (<long * > citer.data[0])[0]
 *         _npix = _nside2npix ( _nside)
 *         (<long * > citer.data[1])[0] = _npix             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((long *)(__pyx_v_citer.data[1]))[0]) = __pyx_v__npix;

            /* "chealpy/_ccode.pyx":739
 *         _npix = _nside2npix ( _nside)
 *         (<long * > citer.data[1])[0] = _npix
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":740
 *         (<long * > citer.data[1])[0] = _npix
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return npix
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":741
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return npix
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":733
 *   cdef long _npix
 *   cdef long _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":742
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return npix             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_npix);
  __pyx_r = __pyx_v_npix;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("chealpy._ccode.nside2npix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_npix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_47nside2npix64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_46nside2npix64[] = "nside2npix64(nside, npix=None)\nnside2npix";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_47nside2npix64 = {__Pyx_NAMESTR("nside2npix64"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_47nside2npix64, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_46nside2npix64)};
static PyObject *__pyx_pw_7chealpy_6_ccode_47nside2npix64(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_nside = 0;
  PyObject *__pyx_v_npix = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__nside,&__pyx_n_s__npix,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nside2npix64 (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[2] = {0,0};

    /* "chealpy/_ccode.pyx":745
 * 
 * 
 * def nside2npix64 (nside, npix = None):             # <<<<<<<<<<<<<<
 *   "nside2npix"
 *   shape = numpy.broadcast(1, nside).shape
 */
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__nside);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__npix);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "nside2npix64") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nside = values[0];
    __pyx_v_npix = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nside2npix64", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.nside2npix64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_46nside2npix64(__pyx_self, __pyx_v_nside, __pyx_v_npix);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_46nside2npix64(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_nside, PyObject *__pyx_v_npix) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  int64_t __pyx_v__npix;
  int64_t __pyx_v__nside;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nside2npix64", 0);
  __Pyx_INCREF(__pyx_v_npix);

  /* "chealpy/_ccode.pyx":747
 * def nside2npix64 (nside, npix = None):
 *   "nside2npix"
 *   shape = numpy.broadcast(1, nside).shape             # <<<<<<<<<<<<<<
 *   if npix is None: npix = numpy.empty(shape, dtype='i8')
 * 
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 747; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_nside);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 747; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 747; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":748
 *   "nside2npix"
 *   shape = numpy.broadcast(1, nside).shape
 *   if npix is None: npix = numpy.empty(shape, dtype='i8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,npix],
 */
  __pyx_t_3 = (__pyx_v_npix == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 748; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 748; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 748; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 748; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__i8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 748; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 748; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_npix);
    __pyx_v_npix = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":750
 *   if npix is None: npix = numpy.empty(shape, dtype='i8')
 * 
 *   iter = numpy.nditer([nside,npix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','i8'],
 *        op_flags=[['readonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_nside);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_nside);
  __Pyx_GIVEREF(__pyx_v_nside);
  __Pyx_INCREF(__pyx_v_npix);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_npix);
  __Pyx_GIVEREF(__pyx_v_npix);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));

  /* "chealpy/_ccode.pyx":751
 * 
 *   iter = numpy.nditer([nside,npix],
 *        op_dtypes=['i8','i8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 751; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__i8));
  PyList_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_n_s__i8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__i8));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":752
 *   iter = numpy.nditer([nside,npix],
 *        op_dtypes=['i8','i8'],
 *        op_flags=[['readonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 752; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 752; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_7 = PyList_New(2); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 752; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  PyList_SET_ITEM(__pyx_t_7, 1, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_7)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;

  /* "chealpy/_ccode.pyx":753
 *        op_dtypes=['i8','i8'],
 *        op_flags=[['readonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_7 = PyList_New(3); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 753; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_7, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_7, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_7)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_7 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __pyx_v_iter = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "chealpy/_ccode.pyx":757
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef int64_t _npix
 *   cdef int64_t _nside
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":760
 *   cdef int64_t _npix
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":761
 *   cdef int64_t _nside
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":762
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _npix = _nside2npix64 ( _nside)
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":763
 *     while size >0:
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _npix = _nside2npix64 ( _nside)
 *         (<int64_t * > citer.data[1])[0] = _npix
 */
            __pyx_v__nside = (((int64_t *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":764
 *       while size > 0:
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _npix = _nside2npix64 ( _nside)             # <<<<<<<<<<<<<<
 *         (<int64_t * > citer.data[1])[0] = _npix
 *         npyiter.advance(&citer)
 */
            __pyx_v__npix = nside2npix64(__pyx_v__nside);

            /* "chealpy/_ccode.pyx":765
 *         _nside = (<int64_t * > citer.data[0])[0]
 *         _npix = _nside2npix64 ( _nside)
 *         (<int64_t * > citer.data[1])[0] = _npix             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((int64_t *)(__pyx_v_citer.data[1]))[0]) = __pyx_v__npix;

            /* "chealpy/_ccode.pyx":766
 *         _npix = _nside2npix64 ( _nside)
 *         (<int64_t * > citer.data[1])[0] = _npix
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":767
 *         (<int64_t * > citer.data[1])[0] = _npix
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return npix
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":768
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return npix
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":760
 *   cdef int64_t _npix
 *   cdef int64_t _nside
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":769
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return npix             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_npix);
  __pyx_r = __pyx_v_npix;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("chealpy._ccode.nside2npix64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF(__pyx_v_npix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_49ang2vec(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_48ang2vec[] = "ang2vec(theta, phi, vec=None)\nang2vec";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_49ang2vec = {__Pyx_NAMESTR("ang2vec"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_49ang2vec, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_48ang2vec)};
static PyObject *__pyx_pw_7chealpy_6_ccode_49ang2vec(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_theta = 0;
  PyObject *__pyx_v_phi = 0;
  PyObject *__pyx_v_vec = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__theta,&__pyx_n_s__phi,&__pyx_n_s__vec,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ang2vec (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":772
 * 
 * 
 * def ang2vec (theta,phi, vec = None):             # <<<<<<<<<<<<<<
 *   "ang2vec"
 *   shape = numpy.broadcast(1, theta,phi).shape
 */
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__theta);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__phi);
        if (likely(values[1])) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ang2vec", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__vec);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ang2vec") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_theta = values[0];
    __pyx_v_phi = values[1];
    __pyx_v_vec = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ang2vec", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.ang2vec", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_48ang2vec(__pyx_self, __pyx_v_theta, __pyx_v_phi, __pyx_v_vec);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_48ang2vec(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi, PyObject *__pyx_v_vec) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  double __pyx_v__theta;
  double __pyx_v__phi;
  PyArrayObject *__pyx_v_vec_a = 0;
  double *__pyx_v__vec;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ang2vec", 0);
  __Pyx_INCREF(__pyx_v_vec);

  /* "chealpy/_ccode.pyx":774
 * def ang2vec (theta,phi, vec = None):
 *   "ang2vec"
 *   shape = numpy.broadcast(1, theta,phi).shape             # <<<<<<<<<<<<<<
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(__pyx_v_theta);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":775
 *   "ang2vec"
 *   shape = numpy.broadcast(1, theta,phi).shape
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([theta,phi,vec[...,0],vec[...,1],vec[...,2]],
 */
  __pyx_t_3 = (__pyx_v_vec == Py_None);
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_57)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_vec);
    __pyx_v_vec = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":777
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 *   iter = numpy.nditer([theta,phi,vec[...,0],vec[...,1],vec[...,2]],             # <<<<<<<<<<<<<<
 *        op_dtypes=['f8','f8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_58)); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_59)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_60)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyList_New(5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_theta);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_6, 3, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_6, 4, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_5 = 0;
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_6 = 0;
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_6));

  /* "chealpy/_ccode.pyx":778
 * 
 *   iter = numpy.nditer([theta,phi,vec[...,0],vec[...,1],vec[...,2]],
 *        op_dtypes=['f8','f8','f8','f8','f8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 778; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 4, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_1)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":779
 *   iter = numpy.nditer([theta,phi,vec[...,0],vec[...,1],vec[...,2]],
 *        op_dtypes=['f8','f8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_10 = PyList_New(5); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_t_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_10, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  PyList_SET_ITEM(__pyx_t_10, 4, ((PyObject *)__pyx_t_9));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_9));
  __pyx_t_1 = 0;
  __pyx_t_5 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":780
 *        op_dtypes=['f8','f8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 780; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_10 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_2), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_iter = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":784
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef double _theta
 *   cdef double _phi
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":787
 *   cdef double _theta
 *   cdef double _phi
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   with nogil:
 */
  __pyx_t_10 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_6 = PyObject_GetAttr(__pyx_t_10, __pyx_n_s__empty); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_10));
  if (PyDict_SetItem(__pyx_t_10, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_62)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_k_tuple_61), ((PyObject *)__pyx_t_10)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_vec_a = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":788
 *   cdef double _phi
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data             # <<<<<<<<<<<<<<
 *   with nogil:
 *     while size >0:
 */
  __pyx_v__vec = ((double *)__pyx_v_vec_a->data);

  /* "chealpy/_ccode.pyx":789
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":790
 *   cdef double * _vec = <double *>vec_a.data
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _theta = (<double * > citer.data[0])[0]
 */
        while (1) {
          __pyx_t_3 = (__pyx_v_size > 0);
          if (!__pyx_t_3) break;

          /* "chealpy/_ccode.pyx":791
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _theta = (<double * > citer.data[0])[0]
 *         _phi = (<double * > citer.data[1])[0]
 */
          while (1) {
            __pyx_t_3 = (__pyx_v_size > 0);
            if (!__pyx_t_3) break;

            /* "chealpy/_ccode.pyx":792
 *     while size >0:
 *       while size > 0:
 *         _theta = (<double * > citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _phi = (<double * > citer.data[1])[0]
 *         _ang2vec ( _theta, _phi, _vec)
 */
            __pyx_v__theta = (((double *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":793
 *       while size > 0:
 *         _theta = (<double * > citer.data[0])[0]
 *         _phi = (<double * > citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _ang2vec ( _theta, _phi, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]
 */
            __pyx_v__phi = (((double *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":794
 *         _theta = (<double * > citer.data[0])[0]
 *         _phi = (<double * > citer.data[1])[0]
 *         _ang2vec ( _theta, _phi, _vec)             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]
 */
            ang2vec(__pyx_v__theta, __pyx_v__phi, __pyx_v__vec);

            /* "chealpy/_ccode.pyx":795
 *         _phi = (<double * > citer.data[1])[0]
 *         _ang2vec ( _theta, _phi, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]
 */
            (((double *)(__pyx_v_citer.data[2]))[0]) = (__pyx_v__vec[0]);

            /* "chealpy/_ccode.pyx":796
 *         _ang2vec ( _theta, _phi, _vec)
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]             # <<<<<<<<<<<<<<
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)
 */
            (((double *)(__pyx_v_citer.data[3]))[0]) = (__pyx_v__vec[1]);

            /* "chealpy/_ccode.pyx":797
 *         (<double *> citer.data[2])[0] = _vec[0]
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((double *)(__pyx_v_citer.data[4]))[0]) = (__pyx_v__vec[2]);

            /* "chealpy/_ccode.pyx":798
 *         (<double *> citer.data[3])[0] = _vec[1]
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":799
 *         (<double *> citer.data[4])[0] = _vec[2]
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return vec
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":800
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return vec
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":789
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":801
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return vec             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_vec);
  __pyx_r = __pyx_v_vec;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("chealpy._ccode.ang2vec", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF((PyObject *)__pyx_v_vec_a);
  __Pyx_XDECREF(__pyx_v_vec);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7chealpy_6_ccode_51vec2ang(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_7chealpy_6_ccode_50vec2ang[] = "vec2ang(vec, theta=None, phi=None)\nvec2ang";
static PyMethodDef __pyx_mdef_7chealpy_6_ccode_51vec2ang = {__Pyx_NAMESTR("vec2ang"), (PyCFunction)__pyx_pw_7chealpy_6_ccode_51vec2ang, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_7chealpy_6_ccode_50vec2ang)};
static PyObject *__pyx_pw_7chealpy_6_ccode_51vec2ang(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_vec = 0;
  PyObject *__pyx_v_theta = 0;
  PyObject *__pyx_v_phi = 0;
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__vec,&__pyx_n_s__theta,&__pyx_n_s__phi,0};
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vec2ang (wrapper)", 0);
  __pyx_self = __pyx_self;
  {
    PyObject* values[3] = {0,0,0};

    /* "chealpy/_ccode.pyx":804
 * 
 * 
 * def vec2ang (vec, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "vec2ang"
 *   shape = numpy.broadcast(1, vec[...,0],vec[...,1],vec[...,2]).shape
 */
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__vec);
        if (likely(values[0])) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__theta);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__phi);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "vec2ang") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 804; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_vec = values[0];
    __pyx_v_theta = values[1];
    __pyx_v_phi = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("vec2ang", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 804; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("chealpy._ccode.vec2ang", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7chealpy_6_ccode_50vec2ang(__pyx_self, __pyx_v_vec, __pyx_v_theta, __pyx_v_phi);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7chealpy_6_ccode_50vec2ang(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_vec, PyObject *__pyx_v_theta, PyObject *__pyx_v_phi) {
  PyObject *__pyx_v_shape = NULL;
  PyObject *__pyx_v_iter = NULL;
  __pyx_t_7chealpy_7npyiter_CIter __pyx_v_citer;
  size_t __pyx_v_size;
  double __pyx_v__theta;
  double __pyx_v__phi;
  PyArrayObject *__pyx_v_vec_a = 0;
  double *__pyx_v__vec;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vec2ang", 0);
  __Pyx_INCREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);

  /* "chealpy/_ccode.pyx":806
 * def vec2ang (vec, theta = None,phi = None):
 *   "vec2ang"
 *   shape = numpy.broadcast(1, vec[...,0],vec[...,1],vec[...,2]).shape             # <<<<<<<<<<<<<<
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 */
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_63)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_64)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_65)); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5numpy_broadcast)), ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__shape); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_shape = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "chealpy/_ccode.pyx":807
 *   "vec2ang"
 *   shape = numpy.broadcast(1, vec[...,0],vec[...,1],vec[...,2]).shape
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')             # <<<<<<<<<<<<<<
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 * 
 */
  __pyx_t_5 = (__pyx_v_theta == Py_None);
  if (__pyx_t_5) {
    __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__empty); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__f8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_4), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_v_theta);
    __pyx_v_theta = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "chealpy/_ccode.pyx":808
 *   shape = numpy.broadcast(1, vec[...,0],vec[...,1],vec[...,2]).shape
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([vec[...,0],vec[...,1],vec[...,2],theta,phi],
 */
  __pyx_t_5 = (__pyx_v_phi == Py_None);
  if (__pyx_t_5) {
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 808; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 808; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 808; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 808; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_n_s__f8)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 808; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 808; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_v_phi);
    __pyx_v_phi = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "chealpy/_ccode.pyx":810
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 * 
 *   iter = numpy.nditer([vec[...,0],vec[...,1],vec[...,2],theta,phi],             # <<<<<<<<<<<<<<
 *        op_dtypes=['f8','f8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly'],['writeonly']],
 */
  __pyx_t_3 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__nditer); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_66)); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_67)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_v_vec, ((PyObject *)__pyx_k_tuple_68)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyList_New(5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_theta);
  PyList_SET_ITEM(__pyx_t_6, 3, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyList_SET_ITEM(__pyx_t_6, 4, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_t_3 = 0;
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_6 = 0;
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_6));

  /* "chealpy/_ccode.pyx":811
 * 
 *   iter = numpy.nditer([vec[...,0],vec[...,1],vec[...,2],theta,phi],
 *        op_dtypes=['f8','f8','f8','f8','f8'],             # <<<<<<<<<<<<<<
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 */
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 2, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 3, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyList_SET_ITEM(__pyx_t_1, 4, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_dtypes), ((PyObject *)__pyx_t_1)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":812
 *   iter = numpy.nditer([vec[...,0],vec[...,1],vec[...,2],theta,phi],
 *        op_dtypes=['f8','f8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly'],['writeonly']],             # <<<<<<<<<<<<<<
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],
 *        casting = 'unsafe')
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__readonly));
  PyList_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_n_s__readonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__readonly));
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__writeonly));
  PyList_SET_ITEM(__pyx_t_9, 0, ((PyObject *)__pyx_n_s__writeonly));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__writeonly));
  __pyx_t_10 = PyList_New(5); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_t_3));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_t_7));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_7));
  PyList_SET_ITEM(__pyx_t_10, 3, ((PyObject *)__pyx_t_8));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
  PyList_SET_ITEM(__pyx_t_10, 4, ((PyObject *)__pyx_t_9));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_9));
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__op_flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":813
 *        op_dtypes=['f8','f8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly'],['writeonly']],
 *        flags = ['buffered', 'external_loop', 'zerosize_ok'],             # <<<<<<<<<<<<<<
 *        casting = 'unsafe')
 * 
 */
  __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__buffered));
  PyList_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_n_s__buffered));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__buffered));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__external_loop));
  PyList_SET_ITEM(__pyx_t_10, 1, ((PyObject *)__pyx_n_s__external_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__external_loop));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__zerosize_ok));
  PyList_SET_ITEM(__pyx_t_10, 2, ((PyObject *)__pyx_n_s__zerosize_ok));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__zerosize_ok));
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__flags), ((PyObject *)__pyx_t_10)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__casting), ((PyObject *)__pyx_n_s__unsafe)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_10 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_2), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_iter = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "chealpy/_ccode.pyx":817
 * 
 *   cdef npyiter.CIter citer
 *   cdef size_t size = npyiter.init(&citer, iter)             # <<<<<<<<<<<<<<
 *   cdef double _theta
 *   cdef double _phi
 */
  __pyx_v_size = __pyx_f_7chealpy_7npyiter_init((&__pyx_v_citer), __pyx_v_iter);

  /* "chealpy/_ccode.pyx":820
 *   cdef double _theta
 *   cdef double _phi
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   with nogil:
 */
  __pyx_t_10 = __Pyx_GetName(__pyx_m, __pyx_n_s__numpy); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_6 = PyObject_GetAttr(__pyx_t_10, __pyx_n_s__empty); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_10));
  if (PyDict_SetItem(__pyx_t_10, ((PyObject *)__pyx_n_s__dtype), ((PyObject *)__pyx_k_tuple_70)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_k_tuple_69), ((PyObject *)__pyx_t_10)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_10)); __pyx_t_10 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_vec_a = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "chealpy/_ccode.pyx":821
 *   cdef double _phi
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data             # <<<<<<<<<<<<<<
 *   with nogil:
 *     while size >0:
 */
  __pyx_v__vec = ((double *)__pyx_v_vec_a->data);

  /* "chealpy/_ccode.pyx":822
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save = NULL;
      #endif
      Py_UNBLOCK_THREADS
      /*try:*/ {

        /* "chealpy/_ccode.pyx":823
 *   cdef double * _vec = <double *>vec_a.data
 *   with nogil:
 *     while size >0:             # <<<<<<<<<<<<<<
 *       while size > 0:
 *         _vec[0] = (<double *> citer.data[0])[0]
 */
        while (1) {
          __pyx_t_5 = (__pyx_v_size > 0);
          if (!__pyx_t_5) break;

          /* "chealpy/_ccode.pyx":824
 *   with nogil:
 *     while size >0:
 *       while size > 0:             # <<<<<<<<<<<<<<
 *         _vec[0] = (<double *> citer.data[0])[0]
 *         _vec[1] = (<double *> citer.data[1])[0]
 */
          while (1) {
            __pyx_t_5 = (__pyx_v_size > 0);
            if (!__pyx_t_5) break;

            /* "chealpy/_ccode.pyx":825
 *     while size >0:
 *       while size > 0:
 *         _vec[0] = (<double *> citer.data[0])[0]             # <<<<<<<<<<<<<<
 *         _vec[1] = (<double *> citer.data[1])[0]
 *         _vec[2] = (<double *> citer.data[2])[0]
 */
            (__pyx_v__vec[0]) = (((double *)(__pyx_v_citer.data[0]))[0]);

            /* "chealpy/_ccode.pyx":826
 *       while size > 0:
 *         _vec[0] = (<double *> citer.data[0])[0]
 *         _vec[1] = (<double *> citer.data[1])[0]             # <<<<<<<<<<<<<<
 *         _vec[2] = (<double *> citer.data[2])[0]
 *         _vec2ang ( _vec, &_theta, &_phi)
 */
            (__pyx_v__vec[1]) = (((double *)(__pyx_v_citer.data[1]))[0]);

            /* "chealpy/_ccode.pyx":827
 *         _vec[0] = (<double *> citer.data[0])[0]
 *         _vec[1] = (<double *> citer.data[1])[0]
 *         _vec[2] = (<double *> citer.data[2])[0]             # <<<<<<<<<<<<<<
 *         _vec2ang ( _vec, &_theta, &_phi)
 *         (<double * > citer.data[3])[0] = _theta
 */
            (__pyx_v__vec[2]) = (((double *)(__pyx_v_citer.data[2]))[0]);

            /* "chealpy/_ccode.pyx":828
 *         _vec[1] = (<double *> citer.data[1])[0]
 *         _vec[2] = (<double *> citer.data[2])[0]
 *         _vec2ang ( _vec, &_theta, &_phi)             # <<<<<<<<<<<<<<
 *         (<double * > citer.data[3])[0] = _theta
 *         (<double * > citer.data[4])[0] = _phi
 */
            vec2ang(__pyx_v__vec, (&__pyx_v__theta), (&__pyx_v__phi));

            /* "chealpy/_ccode.pyx":829
 *         _vec[2] = (<double *> citer.data[2])[0]
 *         _vec2ang ( _vec, &_theta, &_phi)
 *         (<double * > citer.data[3])[0] = _theta             # <<<<<<<<<<<<<<
 *         (<double * > citer.data[4])[0] = _phi
 *         npyiter.advance(&citer)
 */
            (((double *)(__pyx_v_citer.data[3]))[0]) = __pyx_v__theta;

            /* "chealpy/_ccode.pyx":830
 *         _vec2ang ( _vec, &_theta, &_phi)
 *         (<double * > citer.data[3])[0] = _theta
 *         (<double * > citer.data[4])[0] = _phi             # <<<<<<<<<<<<<<
 *         npyiter.advance(&citer)
 *         size = size -1
 */
            (((double *)(__pyx_v_citer.data[4]))[0]) = __pyx_v__phi;

            /* "chealpy/_ccode.pyx":831
 *         (<double * > citer.data[3])[0] = _theta
 *         (<double * > citer.data[4])[0] = _phi
 *         npyiter.advance(&citer)             # <<<<<<<<<<<<<<
 *         size = size -1
 *       size = npyiter.next(&citer)
 */
            __pyx_f_7chealpy_7npyiter_advance((&__pyx_v_citer));

            /* "chealpy/_ccode.pyx":832
 *         (<double * > citer.data[4])[0] = _phi
 *         npyiter.advance(&citer)
 *         size = size -1             # <<<<<<<<<<<<<<
 *       size = npyiter.next(&citer)
 *   return theta,phi
 */
            __pyx_v_size = (__pyx_v_size - 1);
          }

          /* "chealpy/_ccode.pyx":833
 *         npyiter.advance(&citer)
 *         size = size -1
 *       size = npyiter.next(&citer)             # <<<<<<<<<<<<<<
 *   return theta,phi
 * 
 */
          __pyx_v_size = __pyx_f_7chealpy_7npyiter_next((&__pyx_v_citer));
        }
      }

      /* "chealpy/_ccode.pyx":822
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))
 *   cdef double * _vec = <double *>vec_a.data
 *   with nogil:             # <<<<<<<<<<<<<<
 *     while size >0:
 *       while size > 0:
 */
      /*finally:*/ {
        Py_BLOCK_THREADS
      }
  }

  /* "chealpy/_ccode.pyx":834
 *         size = size -1
 *       size = npyiter.next(&citer)
 *   return theta,phi             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_theta);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_theta);
  __Pyx_GIVEREF(__pyx_v_theta);
  __Pyx_INCREF(__pyx_v_phi);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_phi);
  __Pyx_GIVEREF(__pyx_v_phi);
  __pyx_r = ((PyObject *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("chealpy._ccode.vec2ang", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XDECREF(__pyx_v_iter);
  __Pyx_XDECREF((PyObject *)__pyx_v_vec_a);
  __Pyx_XDECREF(__pyx_v_theta);
  __Pyx_XDECREF(__pyx_v_phi);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "npyiter.pxd":45
 *   numpy.npy_intp GetBufferSize "NpyIter_GetBufferSize" (NpyIter * iter)
 * 
 * cdef inline NpyIter* GetNpyIter(object iter):             # <<<<<<<<<<<<<<
 *   return (<NewNpyArrayIterObject*>iter).iter
 * 
 */

static CYTHON_INLINE __pyx_t_7chealpy_7npyiter_NpyIter *__pyx_f_7chealpy_7npyiter_GetNpyIter(PyObject *__pyx_v_iter) {
  __pyx_t_7chealpy_7npyiter_NpyIter *__pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("GetNpyIter", 0);

  /* "npyiter.pxd":46
 * 
 * cdef inline NpyIter* GetNpyIter(object iter):
 *   return (<NewNpyArrayIterObject*>iter).iter             # <<<<<<<<<<<<<<
 * 
 * ctypedef struct CIter:
 */
  __pyx_r = ((__pyx_t_7chealpy_7npyiter_NewNpyArrayIterObject *)__pyx_v_iter)->iter;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "npyiter.pxd":56
 *   int nop
 * 
 * cdef inline size_t next(CIter* self) nogil:             # <<<<<<<<<<<<<<
 *   if self._next(self.npyiter) == 0:
 *     return 0
 */

static CYTHON_INLINE size_t __pyx_f_7chealpy_7npyiter_next(__pyx_t_7chealpy_7npyiter_CIter *__pyx_v_self) {
  size_t __pyx_r;
  int __pyx_t_1;

  /* "npyiter.pxd":57
 * 
 * cdef inline size_t next(CIter* self) nogil:
 *   if self._next(self.npyiter) == 0:             # <<<<<<<<<<<<<<
 *     return 0
 *   return self.size_ptr[0]
 */
  __pyx_t_1 = (__pyx_v_self->_next(__pyx_v_self->npyiter) == 0);
  if (__pyx_t_1) {

    /* "npyiter.pxd":58
 * cdef inline size_t next(CIter* self) nogil:
 *   if self._next(self.npyiter) == 0:
 *     return 0             # <<<<<<<<<<<<<<
 *   return self.size_ptr[0]
 * 
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "npyiter.pxd":59
 *   if self._next(self.npyiter) == 0:
 *     return 0
 *   return self.size_ptr[0]             # <<<<<<<<<<<<<<
 * 
 * cdef inline size_t init(CIter * self, iter):
 */
  __pyx_r = (__pyx_v_self->size_ptr[0]);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  return __pyx_r;
}

/* "npyiter.pxd":61
 *   return self.size_ptr[0]
 * 
 * cdef inline size_t init(CIter * self, iter):             # <<<<<<<<<<<<<<
 *     self.npyiter = GetNpyIter(iter)
 *     self._next = <IterNextFunc>GetIterNext(self.npyiter, NULL)
 */

static CYTHON_INLINE size_t __pyx_f_7chealpy_7npyiter_init(__pyx_t_7chealpy_7npyiter_CIter *__pyx_v_self, PyObject *__pyx_v_iter) {
  size_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("init", 0);

  /* "npyiter.pxd":62
 * 
 * cdef inline size_t init(CIter * self, iter):
 *     self.npyiter = GetNpyIter(iter)             # <<<<<<<<<<<<<<
 *     self._next = <IterNextFunc>GetIterNext(self.npyiter, NULL)
 *     self.data = GetDataPtrArray(self.npyiter)
 */
  __pyx_v_self->npyiter = __pyx_f_7chealpy_7npyiter_GetNpyIter(__pyx_v_iter);

  /* "npyiter.pxd":63
 * cdef inline size_t init(CIter * self, iter):
 *     self.npyiter = GetNpyIter(iter)
 *     self._next = <IterNextFunc>GetIterNext(self.npyiter, NULL)             # <<<<<<<<<<<<<<
 *     self.data = GetDataPtrArray(self.npyiter)
 *     self.strides = GetInnerStrideArray(self.npyiter)
 */
  __pyx_v_self->_next = ((__pyx_t_7chealpy_7npyiter_IterNextFunc)NpyIter_GetIterNext(__pyx_v_self->npyiter, NULL));

  /* "npyiter.pxd":64
 *     self.npyiter = GetNpyIter(iter)
 *     self._next = <IterNextFunc>GetIterNext(self.npyiter, NULL)
 *     self.data = GetDataPtrArray(self.npyiter)             # <<<<<<<<<<<<<<
 *     self.strides = GetInnerStrideArray(self.npyiter)
 *     self.size_ptr = GetInnerLoopSizePtr(self.npyiter)
 */
  __pyx_v_self->data = NpyIter_GetDataPtrArray(__pyx_v_self->npyiter);

  /* "npyiter.pxd":65
 *     self._next = <IterNextFunc>GetIterNext(self.npyiter, NULL)
 *     self.data = GetDataPtrArray(self.npyiter)
 *     self.strides = GetInnerStrideArray(self.npyiter)             # <<<<<<<<<<<<<<
 *     self.size_ptr = GetInnerLoopSizePtr(self.npyiter)
 *     self.nop = GetNOp(self.npyiter)
 */
  __pyx_v_self->strides = NpyIter_GetInnerStrideArray(__pyx_v_self->npyiter);

  /* "npyiter.pxd":66
 *     self.data = GetDataPtrArray(self.npyiter)
 *     self.strides = GetInnerStrideArray(self.npyiter)
 *     self.size_ptr = GetInnerLoopSizePtr(self.npyiter)             # <<<<<<<<<<<<<<
 *     self.nop = GetNOp(self.npyiter)
 *     return self.size_ptr[0]
 */
  __pyx_v_self->size_ptr = NpyIter_GetInnerLoopSizePtr(__pyx_v_self->npyiter);

  /* "npyiter.pxd":67
 *     self.strides = GetInnerStrideArray(self.npyiter)
 *     self.size_ptr = GetInnerLoopSizePtr(self.npyiter)
 *     self.nop = GetNOp(self.npyiter)             # <<<<<<<<<<<<<<
 *     return self.size_ptr[0]
 * 
 */
  __pyx_v_self->nop = NpyIter_GetNOp(__pyx_v_self->npyiter);

  /* "npyiter.pxd":68
 *     self.size_ptr = GetInnerLoopSizePtr(self.npyiter)
 *     self.nop = GetNOp(self.npyiter)
 *     return self.size_ptr[0]             # <<<<<<<<<<<<<<
 * 
 * cdef inline void advance(CIter * self) nogil:
 */
  __pyx_r = (__pyx_v_self->size_ptr[0]);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "npyiter.pxd":70
 *     return self.size_ptr[0]
 * 
 * cdef inline void advance(CIter * self) nogil:             # <<<<<<<<<<<<<<
 *     cdef int iop
 *     for iop in range(self.nop):
 */

static CYTHON_INLINE void __pyx_f_7chealpy_7npyiter_advance(__pyx_t_7chealpy_7npyiter_CIter *__pyx_v_self) {
  int __pyx_v_iop;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;

  /* "npyiter.pxd":72
 * cdef inline void advance(CIter * self) nogil:
 *     cdef int iop
 *     for iop in range(self.nop):             # <<<<<<<<<<<<<<
 *       self.data[iop] += self.strides[iop]
 */
  __pyx_t_1 = __pyx_v_self->nop;
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_iop = __pyx_t_2;

    /* "npyiter.pxd":73
 *     cdef int iop
 *     for iop in range(self.nop):
 *       self.data[iop] += self.strides[iop]             # <<<<<<<<<<<<<<
 */
    __pyx_t_3 = __pyx_v_iop;
    (__pyx_v_self->data[__pyx_t_3]) = ((__pyx_v_self->data[__pyx_t_3]) + (__pyx_v_self->strides[__pyx_v_iop]));
  }

}

/* Python wrapper */
static int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5numpy_7ndarray___getbuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":193
 *         # experimental exception made for __getbuffer__ and __releasebuffer__
 *         # -- the details of this may change.
 *         def __getbuffer__(ndarray self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fullfill the PEP.
 */

static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_v_copy_shape;
  int __pyx_v_i;
  int __pyx_v_ndim;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  int __pyx_v_t;
  char *__pyx_v_f;
  PyArray_Descr *__pyx_v_descr = 0;
  int __pyx_v_offset;
  int __pyx_v_hasfields;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  if (__pyx_v_info != NULL) {
    __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(__pyx_v_info->obj);
  }

  /* "numpy.pxd":199
 *             # of flags
 * 
 *             if info == NULL: return             # <<<<<<<<<<<<<<
 * 
 *             cdef int copy_shape, i, ndim
 */
  __pyx_t_1 = (__pyx_v_info == NULL);
  if (__pyx_t_1) {
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "numpy.pxd":202
 * 
 *             cdef int copy_shape, i, ndim
 *             cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 */
  __pyx_v_endian_detector = 1;

  /* "numpy.pxd":203
 *             cdef int copy_shape, i, ndim
 *             cdef int endian_detector = 1
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 * 
 *             ndim = PyArray_NDIM(self)
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "numpy.pxd":205
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 *             ndim = PyArray_NDIM(self)             # <<<<<<<<<<<<<<
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_v_ndim = PyArray_NDIM(__pyx_v_self);

  /* "numpy.pxd":207
 *             ndim = PyArray_NDIM(self)
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 copy_shape = 1
 *             else:
 */
  __pyx_t_1 = ((sizeof(npy_intp)) != (sizeof(Py_ssize_t)));
  if (__pyx_t_1) {

    /* "numpy.pxd":208
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 copy_shape = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 copy_shape = 0
 */
    __pyx_v_copy_shape = 1;
    goto __pyx_L4;
  }
  /*else*/ {

    /* "numpy.pxd":210
 *                 copy_shape = 1
 *             else:
 *                 copy_shape = 0             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 */
    __pyx_v_copy_shape = 0;
  }
  __pyx_L4:;

  /* "numpy.pxd":212
 *                 copy_shape = 0
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_C_CONTIGUOUS) == PyBUF_C_CONTIGUOUS);
  if (__pyx_t_1) {

    /* "numpy.pxd":213
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 */
    __pyx_t_2 = (!PyArray_CHKFLAGS(__pyx_v_self, NPY_C_CONTIGUOUS));
    __pyx_t_3 = __pyx_t_2;
  } else {
    __pyx_t_3 = __pyx_t_1;
  }
  if (__pyx_t_3) {

    /* "numpy.pxd":214
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
    __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_72), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[2]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "numpy.pxd":216
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  __pyx_t_3 = ((__pyx_v_flags & PyBUF_F_CONTIGUOUS) == PyBUF_F_CONTIGUOUS);
  if (__pyx_t_3) {

    /* "numpy.pxd":217
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 */
    __pyx_t_1 = (!PyArray_CHKFLAGS(__pyx_v_self, NPY_F_CONTIGUOUS));
    __pyx_t_2 = __pyx_t_1;
  } else {
    __pyx_t_2 = __pyx_t_3;
  }
  if (__pyx_t_2) {

    /* "numpy.pxd":218
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
    __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_74), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[2]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "numpy.pxd":220
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 *             info.buf = PyArray_DATA(self)             # <<<<<<<<<<<<<<
 *             info.ndim = ndim
 *             if copy_shape:
 */
  __pyx_v_info->buf = PyArray_DATA(__pyx_v_self);

  /* "numpy.pxd":221
 * 
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim             # <<<<<<<<<<<<<<
 *             if copy_shape:
 *                 # Allocate new buffer for strides and shape info.
 */
  __pyx_v_info->ndim = __pyx_v_ndim;

  /* "numpy.pxd":222
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim
 *             if copy_shape:             # <<<<<<<<<<<<<<
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 */
  if (__pyx_v_copy_shape) {

    /* "numpy.pxd":225
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)             # <<<<<<<<<<<<<<
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 */
    __pyx_v_info->strides = ((Py_ssize_t *)malloc((((sizeof(Py_ssize_t)) * ((size_t)__pyx_v_ndim)) * 2)));

    /* "numpy.pxd":226
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)
 *                 info.shape = info.strides + ndim             # <<<<<<<<<<<<<<
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 */
    __pyx_v_info->shape = (__pyx_v_info->strides + __pyx_v_ndim);

    /* "numpy.pxd":227
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):             # <<<<<<<<<<<<<<
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 */
    __pyx_t_5 = __pyx_v_ndim;
    for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
      __pyx_v_i = __pyx_t_6;

      /* "numpy.pxd":228
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]             # <<<<<<<<<<<<<<
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 */
      (__pyx_v_info->strides[__pyx_v_i]) = (PyArray_STRIDES(__pyx_v_self)[__pyx_v_i]);

      /* "numpy.pxd":229
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 */
      (__pyx_v_info->shape[__pyx_v_i]) = (PyArray_DIMS(__pyx_v_self)[__pyx_v_i]);
    }
    goto __pyx_L7;
  }
  /*else*/ {

    /* "numpy.pxd":231
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)             # <<<<<<<<<<<<<<
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 */
    __pyx_v_info->strides = ((Py_ssize_t *)PyArray_STRIDES(__pyx_v_self));

    /* "numpy.pxd":232
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)             # <<<<<<<<<<<<<<
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 */
    __pyx_v_info->shape = ((Py_ssize_t *)PyArray_DIMS(__pyx_v_self));
  }
  __pyx_L7:;

  /* "numpy.pxd":233
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 */
  __pyx_v_info->suboffsets = NULL;

  /* "numpy.pxd":234
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)             # <<<<<<<<<<<<<<
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 * 
 */
  __pyx_v_info->itemsize = PyArray_ITEMSIZE(__pyx_v_self);

  /* "numpy.pxd":235
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)             # <<<<<<<<<<<<<<
 * 
 *             cdef int t
 */
  __pyx_v_info->readonly = (!PyArray_ISWRITEABLE(__pyx_v_self));

  /* "numpy.pxd":238
 * 
 *             cdef int t
 *             cdef char* f = NULL             # <<<<<<<<<<<<<<
 *             cdef dtype descr = self.descr
 *             cdef list stack
 */
  __pyx_v_f = NULL;

  /* "numpy.pxd":239
 *             cdef int t
 *             cdef char* f = NULL
 *             cdef dtype descr = self.descr             # <<<<<<<<<<<<<<
 *             cdef list stack
 *             cdef int offset
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_self->descr));
  __pyx_v_descr = __pyx_v_self->descr;

  /* "numpy.pxd":243
 *             cdef int offset
 * 
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)             # <<<<<<<<<<<<<<
 * 
 *             if not hasfields and not copy_shape:
 */
  __pyx_v_hasfields = PyDataType_HASFIELDS(__pyx_v_descr);

  /* "numpy.pxd":245
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)
 * 
 *             if not hasfields and not copy_shape:             # <<<<<<<<<<<<<<
 *                 # do not call releasebuffer
 *                 info.obj = None
 */
  __pyx_t_2 = (!__pyx_v_hasfields);
  if (__pyx_t_2) {
    __pyx_t_3 = (!__pyx_v_copy_shape);
    __pyx_t_1 = __pyx_t_3;
  } else {
    __pyx_t_1 = __pyx_t_2;
  }
  if (__pyx_t_1) {

    /* "numpy.pxd":247
 *             if not hasfields and not copy_shape:
 *                 # do not call releasebuffer
 *                 info.obj = None             # <<<<<<<<<<<<<<
 *             else:
 *                 # need to call releasebuffer
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj);
    __pyx_v_info->obj = Py_None;
    goto __pyx_L10;
  }
  /*else*/ {

    /* "numpy.pxd":250
 *             else:
 *                 # need to call releasebuffer
 *                 info.obj = self             # <<<<<<<<<<<<<<
 * 
 *             if not hasfields:
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj);
    __pyx_v_info->obj = ((PyObject *)__pyx_v_self);
  }
  __pyx_L10:;

  /* "numpy.pxd":252
 *                 info.obj = self
 * 
 *             if not hasfields:             # <<<<<<<<<<<<<<
 *                 t = descr.type_num
 *                 if ((descr.byteorder == '>' and little_endian) or
 */
  __pyx_t_1 = (!__pyx_v_hasfields);
  if (__pyx_t_1) {

    /* "numpy.pxd":253
 * 
 *             if not hasfields:
 *                 t = descr.type_num             # <<<<<<<<<<<<<<
 *                 if ((descr.byteorder == '>' and little_endian) or
 *                     (descr.byteorder == '<' and not little_endian)):
 */
    __pyx_v_t = __pyx_v_descr->type_num;

    /* "numpy.pxd":254
 *             if not hasfields:
 *                 t = descr.type_num
 *                 if ((descr.byteorder == '>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == '<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_1 = (__pyx_v_descr->byteorder == '>');
    if (__pyx_t_1) {
      __pyx_t_2 = __pyx_v_little_endian;
    } else {
      __pyx_t_2 = __pyx_t_1;
    }
    if (!__pyx_t_2) {

      /* "numpy.pxd":255
 *                 t = descr.type_num
 *                 if ((descr.byteorder == '>' and little_endian) or
 *                     (descr.byteorder == '<' and not little_endian)):             # <<<<<<<<<<<<<<
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 */
      __pyx_t_1 = (__pyx_v_descr->byteorder == '<');
      if (__pyx_t_1) {
        __pyx_t_3 = (!__pyx_v_little_endian);
        __pyx_t_7 = __pyx_t_3;
      } else {
        __pyx_t_7 = __pyx_t_1;
      }
      __pyx_t_1 = __pyx_t_7;
    } else {
      __pyx_t_1 = __pyx_t_2;
    }
    if (__pyx_t_1) {

      /* "numpy.pxd":256
 *                 if ((descr.byteorder == '>' and little_endian) or
 *                     (descr.byteorder == '<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
      __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_76), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 256; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      {__pyx_filename = __pyx_f[2]; __pyx_lineno = 256; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L12;
    }
    __pyx_L12:;

    /* "numpy.pxd":257
 *                     (descr.byteorder == '<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_BYTE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__b;
      goto __pyx_L13;
    }

    /* "numpy.pxd":258
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_UBYTE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__B;
      goto __pyx_L13;
    }

    /* "numpy.pxd":259
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_SHORT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__h;
      goto __pyx_L13;
    }

    /* "numpy.pxd":260
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_USHORT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__H;
      goto __pyx_L13;
    }

    /* "numpy.pxd":261
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_INT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__i;
      goto __pyx_L13;
    }

    /* "numpy.pxd":262
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_UINT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__I;
      goto __pyx_L13;
    }

    /* "numpy.pxd":263
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_LONG);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__l;
      goto __pyx_L13;
    }

    /* "numpy.pxd":264
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_ULONG);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__L;
      goto __pyx_L13;
    }

    /* "numpy.pxd":265
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_LONGLONG);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__q;
      goto __pyx_L13;
    }

    /* "numpy.pxd":266
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_ULONGLONG);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__Q;
      goto __pyx_L13;
    }

    /* "numpy.pxd":267
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_FLOAT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__f;
      goto __pyx_L13;
    }

    /* "numpy.pxd":268
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_DOUBLE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__d;
      goto __pyx_L13;
    }

    /* "numpy.pxd":269
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_LONGDOUBLE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__g;
      goto __pyx_L13;
    }

    /* "numpy.pxd":270
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_CFLOAT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__Zf;
      goto __pyx_L13;
    }

    /* "numpy.pxd":271
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_CDOUBLE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__Zd;
      goto __pyx_L13;
    }

    /* "numpy.pxd":272
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 */
    __pyx_t_1 = (__pyx_v_t == NPY_CLONGDOUBLE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__Zg;
      goto __pyx_L13;
    }

    /* "numpy.pxd":273
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
    __pyx_t_1 = (__pyx_v_t == NPY_OBJECT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__O;
      goto __pyx_L13;
    }
    /*else*/ {

      /* "numpy.pxd":275
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *                 info.format = f
 *                 return
 */
      __pyx_t_4 = PyInt_FromLong(__pyx_v_t); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_77), __pyx_t_4); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_8));
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_t_8));
      __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
      __pyx_t_8 = 0;
      __pyx_t_8 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      {__pyx_filename = __pyx_f[2]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L13:;

    /* "numpy.pxd":276
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f             # <<<<<<<<<<<<<<
 *                 return
 *             else:
 */
    __pyx_v_info->format = __pyx_v_f;

    /* "numpy.pxd":277
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f
 *                 return             # <<<<<<<<<<<<<<
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L11;
  }
  /*else*/ {

    /* "numpy.pxd":279
 *                 return
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)             # <<<<<<<<<<<<<<
 *                 info.format[0] = '^' # Native data types, manual alignment
 *                 offset = 0
 */
    __pyx_v_info->format = ((char *)malloc(255));

    /* "numpy.pxd":280
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 *                 info.format[0] = '^' # Native data types, manual alignment             # <<<<<<<<<<<<<<
 *                 offset = 0
 *                 f = _util_dtypestring(descr, info.format + 1,
 */
    (__pyx_v_info->format[0]) = '^';

    /* "numpy.pxd":281
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 *                 info.format[0] = '^' # Native data types, manual alignment
 *                 offset = 0             # <<<<<<<<<<<<<<
 *                 f = _util_dtypestring(descr, info.format + 1,
 *                                       info.format + _buffer_format_string_len,
 */
    __pyx_v_offset = 0;

    /* "numpy.pxd":284
 *                 f = _util_dtypestring(descr, info.format + 1,
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)             # <<<<<<<<<<<<<<
 *                 f[0] = 0 # Terminate format string
 * 
 */
    __pyx_t_9 = __pyx_f_5numpy__util_dtypestring(__pyx_v_descr, (__pyx_v_info->format + 1), (__pyx_v_info->format + 255), (&__pyx_v_offset)); if (unlikely(__pyx_t_9 == NULL)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_f = __pyx_t_9;

    /* "numpy.pxd":285
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)
 *                 f[0] = 0 # Terminate format string             # <<<<<<<<<<<<<<
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 */
    (__pyx_v_f[0]) = 0;
  }
  __pyx_L11:;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.ndarray.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info != NULL && __pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = NULL;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info != NULL && __pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(Py_None);
    __Pyx_DECREF(Py_None); __pyx_v_info->obj = NULL;
  }
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_descr);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info); /*proto*/
static void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__ (wrapper)", 0);
  __pyx_pf_5numpy_7ndarray_2__releasebuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info));
  __Pyx_RefNannyFinishContext();
}

/* "numpy.pxd":287
 *                 f[0] = 0 # Terminate format string
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 */

static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__releasebuffer__", 0);

  /* "numpy.pxd":288
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_t_1 = PyArray_HASFIELDS(__pyx_v_self);
  if (__pyx_t_1) {

    /* "numpy.pxd":289
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)             # <<<<<<<<<<<<<<
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 stdlib.free(info.strides)
 */
    free(__pyx_v_info->format);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "numpy.pxd":290
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.strides)
 *                 # info.shape was stored after info.strides in the same block
 */
  __pyx_t_1 = ((sizeof(npy_intp)) != (sizeof(Py_ssize_t)));
  if (__pyx_t_1) {

    /* "numpy.pxd":291
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 stdlib.free(info.strides)             # <<<<<<<<<<<<<<
 *                 # info.shape was stored after info.strides in the same block
 * 
 */
    free(__pyx_v_info->strides);
    goto __pyx_L4;
  }
  __pyx_L4:;

  __Pyx_RefNannyFinishContext();
}

/* "numpy.pxd":767
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 0);

  /* "numpy.pxd":768
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 768; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":770
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 0);

  /* "numpy.pxd":771
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 771; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":773
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 0);

  /* "numpy.pxd":774
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":776
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 0);

  /* "numpy.pxd":777
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":779
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 0);

  /* "numpy.pxd":780
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 780; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":782
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:             # <<<<<<<<<<<<<<
 *     # Recursive utility function used in __getbuffer__ to get format
 *     # string. The new location in the format string is returned.
 */

static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *__pyx_v_descr, char *__pyx_v_f, char *__pyx_v_end, int *__pyx_v_offset) {
  PyArray_Descr *__pyx_v_child = 0;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  PyObject *__pyx_v_fields = 0;
  PyObject *__pyx_v_childname = NULL;
  PyObject *__pyx_v_new_offset = NULL;
  PyObject *__pyx_v_t = NULL;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  long __pyx_t_10;
  char *__pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_util_dtypestring", 0);

  /* "numpy.pxd":789
 *     cdef int delta_offset
 *     cdef tuple i
 *     cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 *     cdef tuple fields
 */
  __pyx_v_endian_detector = 1;

  /* "numpy.pxd":790
 *     cdef tuple i
 *     cdef int endian_detector = 1
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 *     cdef tuple fields
 * 
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "numpy.pxd":793
 *     cdef tuple fields
 * 
 *     for childname in descr.names:             # <<<<<<<<<<<<<<
 *         fields = descr.fields[childname]
 *         child, new_offset = fields
 */
  if (unlikely(((PyObject *)__pyx_v_descr->names) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable"); {__pyx_filename = __pyx_f[2]; __pyx_lineno = 793; __pyx_clineno = __LINE__; goto __pyx_L1_error;} 
  }
  __pyx_t_1 = ((PyObject *)__pyx_v_descr->names); __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++;
    __Pyx_XDECREF(__pyx_v_childname);
    __pyx_v_childname = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "numpy.pxd":794
 * 
 *     for childname in descr.names:
 *         fields = descr.fields[childname]             # <<<<<<<<<<<<<<
 *         child, new_offset = fields
 * 
 */
    __pyx_t_3 = PyObject_GetItem(__pyx_v_descr->fields, __pyx_v_childname); if (!__pyx_t_3) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(PyTuple_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected tuple, got %.200s", Py_TYPE(__pyx_t_3)->tp_name), 0))) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF(((PyObject *)__pyx_v_fields));
    __pyx_v_fields = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "numpy.pxd":795
 *     for childname in descr.names:
 *         fields = descr.fields[childname]
 *         child, new_offset = fields             # <<<<<<<<<<<<<<
 * 
 *         if (end - f) - (new_offset - offset[0]) < 15:
 */
    if (likely(PyTuple_CheckExact(((PyObject *)__pyx_v_fields)))) {
      PyObject* sequence = ((PyObject *)__pyx_v_fields);
      if (unlikely(PyTuple_GET_SIZE(sequence) != 2)) {
        if (PyTuple_GET_SIZE(sequence) > 2) __Pyx_RaiseTooManyValuesError(2);
        else __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(sequence));
        {__pyx_filename = __pyx_f[2]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
    } else {
      __Pyx_UnpackTupleError(((PyObject *)__pyx_v_fields), 2);
      {__pyx_filename = __pyx_f[2]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_dtype))))) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF(((PyObject *)__pyx_v_child));
    __pyx_v_child = ((PyArray_Descr *)__pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_v_new_offset);
    __pyx_v_new_offset = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "numpy.pxd":797
 *         child, new_offset = fields
 * 
 *         if (end - f) - (new_offset - offset[0]) < 15:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 */
    __pyx_t_4 = PyInt_FromLong((__pyx_v_end - __pyx_v_f)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 797; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyInt_FromLong((__pyx_v_offset[0])); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 797; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyNumber_Subtract(__pyx_v_new_offset, __pyx_t_3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 797; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Subtract(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 797; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_3, __pyx_int_15, Py_LT); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 797; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 797; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_6) {

      /* "numpy.pxd":798
 * 
 *         if (end - f) - (new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == '>' and little_endian) or
 */
      __pyx_t_5 = PyObject_Call(__pyx_builtin_RuntimeError, ((PyObject *)__pyx_k_tuple_79), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      {__pyx_filename = __pyx_f[2]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "numpy.pxd":800
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == '>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == '<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_6 = (__pyx_v_child->byteorder == '>');
    if (__pyx_t_6) {
      __pyx_t_7 = __pyx_v_little_endian;
    } else {
      __pyx_t_7 = __pyx_t_6;
    }
    if (!__pyx_t_7) {

      /* "numpy.pxd":801
 * 
 *         if ((child.byteorder == '>' and little_endian) or
 *             (child.byteorder == '<' and not little_endian)):             # <<<<<<<<<<<<<<
 *             raise ValueError(u"Non-native byte order not supported")
 *             # One could encode it in the format string and have Cython
 */
      __pyx_t_6 = (__pyx_v_child->byteorder == '<');
      if (__pyx_t_6) {
        __pyx_t_8 = (!__pyx_v_little_endian);
        __pyx_t_9 = __pyx_t_8;
      } else {
        __pyx_t_9 = __pyx_t_6;
      }
      __pyx_t_6 = __pyx_t_9;
    } else {
      __pyx_t_6 = __pyx_t_7;
    }
    if (__pyx_t_6) {

      /* "numpy.pxd":802
 *         if ((child.byteorder == '>' and little_endian) or
 *             (child.byteorder == '<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
      __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_80), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      {__pyx_filename = __pyx_f[2]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }
    __pyx_L6:;

    /* "numpy.pxd":812
 * 
 *         # Output padding bytes
 *         while offset[0] < new_offset:             # <<<<<<<<<<<<<<
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 */
    while (1) {
      __pyx_t_5 = PyInt_FromLong((__pyx_v_offset[0])); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_v_new_offset, Py_LT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!__pyx_t_6) break;

      /* "numpy.pxd":813
 *         # Output padding bytes
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte             # <<<<<<<<<<<<<<
 *             f += 1
 *             offset[0] += 1
 */
      (__pyx_v_f[0]) = 120;

      /* "numpy.pxd":814
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte
 *             f += 1             # <<<<<<<<<<<<<<
 *             offset[0] += 1
 * 
 */
      __pyx_v_f = (__pyx_v_f + 1);

      /* "numpy.pxd":815
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 *             offset[0] += 1             # <<<<<<<<<<<<<<
 * 
 *         offset[0] += child.itemsize
 */
      __pyx_t_10 = 0;
      (__pyx_v_offset[__pyx_t_10]) = ((__pyx_v_offset[__pyx_t_10]) + 1);
    }

    /* "numpy.pxd":817
 *             offset[0] += 1
 * 
 *         offset[0] += child.itemsize             # <<<<<<<<<<<<<<
 * 
 *         if not PyDataType_HASFIELDS(child):
 */
    __pyx_t_10 = 0;
    (__pyx_v_offset[__pyx_t_10]) = ((__pyx_v_offset[__pyx_t_10]) + __pyx_v_child->elsize);

    /* "numpy.pxd":819
 *         offset[0] += child.itemsize
 * 
 *         if not PyDataType_HASFIELDS(child):             # <<<<<<<<<<<<<<
 *             t = child.type_num
 *             if end - f < 5:
 */
    __pyx_t_6 = (!PyDataType_HASFIELDS(__pyx_v_child));
    if (__pyx_t_6) {

      /* "numpy.pxd":820
 * 
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num             # <<<<<<<<<<<<<<
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")
 */
      __pyx_t_3 = PyInt_FromLong(__pyx_v_child->type_num); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_v_t);
      __pyx_v_t = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "numpy.pxd":821
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num
 *             if end - f < 5:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(u"Format string allocated too short.")
 * 
 */
      __pyx_t_6 = ((__pyx_v_end - __pyx_v_f) < 5);
      if (__pyx_t_6) {

        /* "numpy.pxd":822
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
        __pyx_t_3 = PyObject_Call(__pyx_builtin_RuntimeError, ((PyObject *)__pyx_k_tuple_82), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 822; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        {__pyx_filename = __pyx_f[2]; __pyx_lineno = 822; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L10;
      }
      __pyx_L10:;

      /* "numpy.pxd":825
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_BYTE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 825; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 825; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 825; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 98;
        goto __pyx_L11;
      }

      /* "numpy.pxd":826
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"             # <<<<<<<<<<<<<<
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_UBYTE); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 66;
        goto __pyx_L11;
      }

      /* "numpy.pxd":827
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"             # <<<<<<<<<<<<<<
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_SHORT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 104;
        goto __pyx_L11;
      }

      /* "numpy.pxd":828
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"             # <<<<<<<<<<<<<<
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_USHORT); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 72;
        goto __pyx_L11;
      }

      /* "numpy.pxd":829
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_INT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 105;
        goto __pyx_L11;
      }

      /* "numpy.pxd":830
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_UINT); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 73;
        goto __pyx_L11;
      }

      /* "numpy.pxd":831
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_LONG); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 108;
        goto __pyx_L11;
      }

      /* "numpy.pxd":832
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_ULONG); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 76;
        goto __pyx_L11;
      }

      /* "numpy.pxd":833
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_LONGLONG); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 113;
        goto __pyx_L11;
      }

      /* "numpy.pxd":834
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_ULONGLONG); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 81;
        goto __pyx_L11;
      }

      /* "numpy.pxd":835
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"             # <<<<<<<<<<<<<<
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_FLOAT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 102;
        goto __pyx_L11;
      }

      /* "numpy.pxd":836
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 */
      __pyx_t_5 = PyInt_FromLong(NPY_DOUBLE); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 100;
        goto __pyx_L11;
      }

      /* "numpy.pxd":837
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"             # <<<<<<<<<<<<<<
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 */
      __pyx_t_3 = PyInt_FromLong(NPY_LONGDOUBLE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 103;
        goto __pyx_L11;
      }

      /* "numpy.pxd":838
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf             # <<<<<<<<<<<<<<
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 */
      __pyx_t_5 = PyInt_FromLong(NPY_CFLOAT); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 102;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L11;
      }

      /* "numpy.pxd":839
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd             # <<<<<<<<<<<<<<
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_CDOUBLE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 100;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L11;
      }

      /* "numpy.pxd":840
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg             # <<<<<<<<<<<<<<
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 */
      __pyx_t_5 = PyInt_FromLong(NPY_CLONGDOUBLE); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 103;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L11;
      }

      /* "numpy.pxd":841
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
      __pyx_t_3 = PyInt_FromLong(NPY_OBJECT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 79;
        goto __pyx_L11;
      }
      /*else*/ {

        /* "numpy.pxd":843
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *             f += 1
 *         else:
 */
        __pyx_t_5 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_77), __pyx_v_t); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_5));
        __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_5));
        __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
        __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        {__pyx_filename = __pyx_f[2]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L11:;

      /* "numpy.pxd":844
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *             f += 1             # <<<<<<<<<<<<<<
 *         else:
 *             # Cython ignores struct boundary information ("T{...}"),
 */
      __pyx_v_f = (__pyx_v_f + 1);
      goto __pyx_L9;
    }
    /*else*/ {

      /* "numpy.pxd":848
 *             # Cython ignores struct boundary information ("T{...}"),
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
      __pyx_t_11 = __pyx_f_5numpy__util_dtypestring(__pyx_v_child, __pyx_v_f, __pyx_v_end, __pyx_v_offset); if (unlikely(__pyx_t_11 == NULL)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 848; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_f = __pyx_t_11;
    }
    __pyx_L9:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "numpy.pxd":849
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)
 *     return f             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_f;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("numpy._util_dtypestring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_child);
  __Pyx_XDECREF(__pyx_v_fields);
  __Pyx_XDECREF(__pyx_v_childname);
  __Pyx_XDECREF(__pyx_v_new_offset);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":964
 * 
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *      cdef PyObject* baseptr
 *      if base is None:
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  PyObject *__pyx_v_baseptr;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("set_array_base", 0);

  /* "numpy.pxd":966
 * cdef inline void set_array_base(ndarray arr, object base):
 *      cdef PyObject* baseptr
 *      if base is None:             # <<<<<<<<<<<<<<
 *          baseptr = NULL
 *      else:
 */
  __pyx_t_1 = (__pyx_v_base == Py_None);
  if (__pyx_t_1) {

    /* "numpy.pxd":967
 *      cdef PyObject* baseptr
 *      if base is None:
 *          baseptr = NULL             # <<<<<<<<<<<<<<
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!
 */
    __pyx_v_baseptr = NULL;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "numpy.pxd":969
 *          baseptr = NULL
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!             # <<<<<<<<<<<<<<
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)
 */
    Py_INCREF(__pyx_v_base);

    /* "numpy.pxd":970
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!
 *          baseptr = <PyObject*>base             # <<<<<<<<<<<<<<
 *      Py_XDECREF(arr.base)
 *      arr.base = baseptr
 */
    __pyx_v_baseptr = ((PyObject *)__pyx_v_base);
  }
  __pyx_L3:;

  /* "numpy.pxd":971
 *          Py_INCREF(base) # important to do this before decref below!
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)             # <<<<<<<<<<<<<<
 *      arr.base = baseptr
 * 
 */
  Py_XDECREF(__pyx_v_arr->base);

  /* "numpy.pxd":972
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)
 *      arr.base = baseptr             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  __pyx_v_arr->base = __pyx_v_baseptr;

  __Pyx_RefNannyFinishContext();
}

/* "numpy.pxd":974
 *      arr.base = baseptr
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     if arr.base is NULL:
 *         return None
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 0);

  /* "numpy.pxd":975
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  __pyx_t_1 = (__pyx_v_arr->base == NULL);
  if (__pyx_t_1) {

    /* "numpy.pxd":976
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     else:
 *         return <object>arr.base
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "numpy.pxd":978
 *         return None
 *     else:
 *         return <object>arr.base             # <<<<<<<<<<<<<<
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_arr->base));
    __pyx_r = ((PyObject *)__pyx_v_arr->base);
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    __Pyx_NAMESTR("_ccode"),
    0, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_71, __pyx_k_71, sizeof(__pyx_k_71), 0, 1, 0, 0},
  {&__pyx_kp_u_73, __pyx_k_73, sizeof(__pyx_k_73), 0, 1, 0, 0},
  {&__pyx_kp_u_75, __pyx_k_75, sizeof(__pyx_k_75), 0, 1, 0, 0},
  {&__pyx_kp_u_77, __pyx_k_77, sizeof(__pyx_k_77), 0, 1, 0, 0},
  {&__pyx_kp_u_78, __pyx_k_78, sizeof(__pyx_k_78), 0, 1, 0, 0},
  {&__pyx_kp_u_81, __pyx_k_81, sizeof(__pyx_k_81), 0, 1, 0, 0},
  {&__pyx_kp_s_85, __pyx_k_85, sizeof(__pyx_k_85), 0, 0, 1, 0},
  {&__pyx_n_s_86, __pyx_k_86, sizeof(__pyx_k_86), 0, 0, 1, 1},
  {&__pyx_n_s__RuntimeError, __pyx_k__RuntimeError, sizeof(__pyx_k__RuntimeError), 0, 0, 1, 1},
  {&__pyx_n_s__ValueError, __pyx_k__ValueError, sizeof(__pyx_k__ValueError), 0, 0, 1, 1},
  {&__pyx_n_s____main__, __pyx_k____main__, sizeof(__pyx_k____main__), 0, 0, 1, 1},
  {&__pyx_n_s____test__, __pyx_k____test__, sizeof(__pyx_k____test__), 0, 0, 1, 1},
  {&__pyx_n_s___ipix, __pyx_k___ipix, sizeof(__pyx_k___ipix), 0, 0, 1, 1},
  {&__pyx_n_s___ipnest, __pyx_k___ipnest, sizeof(__pyx_k___ipnest), 0, 0, 1, 1},
  {&__pyx_n_s___ipring, __pyx_k___ipring, sizeof(__pyx_k___ipring), 0, 0, 1, 1},
  {&__pyx_n_s___npix, __pyx_k___npix, sizeof(__pyx_k___npix), 0, 0, 1, 1},
  {&__pyx_n_s___nside, __pyx_k___nside, sizeof(__pyx_k___nside), 0, 0, 1, 1},
  {&__pyx_n_s___phi, __pyx_k___phi, sizeof(__pyx_k___phi), 0, 0, 1, 1},
  {&__pyx_n_s___theta, __pyx_k___theta, sizeof(__pyx_k___theta), 0, 0, 1, 1},
  {&__pyx_n_s___vec, __pyx_k___vec, sizeof(__pyx_k___vec), 0, 0, 1, 1},
  {&__pyx_n_s__ang2pix_nest, __pyx_k__ang2pix_nest, sizeof(__pyx_k__ang2pix_nest), 0, 0, 1, 1},
  {&__pyx_n_s__ang2pix_nest64, __pyx_k__ang2pix_nest64, sizeof(__pyx_k__ang2pix_nest64), 0, 0, 1, 1},
  {&__pyx_n_s__ang2pix_ring, __pyx_k__ang2pix_ring, sizeof(__pyx_k__ang2pix_ring), 0, 0, 1, 1},
  {&__pyx_n_s__ang2pix_ring64, __pyx_k__ang2pix_ring64, sizeof(__pyx_k__ang2pix_ring64), 0, 0, 1, 1},
  {&__pyx_n_s__ang2vec, __pyx_k__ang2vec, sizeof(__pyx_k__ang2vec), 0, 0, 1, 1},
  {&__pyx_n_s__buffered, __pyx_k__buffered, sizeof(__pyx_k__buffered), 0, 0, 1, 1},
  {&__pyx_n_s__casting, __pyx_k__casting, sizeof(__pyx_k__casting), 0, 0, 1, 1},
  {&__pyx_n_s__citer, __pyx_k__citer, sizeof(__pyx_k__citer), 0, 0, 1, 1},
  {&__pyx_n_s__dtype, __pyx_k__dtype, sizeof(__pyx_k__dtype), 0, 0, 1, 1},
  {&__pyx_n_s__empty, __pyx_k__empty, sizeof(__pyx_k__empty), 0, 0, 1, 1},
  {&__pyx_n_s__external_loop, __pyx_k__external_loop, sizeof(__pyx_k__external_loop), 0, 0, 1, 1},
  {&__pyx_n_s__f8, __pyx_k__f8, sizeof(__pyx_k__f8), 0, 0, 1, 1},
  {&__pyx_n_s__flags, __pyx_k__flags, sizeof(__pyx_k__flags), 0, 0, 1, 1},
  {&__pyx_n_s__i8, __pyx_k__i8, sizeof(__pyx_k__i8), 0, 0, 1, 1},
  {&__pyx_n_s__int, __pyx_k__int, sizeof(__pyx_k__int), 0, 0, 1, 1},
  {&__pyx_n_s__ipix, __pyx_k__ipix, sizeof(__pyx_k__ipix), 0, 0, 1, 1},
  {&__pyx_n_s__ipnest, __pyx_k__ipnest, sizeof(__pyx_k__ipnest), 0, 0, 1, 1},
  {&__pyx_n_s__ipring, __pyx_k__ipring, sizeof(__pyx_k__ipring), 0, 0, 1, 1},
  {&__pyx_n_s__iter, __pyx_k__iter, sizeof(__pyx_k__iter), 0, 0, 1, 1},
  {&__pyx_n_s__nditer, __pyx_k__nditer, sizeof(__pyx_k__nditer), 0, 0, 1, 1},
  {&__pyx_n_s__nest2ring, __pyx_k__nest2ring, sizeof(__pyx_k__nest2ring), 0, 0, 1, 1},
  {&__pyx_n_s__nest2ring64, __pyx_k__nest2ring64, sizeof(__pyx_k__nest2ring64), 0, 0, 1, 1},
  {&__pyx_n_s__npix, __pyx_k__npix, sizeof(__pyx_k__npix), 0, 0, 1, 1},
  {&__pyx_n_s__npix2nside, __pyx_k__npix2nside, sizeof(__pyx_k__npix2nside), 0, 0, 1, 1},
  {&__pyx_n_s__npix2nside64, __pyx_k__npix2nside64, sizeof(__pyx_k__npix2nside64), 0, 0, 1, 1},
  {&__pyx_n_s__nside, __pyx_k__nside, sizeof(__pyx_k__nside), 0, 0, 1, 1},
  {&__pyx_n_s__nside2npix, __pyx_k__nside2npix, sizeof(__pyx_k__nside2npix), 0, 0, 1, 1},
  {&__pyx_n_s__nside2npix64, __pyx_k__nside2npix64, sizeof(__pyx_k__nside2npix64), 0, 0, 1, 1},
  {&__pyx_n_s__numpy, __pyx_k__numpy, sizeof(__pyx_k__numpy), 0, 0, 1, 1},
  {&__pyx_n_s__op_dtypes, __pyx_k__op_dtypes, sizeof(__pyx_k__op_dtypes), 0, 0, 1, 1},
  {&__pyx_n_s__op_flags, __pyx_k__op_flags, sizeof(__pyx_k__op_flags), 0, 0, 1, 1},
  {&__pyx_n_s__phi, __pyx_k__phi, sizeof(__pyx_k__phi), 0, 0, 1, 1},
  {&__pyx_n_s__pix2ang_nest, __pyx_k__pix2ang_nest, sizeof(__pyx_k__pix2ang_nest), 0, 0, 1, 1},
  {&__pyx_n_s__pix2ang_nest64, __pyx_k__pix2ang_nest64, sizeof(__pyx_k__pix2ang_nest64), 0, 0, 1, 1},
  {&__pyx_n_s__pix2ang_ring, __pyx_k__pix2ang_ring, sizeof(__pyx_k__pix2ang_ring), 0, 0, 1, 1},
  {&__pyx_n_s__pix2ang_ring64, __pyx_k__pix2ang_ring64, sizeof(__pyx_k__pix2ang_ring64), 0, 0, 1, 1},
  {&__pyx_n_s__pix2vec_nest, __pyx_k__pix2vec_nest, sizeof(__pyx_k__pix2vec_nest), 0, 0, 1, 1},
  {&__pyx_n_s__pix2vec_nest64, __pyx_k__pix2vec_nest64, sizeof(__pyx_k__pix2vec_nest64), 0, 0, 1, 1},
  {&__pyx_n_s__pix2vec_ring, __pyx_k__pix2vec_ring, sizeof(__pyx_k__pix2vec_ring), 0, 0, 1, 1},
  {&__pyx_n_s__pix2vec_ring64, __pyx_k__pix2vec_ring64, sizeof(__pyx_k__pix2vec_ring64), 0, 0, 1, 1},
  {&__pyx_n_s__range, __pyx_k__range, sizeof(__pyx_k__range), 0, 0, 1, 1},
  {&__pyx_n_s__readonly, __pyx_k__readonly, sizeof(__pyx_k__readonly), 0, 0, 1, 1},
  {&__pyx_n_s__ring2nest, __pyx_k__ring2nest, sizeof(__pyx_k__ring2nest), 0, 0, 1, 1},
  {&__pyx_n_s__ring2nest64, __pyx_k__ring2nest64, sizeof(__pyx_k__ring2nest64), 0, 0, 1, 1},
  {&__pyx_n_s__shape, __pyx_k__shape, sizeof(__pyx_k__shape), 0, 0, 1, 1},
  {&__pyx_n_s__size, __pyx_k__size, sizeof(__pyx_k__size), 0, 0, 1, 1},
  {&__pyx_n_s__theta, __pyx_k__theta, sizeof(__pyx_k__theta), 0, 0, 1, 1},
  {&__pyx_n_s__unsafe, __pyx_k__unsafe, sizeof(__pyx_k__unsafe), 0, 0, 1, 1},
  {&__pyx_n_s__vec, __pyx_k__vec, sizeof(__pyx_k__vec), 0, 0, 1, 1},
  {&__pyx_n_s__vec2ang, __pyx_k__vec2ang, sizeof(__pyx_k__vec2ang), 0, 0, 1, 1},
  {&__pyx_n_s__vec2pix_nest, __pyx_k__vec2pix_nest, sizeof(__pyx_k__vec2pix_nest), 0, 0, 1, 1},
  {&__pyx_n_s__vec2pix_nest64, __pyx_k__vec2pix_nest64, sizeof(__pyx_k__vec2pix_nest64), 0, 0, 1, 1},
  {&__pyx_n_s__vec2pix_ring, __pyx_k__vec2pix_ring, sizeof(__pyx_k__vec2pix_ring), 0, 0, 1, 1},
  {&__pyx_n_s__vec2pix_ring64, __pyx_k__vec2pix_ring64, sizeof(__pyx_k__vec2pix_ring64), 0, 0, 1, 1},
  {&__pyx_n_s__vec_a, __pyx_k__vec_a, sizeof(__pyx_k__vec_a), 0, 0, 1, 1},
  {&__pyx_n_s__writeonly, __pyx_k__writeonly, sizeof(__pyx_k__writeonly), 0, 0, 1, 1},
  {&__pyx_n_s__zerosize_ok, __pyx_k__zerosize_ok, sizeof(__pyx_k__zerosize_ok), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetName(__pyx_b, __pyx_n_s__range); if (!__pyx_builtin_range) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_ValueError = __Pyx_GetName(__pyx_b, __pyx_n_s__ValueError); if (!__pyx_builtin_ValueError) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_RuntimeError = __Pyx_GetName(__pyx_b, __pyx_n_s__RuntimeError); if (!__pyx_builtin_RuntimeError) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "chealpy/_ccode.pyx":294
 * def vec2pix_ring (nside,vec, ipix = None):
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape             # <<<<<<<<<<<<<<
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')
 * 
 */
  __pyx_k_tuple_1 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_1);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_1, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_1, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_1));
  __pyx_k_tuple_2 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_2);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_2, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_2, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_2));
  __pyx_k_tuple_3 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_3);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_3, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_3, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_3));

  /* "chealpy/_ccode.pyx":297
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','f8','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 */
  __pyx_k_tuple_4 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_4);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_4, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_4, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_4));
  __pyx_k_tuple_5 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_5);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_5, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_5, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_5));
  __pyx_k_tuple_6 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_6);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_6, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_6, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_6));

  /* "chealpy/_ccode.pyx":306
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 */
  __pyx_k_tuple_7 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_7);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_7, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_7));
  __pyx_k_tuple_8 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_8, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_8, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_8));

  /* "chealpy/_ccode.pyx":326
 * def vec2pix_nest (nside,vec, ipix = None):
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape             # <<<<<<<<<<<<<<
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')
 * 
 */
  __pyx_k_tuple_9 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_9);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_9, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_9, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_9));
  __pyx_k_tuple_10 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_10);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_10, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_10, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_10));
  __pyx_k_tuple_11 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_11);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_11, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_11, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_11));

  /* "chealpy/_ccode.pyx":329
 *   if ipix is None: ipix = numpy.empty(shape, dtype='int')
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','f8','f8','f8','int'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 */
  __pyx_k_tuple_12 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_12);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_12, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_12, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_12));
  __pyx_k_tuple_13 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_13);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_13, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_13, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_13));
  __pyx_k_tuple_14 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_14);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_14, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_14, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_14));

  /* "chealpy/_ccode.pyx":338
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 */
  __pyx_k_tuple_15 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_15);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_15, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_15));
  __pyx_k_tuple_16 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_16);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_16, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_16, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_16));

  /* "chealpy/_ccode.pyx":358
 * def vec2pix_ring64 (nside,vec, ipix = None):
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape             # <<<<<<<<<<<<<<
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')
 * 
 */
  __pyx_k_tuple_17 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 358; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_17);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_17, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_17, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_17));
  __pyx_k_tuple_18 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_18)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 358; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_18);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_18, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_18, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_18));
  __pyx_k_tuple_19 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_19)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 358; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_19);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_19, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_19, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_19));

  /* "chealpy/_ccode.pyx":361
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','f8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 */
  __pyx_k_tuple_20 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_20)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_20);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_20, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_20, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_20));
  __pyx_k_tuple_21 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_21)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_21);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_21, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_21, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_21));
  __pyx_k_tuple_22 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_22)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_22);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_22, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_22, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_22));

  /* "chealpy/_ccode.pyx":370
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 */
  __pyx_k_tuple_23 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_23)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_23);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_23, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_23));
  __pyx_k_tuple_24 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_24)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_24);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_24, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_24, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_24));

  /* "chealpy/_ccode.pyx":390
 * def vec2pix_nest64 (nside,vec, ipix = None):
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape             # <<<<<<<<<<<<<<
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')
 * 
 */
  __pyx_k_tuple_25 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_25)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 390; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_25);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_25, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_25, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_25));
  __pyx_k_tuple_26 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_26)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 390; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_26);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_26, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_26, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_26));
  __pyx_k_tuple_27 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_27)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 390; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_27);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_27, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_27, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_27));

  /* "chealpy/_ccode.pyx":393
 *   if ipix is None: ipix = numpy.empty(shape, dtype='i8')
 * 
 *   iter = numpy.nditer([nside,vec[...,0],vec[...,1],vec[...,2],ipix],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','f8','f8','f8','i8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['readonly'],['writeonly']],
 */
  __pyx_k_tuple_28 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_28)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_28);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_28, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_28, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_28));
  __pyx_k_tuple_29 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_29)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_29);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_29, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_29, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_29));
  __pyx_k_tuple_30 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_30)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_30);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_30, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_30, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_30));

  /* "chealpy/_ccode.pyx":402
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 */
  __pyx_k_tuple_31 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_31)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_31);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_31, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_31));
  __pyx_k_tuple_32 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_32)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_32);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_32, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_32, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_32));

  /* "chealpy/_ccode.pyx":423
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 */
  __pyx_k_tuple_33 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_33)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 423; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_33);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_33, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_33, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_33));

  /* "chealpy/_ccode.pyx":425
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','int','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 */
  __pyx_k_tuple_34 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_34)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_34);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_34, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_34, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_34));
  __pyx_k_tuple_35 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_35)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_35);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_35, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_35, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_35));
  __pyx_k_tuple_36 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_36)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_36);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_36, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_36, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_36));

  /* "chealpy/_ccode.pyx":434
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 */
  __pyx_k_tuple_37 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_37)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_37);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_37, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_37));
  __pyx_k_tuple_38 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_38)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_38);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_38, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_38, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_38));

  /* "chealpy/_ccode.pyx":455
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 */
  __pyx_k_tuple_39 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_39)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 455; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_39);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_39, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_39, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_39));

  /* "chealpy/_ccode.pyx":457
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],             # <<<<<<<<<<<<<<
 *        op_dtypes=['int','int','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 */
  __pyx_k_tuple_40 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_40)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_40);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_40, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_40, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_40));
  __pyx_k_tuple_41 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_41)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_41);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_41, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_41, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_41));
  __pyx_k_tuple_42 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_42)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_42);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_42, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_42, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_42));

  /* "chealpy/_ccode.pyx":466
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef long _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef long _nside
 */
  __pyx_k_tuple_43 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_43)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_43);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_43, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_43));
  __pyx_k_tuple_44 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_44)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_44);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_44, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_44, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_44));

  /* "chealpy/_ccode.pyx":487
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 */
  __pyx_k_tuple_45 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_45)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 487; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_45);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_45, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_45, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_45));

  /* "chealpy/_ccode.pyx":489
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','i8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 */
  __pyx_k_tuple_46 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_46)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_46);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_46, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_46, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_46));
  __pyx_k_tuple_47 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_47)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_47);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_47, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_47, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_47));
  __pyx_k_tuple_48 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_48)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_48);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_48, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_48, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_48));

  /* "chealpy/_ccode.pyx":498
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 */
  __pyx_k_tuple_49 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_49)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_49);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_49, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_49));
  __pyx_k_tuple_50 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_50)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_50);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_50, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_50, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_50));

  /* "chealpy/_ccode.pyx":519
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],
 */
  __pyx_k_tuple_51 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_51)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 519; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_51);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_51, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_51, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_51));

  /* "chealpy/_ccode.pyx":521
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 *   iter = numpy.nditer([nside,ipix,vec[...,0],vec[...,1],vec[...,2]],             # <<<<<<<<<<<<<<
 *        op_dtypes=['i8','i8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 */
  __pyx_k_tuple_52 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_52)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_52);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_52, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_52, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_52));
  __pyx_k_tuple_53 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_53)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_53);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_53, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_53, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_53));
  __pyx_k_tuple_54 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_54)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_54);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_54, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_54, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_54));

  /* "chealpy/_ccode.pyx":530
 *   cdef size_t size = npyiter.init(&citer, iter)
 *   cdef int64_t _ipix
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   cdef int64_t _nside
 */
  __pyx_k_tuple_55 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_55)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 530; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_55);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_55, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_55));
  __pyx_k_tuple_56 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_56)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 530; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_56);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_56, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_56, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_56));

  /* "chealpy/_ccode.pyx":775
 *   "ang2vec"
 *   shape = numpy.broadcast(1, theta,phi).shape
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 * 
 *   iter = numpy.nditer([theta,phi,vec[...,0],vec[...,1],vec[...,2]],
 */
  __pyx_k_tuple_57 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_57)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_57);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_57, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_57, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_57));

  /* "chealpy/_ccode.pyx":777
 *   if vec is None: vec = numpy.empty(shape, dtype=('f8', 3))
 * 
 *   iter = numpy.nditer([theta,phi,vec[...,0],vec[...,1],vec[...,2]],             # <<<<<<<<<<<<<<
 *        op_dtypes=['f8','f8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['writeonly'],['writeonly'],['writeonly']],
 */
  __pyx_k_tuple_58 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_58)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_58);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_58, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_58, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_58));
  __pyx_k_tuple_59 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_59)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_59);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_59, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_59, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_59));
  __pyx_k_tuple_60 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_60)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_60);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_60, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_60, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_60));

  /* "chealpy/_ccode.pyx":787
 *   cdef double _theta
 *   cdef double _phi
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   with nogil:
 */
  __pyx_k_tuple_61 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_61)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_61);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_61, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_61));
  __pyx_k_tuple_62 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_62)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_62);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_62, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_62, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_62));

  /* "chealpy/_ccode.pyx":806
 * def vec2ang (vec, theta = None,phi = None):
 *   "vec2ang"
 *   shape = numpy.broadcast(1, vec[...,0],vec[...,1],vec[...,2]).shape             # <<<<<<<<<<<<<<
 *   if theta is None: theta = numpy.empty(shape, dtype='f8')
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 */
  __pyx_k_tuple_63 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_63)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_63);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_63, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_63, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_63));
  __pyx_k_tuple_64 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_64)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_64);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_64, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_64, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_64));
  __pyx_k_tuple_65 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_65)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_65);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_65, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_65, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_65));

  /* "chealpy/_ccode.pyx":810
 *   if phi is None: phi = numpy.empty(shape, dtype='f8')
 * 
 *   iter = numpy.nditer([vec[...,0],vec[...,1],vec[...,2],theta,phi],             # <<<<<<<<<<<<<<
 *        op_dtypes=['f8','f8','f8','f8','f8'],
 *        op_flags=[['readonly'],['readonly'],['readonly'],['writeonly'],['writeonly']],
 */
  __pyx_k_tuple_66 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_66)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_66);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_66, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_66, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_66));
  __pyx_k_tuple_67 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_67)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_67);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_67, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_67, 1, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_67));
  __pyx_k_tuple_68 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_68)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_68);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_68, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_68, 1, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_68));

  /* "chealpy/_ccode.pyx":820
 *   cdef double _theta
 *   cdef double _phi
 *   cdef numpy.ndarray vec_a = numpy.empty(0, dtype=('f8', 3))             # <<<<<<<<<<<<<<
 *   cdef double * _vec = <double *>vec_a.data
 *   with nogil:
 */
  __pyx_k_tuple_69 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_69)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_69);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_69, 0, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_69));
  __pyx_k_tuple_70 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_70)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_70);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__f8));
  PyTuple_SET_ITEM(__pyx_k_tuple_70, 0, ((PyObject *)__pyx_n_s__f8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__f8));
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_70, 1, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_70));

  /* "numpy.pxd":214
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
  __pyx_k_tuple_72 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_72)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_72);
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_71));
  PyTuple_SET_ITEM(__pyx_k_tuple_72, 0, ((PyObject *)__pyx_kp_u_71));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_71));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_72));

  /* "numpy.pxd":218
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
  __pyx_k_tuple_74 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_74)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_74);
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_73));
  PyTuple_SET_ITEM(__pyx_k_tuple_74, 0, ((PyObject *)__pyx_kp_u_73));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_73));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_74));

  /* "numpy.pxd":256
 *                 if ((descr.byteorder == '>' and little_endian) or
 *                     (descr.byteorder == '<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
  __pyx_k_tuple_76 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_76)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 256; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_76);
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_75));
  PyTuple_SET_ITEM(__pyx_k_tuple_76, 0, ((PyObject *)__pyx_kp_u_75));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_75));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_76));

  /* "numpy.pxd":798
 * 
 *         if (end - f) - (new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == '>' and little_endian) or
 */
  __pyx_k_tuple_79 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_79)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_79);
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_78));
  PyTuple_SET_ITEM(__pyx_k_tuple_79, 0, ((PyObject *)__pyx_kp_u_78));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_78));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_79));

  /* "numpy.pxd":802
 *         if ((child.byteorder == '>' and little_endian) or
 *             (child.byteorder == '<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
  __pyx_k_tuple_80 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_80)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_80);
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_75));
  PyTuple_SET_ITEM(__pyx_k_tuple_80, 0, ((PyObject *)__pyx_kp_u_75));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_75));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_80));

  /* "numpy.pxd":822
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
  __pyx_k_tuple_82 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_82)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 822; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_82);
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_81));
  PyTuple_SET_ITEM(__pyx_k_tuple_82, 0, ((PyObject *)__pyx_kp_u_81));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_81));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_82));

  /* "chealpy/_ccode.pyx":40
 * 
 * 
 * def ang2pix_ring (nside,theta,phi, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 */
  __pyx_k_tuple_83 = PyTuple_New(12); if (unlikely(!__pyx_k_tuple_83)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_83);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 1, ((PyObject *)__pyx_n_s__theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 2, ((PyObject *)__pyx_n_s__phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 3, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 4, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 5, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 6, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 7, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 8, ((PyObject *)__pyx_n_s___theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 9, ((PyObject *)__pyx_n_s___phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 10, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 11, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_83));
  __pyx_k_codeobj_84 = (PyObject*)__Pyx_PyCode_New(4, 0, 12, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_83, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__ang2pix_ring, 40, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_84)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":71
 * 
 * 
 * def ang2pix_nest (nside,theta,phi, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 */
  __pyx_k_tuple_87 = PyTuple_New(12); if (unlikely(!__pyx_k_tuple_87)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_87);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 1, ((PyObject *)__pyx_n_s__theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 2, ((PyObject *)__pyx_n_s__phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 3, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 4, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 5, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 6, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 7, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 8, ((PyObject *)__pyx_n_s___theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 9, ((PyObject *)__pyx_n_s___phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 10, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 11, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_87));
  __pyx_k_codeobj_88 = (PyObject*)__Pyx_PyCode_New(4, 0, 12, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_87, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__ang2pix_nest, 71, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_88)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":102
 * 
 * 
 * def ang2pix_ring64 (nside,theta,phi, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 */
  __pyx_k_tuple_89 = PyTuple_New(12); if (unlikely(!__pyx_k_tuple_89)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_89);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 1, ((PyObject *)__pyx_n_s__theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 2, ((PyObject *)__pyx_n_s__phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 3, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 4, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 5, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 6, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 7, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 8, ((PyObject *)__pyx_n_s___theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 9, ((PyObject *)__pyx_n_s___phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 10, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 11, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_89));
  __pyx_k_codeobj_90 = (PyObject*)__Pyx_PyCode_New(4, 0, 12, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_89, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__ang2pix_ring64, 102, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_90)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":133
 * 
 * 
 * def ang2pix_nest64 (nside,theta,phi, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 */
  __pyx_k_tuple_91 = PyTuple_New(12); if (unlikely(!__pyx_k_tuple_91)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_91);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 1, ((PyObject *)__pyx_n_s__theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 2, ((PyObject *)__pyx_n_s__phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 3, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 4, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 5, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 6, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 7, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 8, ((PyObject *)__pyx_n_s___theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 9, ((PyObject *)__pyx_n_s___phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 10, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 11, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_91));
  __pyx_k_codeobj_92 = (PyObject*)__Pyx_PyCode_New(4, 0, 12, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_91, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__ang2pix_nest64, 133, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_92)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":164
 * 
 * 
 * def pix2ang_ring (nside,ipix, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_k_tuple_93 = PyTuple_New(12); if (unlikely(!__pyx_k_tuple_93)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_93);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 1, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 2, ((PyObject *)__pyx_n_s__theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 3, ((PyObject *)__pyx_n_s__phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 4, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 5, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 6, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 7, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 8, ((PyObject *)__pyx_n_s___theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 9, ((PyObject *)__pyx_n_s___phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 10, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 11, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_93));
  __pyx_k_codeobj_94 = (PyObject*)__Pyx_PyCode_New(4, 0, 12, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_93, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__pix2ang_ring, 164, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_94)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":196
 * 
 * 
 * def pix2ang_nest (nside,ipix, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_k_tuple_95 = PyTuple_New(12); if (unlikely(!__pyx_k_tuple_95)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_95);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 1, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 2, ((PyObject *)__pyx_n_s__theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 3, ((PyObject *)__pyx_n_s__phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 4, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 5, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 6, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 7, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 8, ((PyObject *)__pyx_n_s___theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 9, ((PyObject *)__pyx_n_s___phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 10, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 11, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_95));
  __pyx_k_codeobj_96 = (PyObject*)__Pyx_PyCode_New(4, 0, 12, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_95, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__pix2ang_nest, 196, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_96)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":228
 * 
 * 
 * def pix2ang_ring64 (nside,ipix, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_k_tuple_97 = PyTuple_New(12); if (unlikely(!__pyx_k_tuple_97)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 228; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_97);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 1, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 2, ((PyObject *)__pyx_n_s__theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 3, ((PyObject *)__pyx_n_s__phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 4, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 5, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 6, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 7, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 8, ((PyObject *)__pyx_n_s___theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 9, ((PyObject *)__pyx_n_s___phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 10, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 11, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_97));
  __pyx_k_codeobj_98 = (PyObject*)__Pyx_PyCode_New(4, 0, 12, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__pix2ang_ring64, 228, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_98)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 228; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":260
 * 
 * 
 * def pix2ang_nest64 (nside,ipix, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_k_tuple_99 = PyTuple_New(12); if (unlikely(!__pyx_k_tuple_99)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_99);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 1, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 2, ((PyObject *)__pyx_n_s__theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 3, ((PyObject *)__pyx_n_s__phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 4, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 5, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 6, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 7, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 8, ((PyObject *)__pyx_n_s___theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 9, ((PyObject *)__pyx_n_s___phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 10, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 11, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_99));
  __pyx_k_codeobj_100 = (PyObject*)__Pyx_PyCode_New(4, 0, 12, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_99, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__pix2ang_nest64, 260, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_100)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":292
 * 
 * 
 * def vec2pix_ring (nside,vec, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 */
  __pyx_k_tuple_101 = PyTuple_New(11); if (unlikely(!__pyx_k_tuple_101)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_101);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 1, ((PyObject *)__pyx_n_s__vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 2, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 7, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec_a));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 8, ((PyObject *)__pyx_n_s__vec_a));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec_a));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 9, ((PyObject *)__pyx_n_s___vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 10, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_101));
  __pyx_k_codeobj_102 = (PyObject*)__Pyx_PyCode_New(3, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_101, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__vec2pix_ring, 292, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_102)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":324
 * 
 * 
 * def vec2pix_nest (nside,vec, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 */
  __pyx_k_tuple_103 = PyTuple_New(11); if (unlikely(!__pyx_k_tuple_103)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_103);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 1, ((PyObject *)__pyx_n_s__vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 2, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 7, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec_a));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 8, ((PyObject *)__pyx_n_s__vec_a));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec_a));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 9, ((PyObject *)__pyx_n_s___vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 10, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_103));
  __pyx_k_codeobj_104 = (PyObject*)__Pyx_PyCode_New(3, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_103, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__vec2pix_nest, 324, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_104)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":356
 * 
 * 
 * def vec2pix_ring64 (nside,vec, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 */
  __pyx_k_tuple_105 = PyTuple_New(11); if (unlikely(!__pyx_k_tuple_105)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 356; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_105);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 1, ((PyObject *)__pyx_n_s__vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 2, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 7, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec_a));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 8, ((PyObject *)__pyx_n_s__vec_a));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec_a));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 9, ((PyObject *)__pyx_n_s___vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 10, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_105));
  __pyx_k_codeobj_106 = (PyObject*)__Pyx_PyCode_New(3, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_105, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__vec2pix_ring64, 356, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_106)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 356; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":388
 * 
 * 
 * def vec2pix_nest64 (nside,vec, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 */
  __pyx_k_tuple_107 = PyTuple_New(11); if (unlikely(!__pyx_k_tuple_107)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 388; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_107);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 1, ((PyObject *)__pyx_n_s__vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 2, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 7, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec_a));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 8, ((PyObject *)__pyx_n_s__vec_a));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec_a));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 9, ((PyObject *)__pyx_n_s___vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 10, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_107));
  __pyx_k_codeobj_108 = (PyObject*)__Pyx_PyCode_New(3, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_107, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__vec2pix_nest64, 388, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_108)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 388; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":420
 * 
 * 
 * def pix2vec_ring (nside,ipix, vec = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_k_tuple_109 = PyTuple_New(11); if (unlikely(!__pyx_k_tuple_109)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_109);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 1, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 2, ((PyObject *)__pyx_n_s__vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 7, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec_a));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 8, ((PyObject *)__pyx_n_s__vec_a));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec_a));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 9, ((PyObject *)__pyx_n_s___vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 10, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_109));
  __pyx_k_codeobj_110 = (PyObject*)__Pyx_PyCode_New(3, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_109, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__pix2vec_ring, 420, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_110)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":452
 * 
 * 
 * def pix2vec_nest (nside,ipix, vec = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_k_tuple_111 = PyTuple_New(11); if (unlikely(!__pyx_k_tuple_111)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 452; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_111);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 1, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 2, ((PyObject *)__pyx_n_s__vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 7, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec_a));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 8, ((PyObject *)__pyx_n_s__vec_a));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec_a));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 9, ((PyObject *)__pyx_n_s___vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 10, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_111));
  __pyx_k_codeobj_112 = (PyObject*)__Pyx_PyCode_New(3, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_111, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__pix2vec_nest, 452, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_112)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 452; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":484
 * 
 * 
 * def pix2vec_ring64 (nside,ipix, vec = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_k_tuple_113 = PyTuple_New(11); if (unlikely(!__pyx_k_tuple_113)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 484; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_113);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 1, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 2, ((PyObject *)__pyx_n_s__vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 7, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec_a));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 8, ((PyObject *)__pyx_n_s__vec_a));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec_a));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 9, ((PyObject *)__pyx_n_s___vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 10, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_113));
  __pyx_k_codeobj_114 = (PyObject*)__Pyx_PyCode_New(3, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_113, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__pix2vec_ring64, 484, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_114)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 484; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":516
 * 
 * 
 * def pix2vec_nest64 (nside,ipix, vec = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_k_tuple_115 = PyTuple_New(11); if (unlikely(!__pyx_k_tuple_115)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 516; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_115);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 1, ((PyObject *)__pyx_n_s__ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 2, ((PyObject *)__pyx_n_s__vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipix));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 7, ((PyObject *)__pyx_n_s___ipix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec_a));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 8, ((PyObject *)__pyx_n_s__vec_a));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec_a));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 9, ((PyObject *)__pyx_n_s___vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 10, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_115));
  __pyx_k_codeobj_116 = (PyObject*)__Pyx_PyCode_New(3, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_115, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__pix2vec_nest64, 516, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_116)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 516; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":548
 * 
 * 
 * def nest2ring (nside,ipnest, ipring = None):             # <<<<<<<<<<<<<<
 *   "nest2ring"
 *   shape = numpy.broadcast(1, nside,ipnest).shape
 */
  __pyx_k_tuple_117 = PyTuple_New(10); if (unlikely(!__pyx_k_tuple_117)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 548; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_117);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipnest));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 1, ((PyObject *)__pyx_n_s__ipnest));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipnest));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipring));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 2, ((PyObject *)__pyx_n_s__ipring));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipring));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipnest));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 7, ((PyObject *)__pyx_n_s___ipnest));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipnest));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipring));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 8, ((PyObject *)__pyx_n_s___ipring));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipring));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 9, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_117));
  __pyx_k_codeobj_118 = (PyObject*)__Pyx_PyCode_New(3, 0, 10, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_117, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__nest2ring, 548, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_118)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 548; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":577
 * 
 * 
 * def nest2ring64 (nside,ipnest, ipring = None):             # <<<<<<<<<<<<<<
 *   "nest2ring"
 *   shape = numpy.broadcast(1, nside,ipnest).shape
 */
  __pyx_k_tuple_119 = PyTuple_New(10); if (unlikely(!__pyx_k_tuple_119)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_119);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipnest));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 1, ((PyObject *)__pyx_n_s__ipnest));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipnest));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipring));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 2, ((PyObject *)__pyx_n_s__ipring));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipring));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipnest));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 7, ((PyObject *)__pyx_n_s___ipnest));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipnest));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipring));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 8, ((PyObject *)__pyx_n_s___ipring));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipring));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 9, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_119));
  __pyx_k_codeobj_120 = (PyObject*)__Pyx_PyCode_New(3, 0, 10, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__nest2ring64, 577, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_120)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":606
 * 
 * 
 * def ring2nest (nside,ipring, ipnest = None):             # <<<<<<<<<<<<<<
 *   "ring2nest"
 *   shape = numpy.broadcast(1, nside,ipring).shape
 */
  __pyx_k_tuple_121 = PyTuple_New(10); if (unlikely(!__pyx_k_tuple_121)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 606; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_121);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipring));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 1, ((PyObject *)__pyx_n_s__ipring));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipring));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipnest));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 2, ((PyObject *)__pyx_n_s__ipnest));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipnest));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipring));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 7, ((PyObject *)__pyx_n_s___ipring));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipring));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 8, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipnest));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 9, ((PyObject *)__pyx_n_s___ipnest));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipnest));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_121));
  __pyx_k_codeobj_122 = (PyObject*)__Pyx_PyCode_New(3, 0, 10, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__ring2nest, 606, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_122)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 606; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":635
 * 
 * 
 * def ring2nest64 (nside,ipring, ipnest = None):             # <<<<<<<<<<<<<<
 *   "ring2nest"
 *   shape = numpy.broadcast(1, nside,ipring).shape
 */
  __pyx_k_tuple_123 = PyTuple_New(10); if (unlikely(!__pyx_k_tuple_123)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_123);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipring));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 1, ((PyObject *)__pyx_n_s__ipring));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipring));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ipnest));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 2, ((PyObject *)__pyx_n_s__ipnest));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ipnest));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipring));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 7, ((PyObject *)__pyx_n_s___ipring));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipring));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 8, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___ipnest));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 9, ((PyObject *)__pyx_n_s___ipnest));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___ipnest));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_123));
  __pyx_k_codeobj_124 = (PyObject*)__Pyx_PyCode_New(3, 0, 10, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_123, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__ring2nest64, 635, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_124)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":664
 * 
 * 
 * def npix2nside (npix, nside = None):             # <<<<<<<<<<<<<<
 *   "npix2nside"
 *   shape = numpy.broadcast(1, npix).shape
 */
  __pyx_k_tuple_125 = PyTuple_New(8); if (unlikely(!__pyx_k_tuple_125)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 664; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_125);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__npix));
  PyTuple_SET_ITEM(__pyx_k_tuple_125, 0, ((PyObject *)__pyx_n_s__npix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__npix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_125, 1, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_125, 2, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_125, 3, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_125, 4, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_125, 5, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___npix));
  PyTuple_SET_ITEM(__pyx_k_tuple_125, 6, ((PyObject *)__pyx_n_s___npix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___npix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_125, 7, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_125));
  __pyx_k_codeobj_126 = (PyObject*)__Pyx_PyCode_New(2, 0, 8, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_125, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__npix2nside, 664, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_126)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 664; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":691
 * 
 * 
 * def npix2nside64 (npix, nside = None):             # <<<<<<<<<<<<<<
 *   "npix2nside"
 *   shape = numpy.broadcast(1, npix).shape
 */
  __pyx_k_tuple_127 = PyTuple_New(8); if (unlikely(!__pyx_k_tuple_127)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 691; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_127);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__npix));
  PyTuple_SET_ITEM(__pyx_k_tuple_127, 0, ((PyObject *)__pyx_n_s__npix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__npix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_127, 1, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_127, 2, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_127, 3, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_127, 4, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_127, 5, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___npix));
  PyTuple_SET_ITEM(__pyx_k_tuple_127, 6, ((PyObject *)__pyx_n_s___npix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___npix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_127, 7, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_127));
  __pyx_k_codeobj_128 = (PyObject*)__Pyx_PyCode_New(2, 0, 8, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_127, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__npix2nside64, 691, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_128)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 691; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":718
 * 
 * 
 * def nside2npix (nside, npix = None):             # <<<<<<<<<<<<<<
 *   "nside2npix"
 *   shape = numpy.broadcast(1, nside).shape
 */
  __pyx_k_tuple_129 = PyTuple_New(8); if (unlikely(!__pyx_k_tuple_129)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 718; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_129);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_129, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__npix));
  PyTuple_SET_ITEM(__pyx_k_tuple_129, 1, ((PyObject *)__pyx_n_s__npix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__npix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_129, 2, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_129, 3, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_129, 4, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_129, 5, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___npix));
  PyTuple_SET_ITEM(__pyx_k_tuple_129, 6, ((PyObject *)__pyx_n_s___npix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___npix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_129, 7, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_129));
  __pyx_k_codeobj_130 = (PyObject*)__Pyx_PyCode_New(2, 0, 8, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_129, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__nside2npix, 718, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_130)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 718; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":745
 * 
 * 
 * def nside2npix64 (nside, npix = None):             # <<<<<<<<<<<<<<
 *   "nside2npix"
 *   shape = numpy.broadcast(1, nside).shape
 */
  __pyx_k_tuple_131 = PyTuple_New(8); if (unlikely(!__pyx_k_tuple_131)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_131);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_131, 0, ((PyObject *)__pyx_n_s__nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__nside));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__npix));
  PyTuple_SET_ITEM(__pyx_k_tuple_131, 1, ((PyObject *)__pyx_n_s__npix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__npix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_131, 2, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_131, 3, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_131, 4, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_131, 5, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___npix));
  PyTuple_SET_ITEM(__pyx_k_tuple_131, 6, ((PyObject *)__pyx_n_s___npix));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___npix));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___nside));
  PyTuple_SET_ITEM(__pyx_k_tuple_131, 7, ((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___nside));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_131));
  __pyx_k_codeobj_132 = (PyObject*)__Pyx_PyCode_New(2, 0, 8, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_131, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__nside2npix64, 745, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_132)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":772
 * 
 * 
 * def ang2vec (theta,phi, vec = None):             # <<<<<<<<<<<<<<
 *   "ang2vec"
 *   shape = numpy.broadcast(1, theta,phi).shape
 */
  __pyx_k_tuple_133 = PyTuple_New(11); if (unlikely(!__pyx_k_tuple_133)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_133);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_133, 0, ((PyObject *)__pyx_n_s__theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_133, 1, ((PyObject *)__pyx_n_s__phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_133, 2, ((PyObject *)__pyx_n_s__vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_133, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_133, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_133, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_133, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_133, 7, ((PyObject *)__pyx_n_s___theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_133, 8, ((PyObject *)__pyx_n_s___phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec_a));
  PyTuple_SET_ITEM(__pyx_k_tuple_133, 9, ((PyObject *)__pyx_n_s__vec_a));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec_a));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_133, 10, ((PyObject *)__pyx_n_s___vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_133));
  __pyx_k_codeobj_134 = (PyObject*)__Pyx_PyCode_New(3, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_133, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__ang2vec, 772, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_134)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "chealpy/_ccode.pyx":804
 * 
 * 
 * def vec2ang (vec, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "vec2ang"
 *   shape = numpy.broadcast(1, vec[...,0],vec[...,1],vec[...,2]).shape
 */
  __pyx_k_tuple_135 = PyTuple_New(11); if (unlikely(!__pyx_k_tuple_135)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 804; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_135);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_135, 0, ((PyObject *)__pyx_n_s__vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_135, 1, ((PyObject *)__pyx_n_s__theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_135, 2, ((PyObject *)__pyx_n_s__phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__shape));
  PyTuple_SET_ITEM(__pyx_k_tuple_135, 3, ((PyObject *)__pyx_n_s__shape));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__shape));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__iter));
  PyTuple_SET_ITEM(__pyx_k_tuple_135, 4, ((PyObject *)__pyx_n_s__iter));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__iter));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__citer));
  PyTuple_SET_ITEM(__pyx_k_tuple_135, 5, ((PyObject *)__pyx_n_s__citer));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__citer));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__size));
  PyTuple_SET_ITEM(__pyx_k_tuple_135, 6, ((PyObject *)__pyx_n_s__size));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__size));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___theta));
  PyTuple_SET_ITEM(__pyx_k_tuple_135, 7, ((PyObject *)__pyx_n_s___theta));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___theta));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___phi));
  PyTuple_SET_ITEM(__pyx_k_tuple_135, 8, ((PyObject *)__pyx_n_s___phi));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___phi));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__vec_a));
  PyTuple_SET_ITEM(__pyx_k_tuple_135, 9, ((PyObject *)__pyx_n_s__vec_a));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__vec_a));
  __Pyx_INCREF(((PyObject *)__pyx_n_s___vec));
  PyTuple_SET_ITEM(__pyx_k_tuple_135, 10, ((PyObject *)__pyx_n_s___vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___vec));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_135));
  __pyx_k_codeobj_136 = (PyObject*)__Pyx_PyCode_New(3, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_135, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_85, __pyx_n_s__vec2ang, 804, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_136)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 804; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_15 = PyInt_FromLong(15); if (unlikely(!__pyx_int_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC init_ccode(void); /*proto*/
PyMODINIT_FUNC init_ccode(void)
#else
PyMODINIT_FUNC PyInit__ccode(void); /*proto*/
PyMODINIT_FUNC PyInit__ccode(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit__ccode(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4(__Pyx_NAMESTR("_ccode"), __pyx_methods, 0, 0, PYTHON_API_VERSION);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (!__pyx_m) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  #if PY_MAJOR_VERSION < 3
  Py_INCREF(__pyx_m);
  #endif
  __pyx_b = PyImport_AddModule(__Pyx_NAMESTR(__Pyx_BUILTIN_MODULE_NAME));
  if (!__pyx_b) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  if (__Pyx_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_module_is_main_chealpy___ccode) {
    if (__Pyx_SetAttrString(__pyx_m, "__name__", __pyx_n_s____main__) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  /*--- Type import code ---*/
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType("numpy", "dtype", sizeof(PyArray_Descr), 0); if (unlikely(!__pyx_ptype_5numpy_dtype)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType("numpy", "flatiter", sizeof(PyArrayIterObject), 0); if (unlikely(!__pyx_ptype_5numpy_flatiter)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType("numpy", "broadcast", sizeof(PyArrayMultiIterObject), 0); if (unlikely(!__pyx_ptype_5numpy_broadcast)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType("numpy", "ndarray", sizeof(PyArrayObject), 0); if (unlikely(!__pyx_ptype_5numpy_ndarray)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType("numpy", "ufunc", sizeof(PyUFuncObject), 0); if (unlikely(!__pyx_ptype_5numpy_ufunc)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 860; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/

  /* "chealpy/_ccode.pyx":8
 * cimport npyiter
 * from libc.stdint cimport *
 * import numpy             # <<<<<<<<<<<<<<
 * numpy.import_array()
 * 
 */
  __pyx_t_1 = __Pyx_Import(((PyObject *)__pyx_n_s__numpy), 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 8; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__numpy, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 8; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":9
 * from libc.stdint cimport *
 * import numpy
 * numpy.import_array()             # <<<<<<<<<<<<<<
 * 
 * cdef extern from "chealpix.h":
 */
  import_array();

  /* "chealpy/_ccode.pyx":40
 * 
 * 
 * def ang2pix_ring (nside,theta,phi, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_1ang2pix_ring, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__ang2pix_ring, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":71
 * 
 * 
 * def ang2pix_nest (nside,theta,phi, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_3ang2pix_nest, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__ang2pix_nest, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":102
 * 
 * 
 * def ang2pix_ring64 (nside,theta,phi, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_5ang2pix_ring64, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__ang2pix_ring64, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":133
 * 
 * 
 * def ang2pix_nest64 (nside,theta,phi, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting theta(0 to pi), phi(0 to 2 pi) to pix number"
 *   shape = numpy.broadcast(1, nside,theta,phi).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_7ang2pix_nest64, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__ang2pix_nest64, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":164
 * 
 * 
 * def pix2ang_ring (nside,ipix, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_9pix2ang_ring, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__pix2ang_ring, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":196
 * 
 * 
 * def pix2ang_nest (nside,ipix, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_11pix2ang_nest, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__pix2ang_nest, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":228
 * 
 * 
 * def pix2ang_ring64 (nside,ipix, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_13pix2ang_ring64, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 228; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__pix2ang_ring64, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 228; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":260
 * 
 * 
 * def pix2ang_nest64 (nside,ipix, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to theta(0 to pi), phi(0 to 2 pi)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_15pix2ang_nest64, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__pix2ang_nest64, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":292
 * 
 * 
 * def vec2pix_ring (nside,vec, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_17vec2pix_ring, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__vec2pix_ring, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":324
 * 
 * 
 * def vec2pix_nest (nside,vec, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_19vec2pix_nest, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__vec2pix_nest, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":356
 * 
 * 
 * def vec2pix_ring64 (nside,vec, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_21vec2pix_ring64, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 356; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__vec2pix_ring64, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 356; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":388
 * 
 * 
 * def vec2pix_nest64 (nside,vec, ipix = None):             # <<<<<<<<<<<<<<
 *   "Converting 3 vectors (..., 3) to pix number"
 *   shape = numpy.broadcast(1, nside,vec[...,0],vec[...,1],vec[...,2]).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_23vec2pix_nest64, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 388; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__vec2pix_nest64, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 388; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":420
 * 
 * 
 * def pix2vec_ring (nside,ipix, vec = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_25pix2vec_ring, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__pix2vec_ring, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":452
 * 
 * 
 * def pix2vec_nest (nside,ipix, vec = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_27pix2vec_nest, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 452; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__pix2vec_nest, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 452; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":484
 * 
 * 
 * def pix2vec_ring64 (nside,ipix, vec = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_29pix2vec_ring64, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 484; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__pix2vec_ring64, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 484; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":516
 * 
 * 
 * def pix2vec_nest64 (nside,ipix, vec = None):             # <<<<<<<<<<<<<<
 *   "Converting pix number to 3 vectors (..., 3)"
 *   shape = numpy.broadcast(1, nside,ipix).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_31pix2vec_nest64, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 516; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__pix2vec_nest64, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 516; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":548
 * 
 * 
 * def nest2ring (nside,ipnest, ipring = None):             # <<<<<<<<<<<<<<
 *   "nest2ring"
 *   shape = numpy.broadcast(1, nside,ipnest).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_33nest2ring, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 548; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__nest2ring, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 548; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":577
 * 
 * 
 * def nest2ring64 (nside,ipnest, ipring = None):             # <<<<<<<<<<<<<<
 *   "nest2ring"
 *   shape = numpy.broadcast(1, nside,ipnest).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_35nest2ring64, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__nest2ring64, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":606
 * 
 * 
 * def ring2nest (nside,ipring, ipnest = None):             # <<<<<<<<<<<<<<
 *   "ring2nest"
 *   shape = numpy.broadcast(1, nside,ipring).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_37ring2nest, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 606; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__ring2nest, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 606; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":635
 * 
 * 
 * def ring2nest64 (nside,ipring, ipnest = None):             # <<<<<<<<<<<<<<
 *   "ring2nest"
 *   shape = numpy.broadcast(1, nside,ipring).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_39ring2nest64, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__ring2nest64, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":664
 * 
 * 
 * def npix2nside (npix, nside = None):             # <<<<<<<<<<<<<<
 *   "npix2nside"
 *   shape = numpy.broadcast(1, npix).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_41npix2nside, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 664; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__npix2nside, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 664; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":691
 * 
 * 
 * def npix2nside64 (npix, nside = None):             # <<<<<<<<<<<<<<
 *   "npix2nside"
 *   shape = numpy.broadcast(1, npix).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_43npix2nside64, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 691; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__npix2nside64, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 691; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":718
 * 
 * 
 * def nside2npix (nside, npix = None):             # <<<<<<<<<<<<<<
 *   "nside2npix"
 *   shape = numpy.broadcast(1, nside).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_45nside2npix, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 718; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__nside2npix, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 718; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":745
 * 
 * 
 * def nside2npix64 (nside, npix = None):             # <<<<<<<<<<<<<<
 *   "nside2npix"
 *   shape = numpy.broadcast(1, nside).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_47nside2npix64, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__nside2npix64, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":772
 * 
 * 
 * def ang2vec (theta,phi, vec = None):             # <<<<<<<<<<<<<<
 *   "ang2vec"
 *   shape = numpy.broadcast(1, theta,phi).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_49ang2vec, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__ang2vec, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":804
 * 
 * 
 * def vec2ang (vec, theta = None,phi = None):             # <<<<<<<<<<<<<<
 *   "vec2ang"
 *   shape = numpy.broadcast(1, vec[...,0],vec[...,1],vec[...,2]).shape
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_7chealpy_6_ccode_51vec2ang, NULL, __pyx_n_s_86); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 804; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__vec2ang, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 804; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "chealpy/_ccode.pyx":2
 * 
 * # do not edit. This is auto-generated             # <<<<<<<<<<<<<<
 * #cython: embedsignature=True
 * #cython: cdivision=True
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s____test__, ((PyObject *)__pyx_t_1)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;

  /* "numpy.pxd":974
 *      arr.base = baseptr
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     if arr.base is NULL:
 *         return None
 */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  if (__pyx_m) {
    __Pyx_AddTraceback("init chealpy._ccode", __pyx_clineno, __pyx_lineno, __pyx_filename);
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init chealpy._ccode");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* Runtime support code */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif /* CYTHON_REFNANNY */

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%s() takes %s %"PY_FORMAT_SIZE_T"d positional argument%s (%"PY_FORMAT_SIZE_T"d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AS_STRING(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
        } else {
            #if PY_MAJOR_VERSION < 3
            if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key))) {
            #else
            if (unlikely(!PyUnicode_Check(key))) {
            #endif
                goto invalid_keyword_type;
            } else {
                for (name = first_kw_arg; *name; name++) {
                    #if PY_MAJOR_VERSION >= 3
                    if (PyUnicode_GET_SIZE(**name) == PyUnicode_GET_SIZE(key) &&
                        PyUnicode_Compare(**name, key) == 0) break;
                    #else
                    if (PyString_GET_SIZE(**name) == PyString_GET_SIZE(key) &&
                        _PyString_Eq(**name, key)) break;
                    #endif
                }
                if (*name) {
                    values[name-argnames] = value;
                } else {
                    for (name=argnames; name != first_kw_arg; name++) {
                        if (**name == key) goto arg_passed_twice;
                        #if PY_MAJOR_VERSION >= 3
                        if (PyUnicode_GET_SIZE(**name) == PyUnicode_GET_SIZE(key) &&
                            PyUnicode_Compare(**name, key) == 0) goto arg_passed_twice;
                        #else
                        if (PyString_GET_SIZE(**name) == PyString_GET_SIZE(key) &&
                            _PyString_Eq(**name, key)) goto arg_passed_twice;
                        #endif
                    }
                    if (kwds2) {
                        if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                    } else {
                        goto invalid_keyword;
                    }
                }
            }
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, **name);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static PyObject *__Pyx_GetName(PyObject *dict, PyObject *name) {
    PyObject *result;
    result = PyObject_GetAttr(dict, name);
    if (!result) {
        if (dict != __pyx_b) {
            PyErr_Clear();
            result = PyObject_GetAttr(__pyx_b, name);
        }
        if (!result) {
            PyErr_SetObject(PyExc_NameError, name);
        }
    }
    return result;
}

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_Format(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(PyObject_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_Restore(type, value, tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(type, value, tb);
#endif
}

#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    Py_XINCREF(type);
    Py_XINCREF(value);
    Py_XINCREF(tb);
    if (tb == Py_None) {
        Py_DECREF(tb);
        tb = 0;
    }
    else if (tb != NULL && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto raise_error;
    }
    if (value == NULL) {
        value = Py_None;
        Py_INCREF(value);
    }
    #if PY_VERSION_HEX < 0x02050000
    if (!PyClass_Check(type))
    #else
    if (!PyType_Check(type))
    #endif
    {
        if (value != Py_None) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        Py_DECREF(value);
        value = type;
        #if PY_VERSION_HEX < 0x02050000
            if (PyInstance_Check(type)) {
                type = (PyObject*) ((PyInstanceObject*)type)->in_class;
                Py_INCREF(type);
            }
            else {
                type = 0;
                PyErr_SetString(PyExc_TypeError,
                    "raise: exception must be an old-style class or instance");
                goto raise_error;
            }
        #else
            type = (PyObject*) Py_TYPE(type);
            Py_INCREF(type);
            if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
                PyErr_SetString(PyExc_TypeError,
                    "raise: exception class must be a subclass of BaseException");
                goto raise_error;
            }
        #endif
    }
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else /* Python 3+ */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (!PyExceptionClass_Check(type)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        }
        else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        }
        else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        if (!value) {
            value = PyObject_CallObject(type, NULL);
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
    }
bad:
    return;
}
#endif

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %"PY_FORMAT_SIZE_T"d value%s to unpack",
                 index, (index == 1) ? "" : "s");
}

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %"PY_FORMAT_SIZE_T"d)", expected);
}

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, long level) {
    PyObject *py_import = 0;
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    py_import = __Pyx_GetAttrString(__pyx_b, "__import__");
    if (!py_import)
        goto bad;
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    #if PY_VERSION_HEX >= 0x02050000
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                /* try package relative import first */
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0; /* try absolute import on failure */
        }
        #endif
        if (!module) {
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
        }
    }
    #else
    if (level>0) {
        PyErr_SetString(PyExc_RuntimeError, "Relative import is not supported for Python <=2.4.");
        goto bad;
    }
    module = PyObject_CallFunctionObjArgs(py_import,
        name, global_dict, empty_dict, list, NULL);
    #endif
bad:
    Py_XDECREF(empty_list);
    Py_XDECREF(py_import);
    Py_XDECREF(empty_dict);
    return module;
}

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

#if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eqf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sumf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_difff(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prodf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quotf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        float denom = b.real * b.real + b.imag * b.imag;
        z.real = (a.real * b.real + a.imag * b.imag) / denom;
        z.imag = (a.imag * b.real - a.real * b.imag) / denom;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_negf(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zerof(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conjf(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_absf(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_powf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prodf(a, a);
                        return __Pyx_c_prodf(a, a);
                    case 3:
                        z = __Pyx_c_prodf(a, a);
                        return __Pyx_c_prodf(z, a);
                    case 4:
                        z = __Pyx_c_prodf(a, a);
                        return __Pyx_c_prodf(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                }
                r = a.real;
                theta = 0;
            } else {
                r = __Pyx_c_absf(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

#if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        double denom = b.real * b.real + b.imag * b.imag;
        z.real = (a.real * b.real + a.imag * b.imag) / denom;
        z.imag = (a.imag * b.real - a.real * b.imag) / denom;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prod(a, a);
                        return __Pyx_c_prod(a, a);
                    case 3:
                        z = __Pyx_c_prod(a, a);
                        return __Pyx_c_prod(z, a);
                    case 4:
                        z = __Pyx_c_prod(a, a);
                        return __Pyx_c_prod(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                }
                r = a.real;
                theta = 0;
            } else {
                r = __Pyx_c_abs(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject* x) {
    const unsigned char neg_one = (unsigned char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned char" :
                    "value too large to convert to unsigned char");
            }
            return (unsigned char)-1;
        }
        return (unsigned char)val;
    }
    return (unsigned char)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject* x) {
    const unsigned short neg_one = (unsigned short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned short" :
                    "value too large to convert to unsigned short");
            }
            return (unsigned short)-1;
        }
        return (unsigned short)val;
    }
    return (unsigned short)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject* x) {
    const unsigned int neg_one = (unsigned int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned int" :
                    "value too large to convert to unsigned int");
            }
            return (unsigned int)-1;
        }
        return (unsigned int)val;
    }
    return (unsigned int)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject* x) {
    const char neg_one = (char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to char" :
                    "value too large to convert to char");
            }
            return (char)-1;
        }
        return (char)val;
    }
    return (char)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject* x) {
    const short neg_one = (short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to short" :
                    "value too large to convert to short");
            }
            return (short)-1;
        }
        return (short)val;
    }
    return (short)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject* x) {
    const signed char neg_one = (signed char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed char" :
                    "value too large to convert to signed char");
            }
            return (signed char)-1;
        }
        return (signed char)val;
    }
    return (signed char)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject* x) {
    const signed short neg_one = (signed short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed short" :
                    "value too large to convert to signed short");
            }
            return (signed short)-1;
        }
        return (signed short)val;
    }
    return (signed short)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject* x) {
    const signed int neg_one = (signed int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed int" :
                    "value too large to convert to signed int");
            }
            return (signed int)-1;
        }
        return (signed int)val;
    }
    return (signed int)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject* x) {
    const unsigned long neg_one = (unsigned long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned long");
            return (unsigned long)-1;
        }
        return (unsigned long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned long");
                return (unsigned long)-1;
            }
            return (unsigned long)PyLong_AsUnsignedLong(x);
        } else {
            return (unsigned long)PyLong_AsLong(x);
        }
    } else {
        unsigned long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned long)-1;
        val = __Pyx_PyInt_AsUnsignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject* x) {
    const unsigned PY_LONG_LONG neg_one = (unsigned PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned PY_LONG_LONG");
            return (unsigned PY_LONG_LONG)-1;
        }
        return (unsigned PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned PY_LONG_LONG");
                return (unsigned PY_LONG_LONG)-1;
            }
            return (unsigned PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (unsigned PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        unsigned PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsUnsignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject* x) {
    const long neg_one = (long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to long");
            return (long)-1;
        }
        return (long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long)-1;
            }
            return (long)PyLong_AsUnsignedLong(x);
        } else {
            return (long)PyLong_AsLong(x);
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long)-1;
        val = __Pyx_PyInt_AsLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject* x) {
    const PY_LONG_LONG neg_one = (PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to PY_LONG_LONG");
            return (PY_LONG_LONG)-1;
        }
        return (PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to PY_LONG_LONG");
                return (PY_LONG_LONG)-1;
            }
            return (PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject* x) {
    const signed long neg_one = (signed long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed long");
            return (signed long)-1;
        }
        return (signed long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed long");
                return (signed long)-1;
            }
            return (signed long)PyLong_AsUnsignedLong(x);
        } else {
            return (signed long)PyLong_AsLong(x);
        }
    } else {
        signed long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed long)-1;
        val = __Pyx_PyInt_AsSignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject* x) {
    const signed PY_LONG_LONG neg_one = (signed PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed PY_LONG_LONG");
            return (signed PY_LONG_LONG)-1;
        }
        return (signed PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed PY_LONG_LONG");
                return (signed PY_LONG_LONG)-1;
            }
            return (signed PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (signed PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        signed PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsSignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        #if PY_VERSION_HEX < 0x02050000
        return PyErr_Warn(NULL, message);
        #else
        return PyErr_WarnEx(NULL, message, 1);
        #endif
    }
    return 0;
}

#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name,
    size_t size, int strict)
{
    PyObject *py_module = 0;
    PyObject *result = 0;
    PyObject *py_name = 0;
    char warning[200];
    py_module = __Pyx_ImportModule(module_name);
    if (!py_module)
        goto bad;
    py_name = __Pyx_PyIdentifier_FromString(class_name);
    if (!py_name)
        goto bad;
    result = PyObject_GetAttr(py_module, py_name);
    Py_DECREF(py_name);
    py_name = 0;
    Py_DECREF(py_module);
    py_module = 0;
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%s.%s is not a type object",
            module_name, class_name);
        goto bad;
    }
    if (!strict && (size_t)((PyTypeObject *)result)->tp_basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility",
            module_name, class_name);
        #if PY_VERSION_HEX < 0x02050000
        if (PyErr_Warn(NULL, warning) < 0) goto bad;
        #else
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
        #endif
    }
    else if ((size_t)((PyTypeObject *)result)->tp_basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%s.%s has the wrong size, try recompiling",
            module_name, class_name);
        goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(py_module);
    Py_XDECREF(result);
    return NULL;
}
#endif

#ifndef __PYX_HAVE_RT_ImportModule
#define __PYX_HAVE_RT_ImportModule
static PyObject *__Pyx_ImportModule(const char *name) {
    PyObject *py_name = 0;
    PyObject *py_module = 0;
    py_name = __Pyx_PyIdentifier_FromString(name);
    if (!py_name)
        goto bad;
    py_module = PyImport_Import(py_name);
    Py_DECREF(py_name);
    return py_module;
bad:
    Py_XDECREF(py_name);
    return 0;
}
#endif

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,            /*int argcount,*/
        0,            /*int kwonlyargcount,*/
        0,            /*int nlocals,*/
        0,            /*int stacksize,*/
        0,            /*int flags,*/
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,      /*int firstlineno,*/
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_globals = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_globals = PyModule_GetDict(__pyx_m);
    if (!py_globals) goto bad;
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        py_globals,          /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else  /* Python 3+ has unicode identifiers */
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}


/* Type Conversion Functions */

static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}

static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_VERSION_HEX < 0x03000000
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_VERSION_HEX < 0x03000000
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%s__ returned non-%s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}

static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject* x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}

static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
#if PY_VERSION_HEX < 0x02050000
   if (ival <= LONG_MAX)
       return PyInt_FromLong((long)ival);
   else {
       unsigned char *bytes = (unsigned char *) &ival;
       int one = 1; int little = (int)*(unsigned char*)&one;
       return _PyLong_FromByteArray(bytes, sizeof(size_t), little, 0);
   }
#else
   return PyInt_FromSize_t(ival);
#endif
}

static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject* x) {
   unsigned PY_LONG_LONG val = __Pyx_PyInt_AsUnsignedLongLong(x);
   if (unlikely(val == (unsigned PY_LONG_LONG)-1 && PyErr_Occurred())) {
       return (size_t)-1;
   } else if (unlikely(val != (unsigned PY_LONG_LONG)(size_t)val)) {
       PyErr_SetString(PyExc_OverflowError,
                       "value too large to convert to size_t");
       return (size_t)-1;
   }
   return (size_t)val;
}


#endif /* Py_PYTHON_H */
